@@ -33,19 +33,26 @@
 #include "backend/core/Project.h"
 #include "commonfrontend/cantorWorksheet/CantorWorksheetView.h"
 
+#include <cantor/cantorlibs_version.h>
+#include "3rdparty/cantor/cantor_part.h"
+#include <cantor/worksheetaccess.h>
+
+#ifdef HAVE_NEW_CANTOR_LIBS
+#include <cantor/panelpluginhandler.h>
+#include <cantor/panelplugin.h>
+#else
+#include "3rdparty/cantor/panelpluginhandler.h"
+#include "3rdparty/cantor/panelplugin.h"
+#endif
+
+#include <QAction>
+#include <QFileInfo>
+#include <QModelIndex>
+
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KParts/ReadWritePart>
 
-#include <QAction>
-#include <QModelIndex>
-#include <QDebug>
-
-#include "cantor/cantor_part.h"
-#include <cantor/panelpluginhandler.h>
-#include <cantor/panelplugin.h>
-#include <cantor/worksheetaccess.h>
-
 CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
 	: AbstractPart(name, AspectType::CantorWorksheet), m_backendName(name) {
 
@@ -57,15 +64,15 @@ CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
 	initializes Cantor's part and plugins
 */
 bool CantorWorksheet::init(QByteArray* content) {
-	KPluginLoader loader(QLatin1String("libcantorpart"));
+	KPluginLoader loader(QLatin1String("cantorpart"));
 	KPluginFactory* factory = loader.factory();
 
 	if (!factory) {
 		//we can only get to this here if we open a project having Cantor content and Cantor plugins were not found.
 		//return false here, a proper error message will be created in load() and propagated further.
 		WARN("Failed to load Cantor plugin:")
-		WARN("Cantor Part file name: " << loader.fileName().toStdString())
-		WARN("	" << loader.errorString().toStdString())
+		WARN("Cantor Part file name: " << STDSTRING(loader.fileName()))
+		WARN("	" << STDSTRING(loader.errorString()))
 		return false;
 	} else {
 		m_part = factory->create<KParts::ReadWritePart>(this, QVariantList() << m_backendName << QLatin1String("--noprogress"));
@@ -86,23 +93,27 @@ bool CantorWorksheet::init(QByteArray* content) {
 		connect(m_session, SIGNAL(statusChanged(Cantor::Session::Status)), this, SIGNAL(statusChanged(Cantor::Session::Status)));
 
 		//variable model
-#ifndef OLD_CANTORLIBS_VERSION
 		m_variableModel = m_session->variableDataModel();
-#else
-		m_variableModel = m_session->variableModel();
-#endif
 		connect(m_variableModel, &QAbstractItemModel::dataChanged, this, &CantorWorksheet::dataChanged);
 		connect(m_variableModel, &QAbstractItemModel::rowsInserted, this, &CantorWorksheet::rowsInserted);
 		connect(m_variableModel, &QAbstractItemModel::rowsAboutToBeRemoved, this, &CantorWorksheet::rowsAboutToBeRemoved);
 		connect(m_variableModel, &QAbstractItemModel::modelReset, this, &CantorWorksheet::modelReset);
 
 		//available plugins
+#ifdef HAVE_NEW_CANTOR_LIBS
+		auto* handler = new Cantor::PanelPluginHandler(this);
+		handler->loadPlugins();
+		m_plugins = handler->activePluginsForSession(m_session, Cantor::PanelPluginHandler::PanelStates());
+		for (auto* plugin : m_plugins)
+			plugin->connectToShell(m_part);
+#else
 		auto* handler = m_part->findChild<Cantor::PanelPluginHandler*>(QLatin1String("PanelPluginHandler"));
 		if (!handler) {
-			KMessageBox::error(view(), i18n("no PanelPluginHandle found for the Cantor Part."));
+			KMessageBox::error(nullptr, i18n("No PanelPluginHandle found for the Cantor Part."));
 			return false;
 		}
 		m_plugins = handler->plugins();
+#endif
 	}
 
 	return true;
@@ -170,20 +181,13 @@ void CantorWorksheet::modelReset() {
 
 void CantorWorksheet::rowsAboutToBeRemoved(const QModelIndex & parent, int first, int last) {
 	Q_UNUSED(parent);
-#ifndef OLD_CANTORLIBS_VERSION
+
 	for (int i = first; i <= last; ++i) {
 		const QString& name = m_variableModel->data(m_variableModel->index(first, 0)).toString();
 		Column* column = child<Column>(name);
 		if (column)
 			column->remove();
 	}
-#else
-	Q_UNUSED(first);
-	Q_UNUSED(last);
-	//TODO: Old Cantor removes rows from the model even when the variable was changed only.
-	//We don't want this behaviour since this removes the columns from the datasource in the curve.
-	return;
-#endif
 }
 
 QList<Cantor::PanelPlugin*> CantorWorksheet::getPlugins() {
@@ -206,6 +210,14 @@ QWidget* CantorWorksheet::view() const {
 		m_view->setBaseSize(1500, 1500);
 		m_partView = m_view;
 		// 	connect(m_view, SIGNAL(statusInfo(QString)), this, SIGNAL(statusInfo(QString)));
+
+		//set the current path in the session to the path of the project file
+		const Project* project = const_cast<CantorWorksheet*>(this)->project();
+		const QString& fileName = project->fileName();
+		if (!fileName.isEmpty()) {
+			QFileInfo fi(fileName);
+			m_session->setWorksheetPath(fi.filePath());
+		}
 	}
 	return m_partView;
 }
@@ -263,7 +275,7 @@ void CantorWorksheet::save(QXmlStreamWriter* writer) const{
 	writer->writeEndElement();
 
 	//save columns(variables)
-	for (auto* col : children<Column>(IncludeHidden))
+	for (auto* col : children<Column>(ChildIndexFlag::IncludeHidden))
 		col->save(writer);
 
 	writer->writeEndElement(); // close "cantorWorksheet" section
