@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Represents a LabPlot project.
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2019 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2011-2020 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2007-2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2007 Knut Franke (knut.franke@gmx.de)
  ***************************************************************************/
@@ -44,6 +44,7 @@
 #include <QDateTime>
 #include <QFile>
 #include <QMenu>
+#include <QMimeData>
 #include <QThreadPool>
 #include <QUndoStack>
 #include <QBuffer>
@@ -82,10 +83,14 @@
 
 class Project::Private {
 public:
-	Private() :
+	Private(Project* owner) :
 		version(LVERSION),
 		author(QString(qgetenv("USER"))),
-		modificationTime(QDateTime::currentDateTime()) {
+		modificationTime(QDateTime::currentDateTime()),
+		q(owner) {
+	}
+	QString name() const  {
+		return q->name();
 	}
 
 	QUndoStack undo_stack;
@@ -96,9 +101,10 @@ public:
 	QDateTime modificationTime;
 	bool changed{false};
 	bool aspectAddedSignalSuppressed{false};
+	Project* const q;
 };
 
-Project::Project() : Folder(i18n("Project"), AspectType::Project), d(new Private()) {
+Project::Project() : Folder(i18n("Project"), AspectType::Project), d(new Private(this)) {
 	//load default values for name, comment and author from config
 	KConfig config;
 	KConfigGroup group = config.group("Project");
@@ -175,9 +181,15 @@ Project::MdiWindowVisibility Project::mdiWindowVisibility() const {
 
 CLASS_D_ACCESSOR_IMPL(Project, QString, fileName, FileName, fileName)
 BASIC_D_ACCESSOR_IMPL(Project, QString, version, Version, version)
-CLASS_D_ACCESSOR_IMPL(Project, QString, author, Author, author)
+CLASS_D_READER_IMPL(Project, QString, author, author)
 CLASS_D_ACCESSOR_IMPL(Project, QDateTime, modificationTime, ModificationTime, modificationTime)
 
+STD_SETTER_CMD_IMPL_S(Project, SetAuthor, QString, author)
+void Project::setAuthor(const QString& author) {
+	if (author != d->author)
+		exec(new ProjectSetAuthorCmd(d, author, ki18n("%1: set author")));
+}
+
 void Project::setChanged(const bool value) {
 	if (isLoading())
 		return;
@@ -197,7 +209,7 @@ bool Project::aspectAddedSignalSuppressed() const {
 }
 
 bool Project::hasChanged() const {
-	return d->changed ;
+	return d->changed;
 }
 
 /*!
@@ -361,6 +373,21 @@ QString Project::supportedExtensions() {
 	return extensions;
 }
 
+QVector<quintptr> Project::droppedAspects(const QMimeData* mimeData) {
+	QByteArray data = mimeData->data(QLatin1String("labplot-dnd"));
+	QDataStream stream(&data, QIODevice::ReadOnly);
+
+	//read the project pointer first
+	quintptr project = 0;
+	stream >> project;
+
+	//read the pointers of the dragged aspects
+	QVector<quintptr> vec;
+	stream >> vec;
+
+	return vec;
+}
+
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
