@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Represents a LabPlot project.
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2014 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2011-2020 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2007-2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2007 Knut Franke (knut.franke@gmx.de)
 
@@ -33,6 +33,7 @@
 #include "backend/core/Folder.h"
 #include "backend/lib/macros.h"
 
+class QMimeData;
 class QString;
 
 class Project : public Folder {
@@ -82,12 +83,16 @@ public:
 
 	static bool isLabPlotProject(const QString& fileName);
 	static QString supportedExtensions();
+	QVector<quintptr> droppedAspects(const QMimeData*);
+
+	class Private;
 
 public slots:
 	void descriptionChanged(const AbstractAspect*);
 	void aspectAddedSlot(const AbstractAspect*);
 
 signals:
+	void authorChanged(const QString&);
 	void requestSaveState(QXmlStreamWriter*) const;
 	void requestLoadState(XmlStreamReader*);
 	void requestProjectContextMenu(QMenu*);
@@ -99,7 +104,6 @@ signals:
 	void closeRequested();
 
 private:
-	class Private;
 	Private* d;
 	bool readProjectAttributes(XmlStreamReader*);
 	void save(QXmlStreamWriter*) const override;
