@@ -51,12 +51,12 @@ public:
 	}
 
 	//! Return the data type of the column
-	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::Numeric; }
+	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::ColumnMode::Numeric; }
 
 protected:
 	//! Using typed ports: only date-time inputs are accepted.
 	bool inputAcceptable(int, const AbstractColumn *source) override {
-		return source->columnMode() == AbstractColumn::Month;
+		return source->columnMode() == AbstractColumn::ColumnMode::Month;
 	}
 };
 
