@@ -2,8 +2,8 @@
     File                 : String2DoubleFilter.h
     Project              : AbstractColumn
     --------------------------------------------------------------------
-    Copyright            : (C) 2007 by Knut Franke
-    Email (use @ for *)  : knut.franke*gmx.de
+    Copyright            : (C) 2007 by Knut Franke (knut.franke*gmx.de)
+    Copyright            : (C) 2020 by Stefan Gerlach (stefan.gerlach@uni.kn)
     Description          : Locale-aware conversion filter QString -> double.
 
  ***************************************************************************/
@@ -38,21 +38,20 @@ class String2DoubleFilter : public AbstractSimpleFilter {
 	Q_OBJECT
 
 public:
-	String2DoubleFilter() : m_use_default_locale(true) {}
-	void setNumericLocale(const QLocale& locale) { m_numeric_locale = locale; m_use_default_locale = false; }
-	void setNumericLocaleToDefault() { m_use_default_locale = true; }
+	String2DoubleFilter() {}
 
 	double valueAt(int row) const override {
-		DEBUG("String2Double::valueAt()");
+		//DEBUG("String2Double::valueAt()");
 
-		if (!m_inputs.value(0)) return 0;
+		if (!m_inputs.value(0))
+			return 0;
 
 		double result;
 		bool valid;
-		if (m_use_default_locale) // we need a new QLocale instance here in case the default changed since the last call
+		if (m_useDefaultLocale) // we need a new QLocale instance here in case the default changed since the last call
 			result = QLocale().toDouble(m_inputs.value(0)->textAt(row), &valid);
 		else
-			result = m_numeric_locale.toDouble(m_inputs.value(0)->textAt(row), &valid);
+			result = m_numberLocale.toDouble(m_inputs.value(0)->textAt(row), &valid);
 
 		if (valid)
 			return result;
@@ -60,17 +59,13 @@ public:
 	}
 
 	//! Return the data type of the column
-	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::Numeric; }
+	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::ColumnMode::Numeric; }
 
 protected:
 	//! Using typed ports: only string inputs are accepted.
 	bool inputAcceptable(int, const AbstractColumn *source) override {
-		return source->columnMode() == AbstractColumn::Text;
+		return source->columnMode() == AbstractColumn::ColumnMode::Text;
 	}
-
-private:
-	QLocale m_numeric_locale;
-	bool m_use_default_locale;
 };
 
 #endif // ifndef STRING2DOUBLE_FILTER_H
