@@ -150,6 +150,7 @@ DatapickerImage* Datapicker::image() const {
     in order to select the corresponding tab.
  */
 void Datapicker::childSelected(const AbstractAspect* aspect) {
+	Q_ASSERT(aspect);
 	m_activeCurve = dynamic_cast<DatapickerCurve*>(const_cast<AbstractAspect*>(aspect));
 
 	int index = -1;
@@ -158,7 +159,7 @@ void Datapicker::childSelected(const AbstractAspect* aspect) {
 		index = 0;
 		emit statusInfo(i18n("%1, active curve \"%2\"", this->name(), m_activeCurve->name()));
 		emit requestUpdateActions();
-	} else {
+	} else if (aspect) {
 		const auto* curve = aspect->ancestor<const DatapickerCurve>();
 		index = indexOfChild<AbstractAspect>(curve);
 		++index; //+1 because of the hidden plot image being the first child and shown in the first tab in the view
@@ -199,7 +200,7 @@ void Datapicker::setChildSelectedInView(int index, bool selected) {
 	--index; //-1 because of the first tab in the view being reserved for the plot image and curves
 
 	//select/deselect the data spreadhseets
-	QVector<const Spreadsheet*> spreadsheets = children<const Spreadsheet>(AbstractAspect::Recursive);
+	auto spreadsheets = children<const Spreadsheet>(ChildIndexFlag::Recursive);
 	const AbstractAspect* aspect = spreadsheets.at(index);
 	if (selected) {
 		emit childAspectSelectedInView(aspect);
@@ -227,10 +228,10 @@ void Datapicker::setSelectedInView(const bool b) {
 		emit childAspectDeselectedInView(this);
 }
 
-void Datapicker::addNewPoint(const QPointF& pos, AbstractAspect* parentAspect) {
-	QVector<DatapickerPoint*> childPoints = parentAspect->children<DatapickerPoint>(AbstractAspect::IncludeHidden);
+void Datapicker::addNewPoint(QPointF pos, AbstractAspect* parentAspect) {
+	auto points = parentAspect->children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
 
-	auto* newPoint = new DatapickerPoint(i18n("Point %1", childPoints.count() + 1));
+	auto* newPoint = new DatapickerPoint(i18n("Point %1", points.count() + 1));
 	newPoint->setPosition(pos);
 	newPoint->setHidden(true);
 
@@ -238,12 +239,12 @@ void Datapicker::addNewPoint(const QPointF& pos, AbstractAspect* parentAspect) {
 	parentAspect->addChild(newPoint);
 	newPoint->retransform();
 
-	auto* datapickerCurve = dynamic_cast<DatapickerCurve*>(parentAspect);
+	auto* datapickerCurve = static_cast<DatapickerCurve*>(parentAspect);
 	if (m_image == parentAspect) {
-		DatapickerImage::ReferencePoints points = m_image->axisPoints();
-		points.scenePos[childPoints.count()].setX(pos.x());
-		points.scenePos[childPoints.count()].setY(pos.y());
-		m_image->setAxisPoints(points);
+		DatapickerImage::ReferencePoints axisPoints = m_image->axisPoints();
+		axisPoints.scenePos[points.count()].setX(pos.x());
+		axisPoints.scenePos[points.count()].setY(pos.y());
+		m_image->setAxisPoints(axisPoints);
 	} else if (datapickerCurve) {
 		newPoint->initErrorBar(datapickerCurve->curveErrorTypes());
 		datapickerCurve->updatePoint(newPoint);
@@ -253,11 +254,11 @@ void Datapicker::addNewPoint(const QPointF& pos, AbstractAspect* parentAspect) {
 	emit requestUpdateActions();
 }
 
-QVector3D Datapicker::mapSceneToLogical(const QPointF& point) const {
+QVector3D Datapicker::mapSceneToLogical(QPointF point) const {
 	return m_transform->mapSceneToLogical(point, m_image->axisPoints());
 }
 
-QVector3D Datapicker::mapSceneLengthToLogical(const QPointF& point) const {
+QVector3D Datapicker::mapSceneLengthToLogical(QPointF point) const {
 	return m_transform->mapSceneLengthToLogical(point, m_image->axisPoints());
 }
 
@@ -265,7 +266,7 @@ void Datapicker::handleAspectAboutToBeRemoved(const AbstractAspect* aspect) {
 	const auto* curve = qobject_cast<const DatapickerCurve*>(aspect);
 	if (curve) {
 		//clear scene
-		auto points = curve->children<DatapickerPoint>(IncludeHidden);
+		auto points = curve->children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
 		for (auto* point : points)
 			handleChildAspectAboutToBeRemoved(point);
 
@@ -286,19 +287,19 @@ void Datapicker::handleAspectAdded(const AbstractAspect* aspect) {
 		handleChildAspectAdded(addedPoint);
 	else if (curve) {
 		connect(m_image, &DatapickerImage::axisPointsChanged, curve, &DatapickerCurve::updatePoints);
-		auto points = curve->children<DatapickerPoint>(IncludeHidden);
+		auto points = curve->children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
 		for (auto* point : points)
 			handleChildAspectAdded(point);
 	} else
 		return;
 
 	qreal zVal = 0;
-	auto points = m_image->children<DatapickerPoint>(IncludeHidden);
+	auto points = m_image->children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
 	for (auto* point : points)
 		point->graphicsItem()->setZValue(zVal++);
 
 	for (const auto* curve : children<DatapickerCurve>()) {
-		for (auto* point : curve->children<DatapickerPoint>(IncludeHidden))
+		for (auto* point : curve->children<DatapickerPoint>(ChildIndexFlag::IncludeHidden))
 			point->graphicsItem()->setZValue(zVal++);
 	}
 
@@ -336,7 +337,7 @@ void Datapicker::save(QXmlStreamWriter* writer) const {
 	writeCommentElement(writer);
 
 	//serialize all children
-	for (auto* child : children<AbstractAspect>(IncludeHidden))
+	for (auto* child : children<AbstractAspect>(ChildIndexFlag::IncludeHidden))
 		child->save(writer);
 
 	writer->writeEndElement(); // close "datapicker" section
@@ -359,7 +360,7 @@ bool Datapicker::load(XmlStreamReader* reader, bool preview) {
 			if (!readCommentElement(reader))
 				return false;
 		} else if (reader->name() == "datapickerImage") {
-			DatapickerImage* plot = new DatapickerImage(i18n("Plot"), true);
+			auto* plot = new DatapickerImage(i18n("Plot"), true);
 			if (!plot->load(reader, preview)) {
 				delete plot;
 				return false;
@@ -369,7 +370,7 @@ bool Datapicker::load(XmlStreamReader* reader, bool preview) {
 				m_image = plot;
 			}
 		} else if (reader->name() == "datapickerCurve") {
-			DatapickerCurve* curve = new DatapickerCurve(QString());
+			auto* curve = new DatapickerCurve(QString());
 			if (!curve->load(reader, preview)) {
 				delete curve;
 				return false;
@@ -381,8 +382,8 @@ bool Datapicker::load(XmlStreamReader* reader, bool preview) {
 		}
 	}
 
-	for (auto* aspect : children<AbstractAspect>(IncludeHidden)) {
-		for (auto* point : aspect->children<DatapickerPoint>(IncludeHidden))
+	for (auto* aspect : children<AbstractAspect>(ChildIndexFlag::IncludeHidden)) {
+		for (auto* point : aspect->children<DatapickerPoint>(ChildIndexFlag::IncludeHidden))
 			handleAspectAdded(point);
 	}
 
