@@ -48,7 +48,7 @@ public:
 	explicit DatapickerCurve(const QString&);
 	~DatapickerCurve() override;
 
-	enum ErrorType {NoError, SymmetricError, AsymmetricError};
+	enum class ErrorType {NoError, SymmetricError, AsymmetricError};
 	struct Errors {
 		ErrorType x;
 		ErrorType y;
