@@ -47,9 +47,11 @@ Copyright	: (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 #include <QMessageBox>
 #include <QProcess>
 #include <QTimer>
-#include <QSerialPortInfo>
 #include <QTcpSocket>
 #include <QUdpSocket>
+#ifdef HAVE_QTSERIALPORT
+#include <QSerialPortInfo>
+#endif
 
 #include <KLocalizedString>
 
@@ -76,7 +78,9 @@ LiveDataSource::~LiveDataSource() {
 	delete m_fileSystemWatcher;
 	delete m_localSocket;
 	delete m_tcpSocket;
+#ifdef HAVE_QTSERIALPORT
 	delete m_serialPort;
+#endif
 }
 
 void LiveDataSource::initActions() {
@@ -101,14 +105,16 @@ QStringList LiveDataSource::availablePorts() {
 	QStringList ports;
 // 	qDebug() << "available ports count:" << QSerialPortInfo::availablePorts().size();
 
+#ifdef HAVE_QTSERIALPORT
 	for (const QSerialPortInfo& sp : QSerialPortInfo::availablePorts()) {
 		ports.append(sp.portName());
 
-		DEBUG(" port " << sp.portName().toStdString() << ": " << sp.systemLocation().toStdString() << sp.description().toStdString()
-			<< ' ' << sp.manufacturer().toStdString() << ' ' << sp.serialNumber().toStdString());
+		DEBUG(" port " << STDSTRING(sp.portName()) << ": " << STDSTRING(sp.systemLocation()) << STDSTRING(sp.description())
+			<< ' ' << STDSTRING(sp.manufacturer()) << ' ' << STDSTRING(sp.serialNumber()));
 	}
 	// For Testing:
 	// ports.append("/dev/pts/26");
+#endif
 
 	return ports;
 }
@@ -119,8 +125,10 @@ QStringList LiveDataSource::availablePorts() {
 QStringList LiveDataSource::supportedBaudRates() {
 	QStringList baudRates;
 
+#ifdef HAVE_QTSERIALPORT
 	for (const auto& baud : QSerialPortInfo::standardBaudRates())
 		baudRates.append(QString::number(baud));
+#endif
 	return baudRates;
 }
 
@@ -129,14 +137,14 @@ QStringList LiveDataSource::supportedBaudRates() {
  */
 void LiveDataSource::updateNow() {
 	DEBUG("LiveDataSource::updateNow() update interval = " << m_updateInterval);
-	if (m_updateType == TimeInterval)
+	if (m_updateType == UpdateType::TimeInterval)
 		m_updateTimer->stop();
 	else
 		m_pending = false;
 	read();
 
 	//restart the timer after update
-	if (m_updateType == TimeInterval && !m_paused)
+	if (m_updateType == UpdateType::TimeInterval && !m_paused)
 		m_updateTimer->start(m_updateInterval);
 }
 
@@ -156,7 +164,7 @@ void LiveDataSource::continueReading() {
  */
 void LiveDataSource::pauseReading() {
 	m_paused = true;
-	if (m_updateType == TimeInterval) {
+	if (m_updateType == UpdateType::TimeInterval) {
 		m_pending = true;
 		m_updateTimer->stop();
 	}
@@ -315,7 +323,7 @@ LiveDataSource::ReadingType LiveDataSource::readingType() const {
  */
 void LiveDataSource::setUpdateType(UpdateType updatetype) {
 	switch (updatetype) {
-	case NewData: {
+	case UpdateType::NewData: {
 		m_updateTimer->stop();
 		if (!m_fileSystemWatcher)
 			m_fileSystemWatcher = new QFileSystemWatcher(this);
@@ -335,7 +343,7 @@ void LiveDataSource::setUpdateType(UpdateType updatetype) {
 		connect(m_fileSystemWatcher, &QFileSystemWatcher::directoryChanged, this, [&](){ m_watchTimer->start(); });
 		break;
 	}
-	case TimeInterval:
+	case UpdateType::TimeInterval:
 		delete m_fileSystemWatcher;
 		m_fileSystemWatcher = nullptr;
 		break;
@@ -387,28 +395,28 @@ QIcon LiveDataSource::icon() const {
 	QIcon icon;
 
 	switch (m_fileType) {
-	case AbstractFileFilter::Ascii:
+	case AbstractFileFilter::FileType::Ascii:
 		icon = QIcon::fromTheme("text-plain");
 		break;
-	case AbstractFileFilter::Binary:
+	case AbstractFileFilter::FileType::Binary:
 		icon = QIcon::fromTheme("application-octet-stream");
 		break;
-	case AbstractFileFilter::Image:
+	case AbstractFileFilter::FileType::Image:
 		icon = QIcon::fromTheme("image-x-generic");
 		break;
 	// TODO: missing icons
-	case AbstractFileFilter::HDF5:
-	case AbstractFileFilter::NETCDF:
+	case AbstractFileFilter::FileType::HDF5:
+	case AbstractFileFilter::FileType::NETCDF:
 		break;
-	case AbstractFileFilter::FITS:
+	case AbstractFileFilter::FileType::FITS:
 		icon = QIcon::fromTheme("kstars_fitsviewer");
 		break;
-	case AbstractFileFilter::JSON:
+	case AbstractFileFilter::FileType::JSON:
 		icon = QIcon::fromTheme("application-json");
 		break;
-	case AbstractFileFilter::ROOT:
-	case AbstractFileFilter::NgspiceRawAscii:
-	case AbstractFileFilter::NgspiceRawBinary:
+	case AbstractFileFilter::FileType::ROOT:
+	case AbstractFileFilter::FileType::NgspiceRawAscii:
+	case AbstractFileFilter::FileType::NgspiceRawBinary:
 		break;
 	}
 
@@ -474,11 +482,11 @@ void LiveDataSource::read() {
 	if (!m_prepared) {
 		DEBUG("	Preparing device: update type = " << ENUM_TO_STRING(LiveDataSource, UpdateType, m_updateType));
 		switch (m_sourceType) {
-		case FileOrPipe:
+		case SourceType::FileOrPipe:
 			delete m_device;
 			m_device = new QFile(m_fileName);
 			break;
-		case NetworkTcpSocket:
+		case SourceType::NetworkTcpSocket:
 			m_tcpSocket = new QTcpSocket(this);
 			m_device = m_tcpSocket;
 			m_tcpSocket->connectToHost(m_host, m_port, QIODevice::ReadOnly);
@@ -487,19 +495,19 @@ void LiveDataSource::read() {
 			connect(m_tcpSocket, static_cast<void (QTcpSocket::*) (QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &LiveDataSource::tcpSocketError);
 
 			break;
-		case NetworkUdpSocket:
+		case SourceType::NetworkUdpSocket:
 			m_udpSocket = new QUdpSocket(this);
 			m_device = m_udpSocket;
 			m_udpSocket->bind(QHostAddress(m_host), m_port);
 			m_udpSocket->connectToHost(m_host, 0, QUdpSocket::ReadOnly);
 
 			// only connect to readyRead when update is on new data
-			if (m_updateType == NewData)
+			if (m_updateType == UpdateType::NewData)
 				connect(m_udpSocket, &QUdpSocket::readyRead, this, &LiveDataSource::readyRead);
 			connect(m_udpSocket, static_cast<void (QUdpSocket::*) (QAbstractSocket::SocketError)>(&QUdpSocket::error), this, &LiveDataSource::tcpSocketError);
 
 			break;
-		case LocalSocket:
+		case SourceType::LocalSocket:
 			m_localSocket = new QLocalSocket(this);
 			m_device = m_localSocket;
 			m_localSocket->connectToServer(m_localSocketName, QLocalSocket::ReadOnly);
@@ -508,20 +516,22 @@ void LiveDataSource::read() {
 			connect(m_localSocket, static_cast<void (QLocalSocket::*) (QLocalSocket::LocalSocketError)>(&QLocalSocket::error), this, &LiveDataSource::localSocketError);
 
 			break;
-		case SerialPort:
+		case SourceType::SerialPort:
+#ifdef HAVE_QTSERIALPORT
 			m_serialPort = new QSerialPort(this);
 			m_device = m_serialPort;
-			DEBUG("	Serial: " << m_serialPortName.toStdString() << ", " << m_baudRate);
+			DEBUG("	Serial: " << STDSTRING(m_serialPortName) << ", " << m_baudRate);
 			m_serialPort->setBaudRate(m_baudRate);
 			m_serialPort->setPortName(m_serialPortName);
 			m_serialPort->open(QIODevice::ReadOnly);
 
 			// only connect to readyRead when update is on new data
-			if (m_updateType == NewData)
+			if (m_updateType == UpdateType::NewData)
 				connect(m_serialPort, &QSerialPort::readyRead, this, &LiveDataSource::readyRead);
 			connect(m_serialPort, static_cast<void (QSerialPort::*) (QSerialPort::SerialPortError)>(&QSerialPort::error), this, &LiveDataSource::serialPortError);
+#endif
 			break;
-		case MQTT:
+		case SourceType::MQTT:
 			break;
 		}
 		m_prepared = true;
@@ -530,10 +540,10 @@ void LiveDataSource::read() {
 	qint64 bytes = 0;
 
 	switch (m_sourceType) {
-	case FileOrPipe:
+	case SourceType::FileOrPipe:
 		DEBUG("Reading FileOrPipe. type = " << ENUM_TO_STRING(AbstractFileFilter, FileType, m_fileType));
 		switch (m_fileType) {
-		case AbstractFileFilter::Ascii:
+		case AbstractFileFilter::FileType::Ascii:
 			if (m_readingType == LiveDataSource::ReadingType::WholeFile) {
 				static_cast<AsciiFilter*>(m_filter)->readFromLiveDevice(*m_device, this, 0);
 			} else {
@@ -542,39 +552,39 @@ void LiveDataSource::read() {
 				DEBUG("Read " << bytes << " bytes, in total: " << m_bytesRead);
 			}
 			break;
-		case AbstractFileFilter::Binary:
+		case AbstractFileFilter::FileType::Binary:
 			//TODO: not implemented yet
 			// bytes = qSharedPointerCast<BinaryFilter>(m_filter)->readFromLiveDevice(*m_file, this, m_bytesRead);
 // 			m_bytesRead += bytes;
-		case AbstractFileFilter::ROOT:
-		case AbstractFileFilter::NgspiceRawAscii:
-		case AbstractFileFilter::NgspiceRawBinary:
+		case AbstractFileFilter::FileType::ROOT:
+		case AbstractFileFilter::FileType::NgspiceRawAscii:
+		case AbstractFileFilter::FileType::NgspiceRawBinary:
 			//only re-reading of the whole file is supported
 			m_filter->readDataFromFile(m_fileName, this);
 			break;
 		//TODO: other types not implemented yet
-		case AbstractFileFilter::Image:
-		case AbstractFileFilter::HDF5:
-		case AbstractFileFilter::NETCDF:
-		case AbstractFileFilter::FITS:
-		case AbstractFileFilter::JSON:
+		case AbstractFileFilter::FileType::Image:
+		case AbstractFileFilter::FileType::HDF5:
+		case AbstractFileFilter::FileType::NETCDF:
+		case AbstractFileFilter::FileType::FITS:
+		case AbstractFileFilter::FileType::JSON:
 			break;
 		}
 		break;
-	case NetworkTcpSocket:
+	case SourceType::NetworkTcpSocket:
 		DEBUG("reading from TCP socket. state before abort = " << m_tcpSocket->state());
 		m_tcpSocket->abort();
 		m_tcpSocket->connectToHost(m_host, m_port, QIODevice::ReadOnly);
 		DEBUG("reading from TCP socket. state after reconnect = " << m_tcpSocket->state());
 		break;
-	case NetworkUdpSocket:
+	case SourceType::NetworkUdpSocket:
 		DEBUG("	Reading from UDP socket. state = " << m_udpSocket->state());
 
 		// reading data here
-		if (m_fileType == AbstractFileFilter::Ascii)
+		if (m_fileType == AbstractFileFilter::FileType::Ascii)
 			static_cast<AsciiFilter*>(m_filter)->readFromLiveDeviceNotFile(*m_device, this);
 		break;
-	case LocalSocket:
+	case SourceType::LocalSocket:
 		DEBUG("	Reading from local socket. state before abort = " << m_localSocket->state());
 		if (m_localSocket->state() == QLocalSocket::ConnectingState)
 			m_localSocket->abort();
@@ -583,14 +593,16 @@ void LiveDataSource::read() {
 			m_localSocket->waitForReadyRead();
 		DEBUG("	Reading from local socket. state after reconnect = " << m_localSocket->state());
 		break;
-	case SerialPort:
+	case SourceType::SerialPort:
 		DEBUG("	Reading from serial port");
+#ifdef HAVE_QTSERIALPORT
 
 		// reading data here
-		if (m_fileType == AbstractFileFilter::Ascii)
+		if (m_fileType == AbstractFileFilter::FileType::Ascii)
 			static_cast<AsciiFilter*>(m_filter)->readFromLiveDeviceNotFile(*m_device, this);
+#endif
 		break;
-	case MQTT:
+	case SourceType::MQTT:
 		break;
 	}
 
@@ -606,16 +618,16 @@ void LiveDataSource::readyRead() {
 	DEBUG("LiveDataSource::readyRead() update type = " << ENUM_TO_STRING(LiveDataSource,UpdateType,m_updateType));
 	DEBUG("	REMAINING TIME = " << m_updateTimer->remainingTime());
 
-	if (m_fileType == AbstractFileFilter::Ascii)
+	if (m_fileType == AbstractFileFilter::FileType::Ascii)
 		static_cast<AsciiFilter*>(m_filter)->readFromLiveDeviceNotFile(*m_device, this);
 
 //TODO: not implemented yet
-//	else if (m_fileType == AbstractFileFilter::Binary)
+//	else if (m_fileType == AbstractFileFilter::FileType::Binary)
 //		dynamic_cast<BinaryFilter*>(m_filter)->readFromLiveDeviceNotFile(*m_device, this);
 
 	//since we won't have the timer to call read() where we create new connections
 	//for sequential devices in read() we just request data/connect to servers
-	if (m_updateType == NewData)
+	if (m_updateType == UpdateType::NewData)
 		read();
 }
 
@@ -664,6 +676,7 @@ void LiveDataSource::tcpSocketError(QAbstractSocket::SocketError socketError) {
 	}*/
 }
 
+#ifdef HAVE_QTSERIALPORT
 void LiveDataSource::serialPortError(QSerialPort::SerialPortError serialPortError) {
 	switch (serialPortError) {
 	case QSerialPort::DeviceNotFoundError:
@@ -704,6 +717,7 @@ void LiveDataSource::serialPortError(QSerialPort::SerialPortError serialPortErro
 		break;
 	}
 }
+#endif
 
 void LiveDataSource::plotData() {
 	auto* dlg = new PlotDataDialog(this);
@@ -725,8 +739,8 @@ void LiveDataSource::save(QXmlStreamWriter* writer) const {
 	writer->writeStartElement("general");
 
 	switch (m_sourceType) {
-	case FileOrPipe:
-		writer->writeAttribute("fileType", QString::number(m_fileType));
+	case SourceType::FileOrPipe:
+		writer->writeAttribute("fileType", QString::number(static_cast<int>(m_fileType)));
 		writer->writeAttribute("fileLinked", QString::number(m_fileLinked));
 		writer->writeAttribute("relativePath", QString::number(m_relativePath));
 		if (m_relativePath) {
@@ -738,32 +752,30 @@ void LiveDataSource::save(QXmlStreamWriter* writer) const {
 			writer->writeAttribute("fileName", m_fileName);
 
 		break;
-	case SerialPort:
+	case SourceType::SerialPort:
 		writer->writeAttribute("baudRate", QString::number(m_baudRate));
 		writer->writeAttribute("serialPortName", m_serialPortName);
 		break;
-	case NetworkTcpSocket:
-	case NetworkUdpSocket:
+	case SourceType::NetworkTcpSocket:
+	case SourceType::NetworkUdpSocket:
 		writer->writeAttribute("host", m_host);
 		writer->writeAttribute("port", QString::number(m_port));
 		break;
-	case LocalSocket:
+	case SourceType::LocalSocket:
 		break;
-	case MQTT:
-		break;
-	default:
+	case SourceType::MQTT:
 		break;
 	}
 
-	writer->writeAttribute("updateType", QString::number(m_updateType));
-	writer->writeAttribute("readingType", QString::number(m_readingType));
-	writer->writeAttribute("sourceType", QString::number(m_sourceType));
+	writer->writeAttribute("updateType", QString::number(static_cast<int>(m_updateType)));
+	writer->writeAttribute("readingType", QString::number(static_cast<int>(m_readingType)));
+	writer->writeAttribute("sourceType", QString::number(static_cast<int>(m_sourceType)));
 	writer->writeAttribute("keepNValues", QString::number(m_keepNValues));
 
-	if (m_updateType == TimeInterval)
+	if (m_updateType == UpdateType::TimeInterval)
 		writer->writeAttribute("updateInterval", QString::number(m_updateInterval));
 
-	if (m_readingType != TillEnd)
+	if (m_readingType != ReadingType::TillEnd)
 		writer->writeAttribute("sampleSize", QString::number(m_sampleSize));
 	writer->writeEndElement(); //general
 
@@ -772,7 +784,7 @@ void LiveDataSource::save(QXmlStreamWriter* writer) const {
 
 	//columns
 	if (!m_fileLinked) {
-		for (auto* col : children<Column>(IncludeHidden))
+		for (auto* col : children<Column>(ChildIndexFlag::IncludeHidden))
 			col->save(writer);
 	}
 
@@ -847,7 +859,7 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 			else
 				m_readingType =  static_cast<ReadingType>(str.toInt());
 
-			if (m_updateType == TimeInterval) {
+			if (m_updateType == UpdateType::TimeInterval) {
 				str = attribs.value("updateInterval").toString();
 				if (str.isEmpty())
 					reader->raiseWarning(attributeWarning.subs("updateInterval").toString());
@@ -855,7 +867,7 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 					m_updateInterval = str.toInt();
 			}
 
-			if (m_readingType != TillEnd) {
+			if (m_readingType != ReadingType::TillEnd) {
 				str = attribs.value("sampleSize").toString();
 				if (str.isEmpty())
 					reader->raiseWarning(attributeWarning.subs("sampleSize").toString());
@@ -864,7 +876,7 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 			}
 
 			switch (m_sourceType) {
-			case SerialPort:
+			case SourceType::SerialPort:
 				str = attribs.value("baudRate").toString();
 				if (str.isEmpty())
 					reader->raiseWarning(attributeWarning.subs("baudRate").toString());
@@ -878,8 +890,8 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 					m_serialPortName = str;
 
 				break;
-			case NetworkTcpSocket:
-			case NetworkUdpSocket:
+			case SourceType::NetworkTcpSocket:
+			case SourceType::NetworkUdpSocket:
 				str = attribs.value("host").toString();
 				if (str.isEmpty())
 					reader->raiseWarning(attributeWarning.subs("host").toString());
@@ -892,13 +904,11 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 				else
 					m_host = str;
 				break;
-			case MQTT:
+			case SourceType::MQTT:
 				break;
-			case FileOrPipe:
+			case SourceType::FileOrPipe:
 				break;
-			case LocalSocket:
-				break;
-			default:
+			case SourceType::LocalSocket:
 				break;
 			}
 
@@ -911,7 +921,7 @@ bool LiveDataSource::load(XmlStreamReader* reader, bool preview) {
 			if (!m_filter->load(reader))
 				return false;
 		} else if (reader->name() == "column") {
-			Column* column = new Column(QString(), AbstractColumn::Text);
+			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Text);
 			if (!column->load(reader, preview)) {
 				delete column;
 				setColumnCount(0);
