@@ -26,31 +26,12 @@ Copyright	: (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
 *                                                                         *
 ***************************************************************************/
 #include "backend/datasources/MQTTClient.h"
-
 #include "backend/datasources/MQTTSubscription.h"
 #include "backend/datasources/MQTTTopic.h"
-
 #include "backend/datasources/filters/AsciiFilter.h"
-#include "backend/datasources/filters/FITSFilter.h"
-#include "backend/datasources/filters/BinaryFilter.h"
-#include "backend/core/Project.h"
-#include "kdefrontend/spreadsheet/PlotDataDialog.h"
-
-#include "commonfrontend/spreadsheet/SpreadsheetView.h"
-
 #include "kdefrontend/datasources/MQTTErrorWidget.h"
 
-#include <QFileInfo>
-#include <QDateTime>
-#include <QProcess>
-#include <QDir>
-#include <QMenu>
 #include <QTimer>
-#include <QMessageBox>
-
-#include <QIcon>
-#include <QAction>
-#include <KLocalizedString>
 
 /*!
   \class MQTTClient
@@ -393,7 +374,7 @@ void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 			m_subscriptions.push_back(temp->topic().filter());
 			m_subscribedTopicNameQoS[temp->topic().filter()] = temp->qos();
 
-			MQTTSubscription* newSubscription = new MQTTSubscription(temp->topic().filter());
+			auto* newSubscription = new MQTTSubscription(temp->topic().filter());
 			newSubscription->setMQTTClient(this);
 
 			addChildFast(newSubscription);
@@ -467,9 +448,9 @@ void MQTTClient::removeMQTTSubscription(const QString& subscriptionName) {
 				m_MQTTSubscriptions.remove(i);
 				//Remove every topic of the subscription as well
 				QVector<MQTTTopic*> topics = removeSubscription->topics();
-				for (int j = 0; j < topics.size(); ++j) {
-					m_topicNames.removeAll(topics[j]->topicName());
-				}
+				for (const auto& topic : topics)
+					m_topicNames.removeAll(topic->topicName());
+
 				//Remove the MQTTSubscription
 				removeChild(removeSubscription);
 				break;
@@ -507,7 +488,7 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
 			m_subscriptions.push_back(temp->topic().filter());
 			m_subscribedTopicNameQoS[temp->topic().filter()] = temp->qos();
 
-			MQTTSubscription* newSubscription = new MQTTSubscription(temp->topic().filter());
+			auto* newSubscription = new MQTTSubscription(temp->topic().filter());
 			newSubscription->setMQTTClient(this);
 
 			addChildFast(newSubscription);
@@ -823,13 +804,8 @@ void MQTTClient::updateWillMessage() {
 		//If client is disconnected we can update the settings
 		else if (m_MQTTWill.enabled && (m_client->state() == QMqttClient::ClientState::Disconnected) && m_disconnectForWill) {
 			m_client->setWillQoS(m_MQTTWill.willQoS);
-// 			qDebug()<<"Will QoS" << m_MQTTWill.willQoS;
-
 			m_client->setWillRetain(m_MQTTWill.willRetain);
-// 			qDebug()<<"Will retain" << m_MQTTWill.willRetain;
-
 			m_client->setWillTopic(m_MQTTWill.willTopic);
-// 			qDebug()<<"Will Topic" << m_MQTTWill.willTopic;
 
 			//Set the will message according to m_willMessageType
 			switch (m_MQTTWill.willMessageType) {
@@ -838,21 +814,16 @@ void MQTTClient::updateWillMessage() {
 // 				qDebug()<<"Will own message" << m_MQTTWill.willOwnMessage;
 				break;
 			case WillMessageType::Statistics: {
-				const auto asciiFilter = willTopic->filter();
-
-				//If the topic's asciiFilter was found, get the needed statistics
-				if (asciiFilter != nullptr) {
-					//Statistics is only possible if the data stored in the MQTTTopic is of type integer or numeric
-					if ((asciiFilter->MQTTColumnMode() == AbstractColumn::ColumnMode::Integer) ||
-					        (asciiFilter->MQTTColumnMode() == AbstractColumn::ColumnMode::Numeric)) {
-						m_client->setWillMessage(asciiFilter->MQTTColumnStatistics(willTopic).toUtf8());
-					}
-					//Otherwise set empty message
-					else {
-						m_client->setWillMessage(QByteArray());
-					}
+				//Statistics is only possible if the data stored in the MQTTTopic is of type integer or numeric
+				//check the column mode of the last column in the topic for this.
+				//TODO: check this logic again - why last column only?
+				const auto* col = willTopic->child<Column>(willTopic->childCount<Column>() - 1);
+				auto mode = col->columnMode();
+				if (mode == AbstractColumn::ColumnMode::Integer || mode == AbstractColumn::ColumnMode::Numeric)
+					m_client->setWillMessage(this->statistics(willTopic).toUtf8());
+				else
+					m_client->setWillMessage(QByteArray()); //empty message
 // 					qDebug() << "Will statistics message: "<< QString(m_client->willMessage());
-				}
 				break;
 			}
 			case WillMessageType::LastMessage:
@@ -870,6 +841,73 @@ void MQTTClient::updateWillMessage() {
 	}
 }
 
+/*!
+ * \brief Returns the statistical data that is needed by the topic for its MQTTClient's will message
+ * \param topic
+ */
+QString MQTTClient::statistics(const MQTTTopic* topic) const {
+	const auto* col = topic->child<Column>(topic->childCount<Column>() - 1);
+	QString statistics;
+
+	QVector<bool> willStatistics = topic->mqttClient()->willStatistics();
+	//Add every statistical data to the string, the flag of which is set true
+	for (int i = 0; i <= willStatistics.size(); i++) {
+		if (willStatistics[i]) {
+			switch (static_cast<MQTTClient::WillStatisticsType>(i) ) {
+			case MQTTClient::WillStatisticsType::ArithmeticMean:
+				statistics += QLatin1String("Arithmetic mean: ") + QString::number(col->statistics().arithmeticMean) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::ContraharmonicMean:
+				statistics += QLatin1String("Contraharmonic mean: ") + QString::number(col->statistics().contraharmonicMean) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Entropy:
+				statistics += QLatin1String("Entropy: ") + QString::number(col->statistics().entropy) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::GeometricMean:
+				statistics += QLatin1String("Geometric mean: ") + QString::number(col->statistics().geometricMean) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::HarmonicMean:
+				statistics += QLatin1String("Harmonic mean: ") + QString::number(col->statistics().harmonicMean) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Kurtosis:
+				statistics += QLatin1String("Kurtosis: ") + QString::number(col->statistics().kurtosis) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Maximum:
+				statistics += QLatin1String("Maximum: ") + QString::number(col->statistics().maximum) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::MeanDeviation:
+				statistics += QLatin1String("Mean deviation: ") + QString::number(col->statistics().meanDeviation) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::MeanDeviationAroundMedian:
+				statistics += QLatin1String("Mean deviation around median: ") + QString::number(col->statistics().meanDeviationAroundMedian) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Median:
+				statistics += QLatin1String("Median: ") + QString::number(col->statistics().median) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::MedianDeviation:
+				statistics += QLatin1String("Median deviation: ") + QString::number(col->statistics().medianDeviation) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Minimum:
+				statistics += QLatin1String("Minimum: ") + QString::number(col->statistics().minimum) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Skewness:
+				statistics += QLatin1String("Skewness: ") + QString::number(col->statistics().skewness) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::StandardDeviation:
+				statistics += QLatin1String("Standard deviation: ") + QString::number(col->statistics().standardDeviation) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::Variance:
+				statistics += QLatin1String("Variance: ") + QString::number(col->statistics().variance) + "\n";
+				break;
+			case MQTTClient::WillStatisticsType::NoStatistics:
+			default:
+				break;
+			}
+		}
+	}
+	return statistics;
+}
+
 /*!
  * \brief Returns the MQTTClient's will update type
  */
@@ -998,7 +1036,7 @@ void MQTTClient::onMQTTConnect() {
 					if (!m_loaded) {
 						m_subscriptions.push_back(temp->topic().filter());
 
-						MQTTSubscription* newSubscription = new MQTTSubscription(temp->topic().filter());
+						auto* newSubscription = new MQTTSubscription(temp->topic().filter());
 						newSubscription->setMQTTClient(this);
 
 						addChildFast(newSubscription);
@@ -1065,7 +1103,7 @@ void MQTTClient::MQTTSubscriptionMessageReceived(const QMqttMessage& msg) {
  */
 void MQTTClient::MQTTErrorChanged(QMqttClient::ClientError clientError) {
 	if (clientError != QMqttClient::ClientError::NoError) {
-		MQTTErrorWidget* errorWidget = new MQTTErrorWidget(clientError, this);
+		auto* errorWidget = new MQTTErrorWidget(clientError, this);
 		errorWidget->show();
 	}
 }
@@ -1335,7 +1373,7 @@ bool MQTTClient::load(XmlStreamReader* reader, bool preview) {
 			if (!m_filter->load(reader))
 				return false;
 		} else if (reader->name() == "MQTTSubscription") {
-			MQTTSubscription* subscription = new MQTTSubscription(QString());
+			auto* subscription = new MQTTSubscription(QString());
 			subscription->setMQTTClient(this);
 			m_MQTTSubscriptions.push_back(subscription);
 			connect(subscription, &MQTTSubscription::loaded, this, &MQTTClient::subscriptionLoaded);
@@ -1352,4 +1390,3 @@ bool MQTTClient::load(XmlStreamReader* reader, bool preview) {
 
 	return !reader->hasError();
 }
-
