@@ -58,12 +58,12 @@ public:
 
 	// read data from any device
 	void readDataFromDevice(QIODevice& device, AbstractDataSource*,
-	                        AbstractFileFilter::ImportMode = AbstractFileFilter::Replace, int lines = -1);
+	                        AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace, int lines = -1);
 	void readFromLiveDeviceNotFile(QIODevice& device, AbstractDataSource*dataSource);
 	qint64 readFromLiveDevice(QIODevice& device, AbstractDataSource*, qint64 from = -1);
 	// overloaded function to read from file
 	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr,
-	                      AbstractFileFilter::ImportMode = AbstractFileFilter::Replace) override;
+	                      AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace) override;
 	void write(const QString& fileName, AbstractDataSource*) override;
 
 	QVector<QStringList> preview(const QString& fileName, int lines);
@@ -74,8 +74,6 @@ public:
 
 #ifdef HAVE_MQTT
 	QVector<QStringList> preview(const QString& message);
-	QString MQTTColumnStatistics(const MQTTTopic*) const;
-	AbstractColumn::ColumnMode MQTTColumnMode() const;
 	void readMQTTTopic(const QString& message, AbstractDataSource*);
 	void setPreparedForMQTT(bool, MQTTTopic*, const QString&);
 #endif
@@ -108,6 +106,7 @@ public:
 	bool createTimestampEnabled() const;
 
 	void setVectorNames(const QString&);
+	void setVectorNames(const QStringList&);
 	QStringList vectorNames() const;
 	QVector<AbstractColumn::ColumnMode> columnModes();
 
