@@ -37,7 +37,7 @@ class ImageFilter : public AbstractFileFilter {
 	Q_ENUMS(ImportFormat)
 
 public:
-	enum ImportFormat {MATRIX, XYZ, XYRGB};
+	enum class ImportFormat {MATRIX, XYZ, XYRGB};
 
 	ImageFilter();
 	~ImageFilter() override;
@@ -45,7 +45,7 @@ public:
 	static QStringList importFormats();
 	static QString fileInfoString(const QString&);
 
-	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::Replace) override;
+	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace) override;
 	void write(const QString& fileName, AbstractDataSource*) override;
 
 	void loadFilterSettings(const QString&) override;
