@@ -2,6 +2,7 @@
  * The MIT License (MIT)
  *
  * Copyright (c) 2011 SCHUTZ Sacha
+ * Copyright (C) 2020 Alexander Semke (alexander.semke@web.de)
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,25 +25,27 @@
 
 #include "QJsonModel.h"
 
-#include <QApplication>
-#include <QDebug>
 #include <QFile>
 #include <QMessageBox>
-#include <QPalette>
 #include <KLocalizedString>
+#include "backend/lib/trace.h"
 
 QJsonTreeItem::QJsonTreeItem(QJsonTreeItem* parent) : mParent(parent) {}
 
 QJsonTreeItem::~QJsonTreeItem() {
-	qDeleteAll(mChilds);
+	qDeleteAll(mChildren);
 }
 
 void QJsonTreeItem::appendChild(QJsonTreeItem* item) {
-	mChilds.append(item);
+	mChildren.append(item);
+}
+
+void QJsonTreeItem::reserve(int size) {
+	mChildren.reserve(size);
 }
 
 QJsonTreeItem* QJsonTreeItem::child(int row) {
-	return mChilds.value(row);
+	return mChildren.value(row);
 }
 
 QJsonTreeItem* QJsonTreeItem::parent() {
@@ -50,12 +53,12 @@ QJsonTreeItem* QJsonTreeItem::parent() {
 }
 
 int QJsonTreeItem::childCount() const {
-	return mChilds.count();
+	return mChildren.count();
 }
 
 int QJsonTreeItem::row() const {
 	if (mParent)
-		return mParent->mChilds.indexOf(const_cast<QJsonTreeItem*>(this));
+		return mParent->mChildren.indexOf(const_cast<QJsonTreeItem*>(this));
 
 	return 0;
 }
@@ -72,11 +75,15 @@ void QJsonTreeItem::setType(const QJsonValue::Type type) {
 	mType = type;
 }
 
-QString QJsonTreeItem::key() const {
+void QJsonTreeItem::setSize(int size) {
+	mSize = size;
+}
+
+const QString& QJsonTreeItem::key() const {
 	return mKey;
 }
 
-QString QJsonTreeItem::value() const {
+const QString& QJsonTreeItem::value() const {
 	return mValue;
 }
 
@@ -84,33 +91,46 @@ QJsonValue::Type QJsonTreeItem::type() const {
 	return mType;
 }
 
+int QJsonTreeItem::size() const {
+	return mSize;
+}
+
 QJsonTreeItem* QJsonTreeItem::load(const QJsonValue& value, QJsonTreeItem* parent) {
 	auto* rootItem = new QJsonTreeItem(parent);
-	rootItem->setKey("root");
+// 	rootItem->setKey("root");
 
 	if (value.isObject()) {
+		const auto& object = value.toObject();
 
-		//Get all QJsonValue childs
-		for (QString key : value.toObject().keys()) {
-			QJsonValue v = value.toObject().value(key);
+		//determine the size
+		rootItem->setSize(QJsonDocument(object).toJson(QJsonDocument::Compact).size());
+
+		//read all children
+		for (const QString& key : object.keys()) {
+			const QJsonValue& v = object.value(key);
 			QJsonTreeItem* child = load(v,rootItem);
 			child->setKey(key);
 			child->setType(v.type());
 			rootItem->appendChild(child);
 		}
 	} else if (value.isArray()) {
-		//Get all QJsonValue childs
+		const auto& array = value.toArray();
+		rootItem->setSize(QJsonDocument(array).toJson(QJsonDocument::Compact).size());
+
 		int index = 0;
-		for (QJsonValue v : value.toArray()) {
-			QJsonTreeItem* child = load(v,rootItem);
+		rootItem->reserve(array.count());
+		for (const QJsonValue& v : array) {
+			QJsonTreeItem* child = load(v, rootItem);
 			child->setKey(QString::number(index));
 			child->setType(v.type());
 			rootItem->appendChild(child);
 			++index;
 		}
 	} else {
-		rootItem->setValue(value.toVariant().toString());
+		const QString& str = value.toVariant().toString();
+		rootItem->setValue(str);
 		rootItem->setType(value.type());
+		rootItem->setSize(str.length());
 	}
 
 	return rootItem;
@@ -123,8 +143,25 @@ QJsonModel::QJsonModel(QObject* parent) : QAbstractItemModel(parent),
 	mRootItem(new QJsonTreeItem(mHeadItem)) {
 
 	mHeadItem->appendChild(mRootItem);
-	mHeaders.append("key");
-	mHeaders.append("value");
+	mHeaders.append(i18n("Key"));
+	mHeaders.append(i18n("Value"));
+	mHeaders.append(i18n("Size in Bytes"));
+
+	//icons
+	mObjectIcon = QIcon::fromTheme(QLatin1String("labplot-json-object"));
+	mArrayIcon = QIcon::fromTheme(QLatin1String("labplot-json-array"));
+
+	//dark theme is used -> invert the icons which use black colors
+	if (qApp->palette().color(QPalette::Base).lightness() < 128) {
+		//TODO: use different(standard?) pixel size?
+		QImage image = mObjectIcon.pixmap(64, 64).toImage();
+		image.invertPixels();
+		mObjectIcon = QIcon(QPixmap::fromImage(image));
+
+		image = mArrayIcon.pixmap(64, 64).toImage();
+		image.invertPixels();
+		mArrayIcon = QIcon(QPixmap::fromImage(image));
+	}
 }
 
 QJsonModel::~QJsonModel() {
@@ -159,7 +196,8 @@ bool QJsonModel::load(QIODevice* device) {
 
 bool QJsonModel::loadJson(const QByteArray& json) {
 	QJsonParseError error;
-	QJsonDocument doc = QJsonDocument::fromJson(json, &error);
+
+	const QJsonDocument& doc = QJsonDocument::fromJson(json, &error);
 	if (error.error == QJsonParseError::NoError)
 		return loadJson(doc);
 	else {
@@ -171,6 +209,7 @@ bool QJsonModel::loadJson(const QByteArray& json) {
 }
 
 bool QJsonModel::loadJson(const QJsonDocument& jdoc) {
+	PERFTRACE("load json document into the model");
 	if (!jdoc.isNull()) {
 		beginResetModel();
 		delete mHeadItem;
@@ -178,7 +217,10 @@ bool QJsonModel::loadJson(const QJsonDocument& jdoc) {
 		mHeadItem = new QJsonTreeItem;
 
 		if (jdoc.isArray()) {
+			{
+			PERFTRACE("load json tree items");
 			mRootItem = QJsonTreeItem::load(QJsonValue(jdoc.array()), mHeadItem);
+			}
 			mRootItem->setType(QJsonValue::Array);
 
 		} else {
@@ -203,30 +245,29 @@ QVariant QJsonModel::data(const QModelIndex& index, int role) const {
 
 	if (role == Qt::DisplayRole) {
 		if (index.column() == 0)
-			return QString("%1").arg(item->key());
-
-		if (index.column() == 1)
-			return QString("%1").arg(item->value());
+			return item->key();
+		else if (index.column() == 1) {
+			//in case the value is very long, cut it so the preview tree tree view doesnt' explode
+			if (item->value().length() > 200)
+				return item->value().left(200) + QLatin1String(" ...");
+			else
+				return item->value();
+		} else {
+			if (item->size() != 0)
+				return QString::number(item->size());
+			else
+				return QString();
+		}
 	} else if (Qt::EditRole == role) {
 		if (index.column() == 1)
-			return QString("%1").arg(item->value());
+			return item->value();
 	} else if (role == Qt::DecorationRole) {
 		if (index.column() == 0) {
-			QIcon icon;
 			if (item->type() == QJsonValue::Array)
-				icon = QIcon::fromTheme("labplot-json-array");
+				return mArrayIcon;
 			else if (item->type() == QJsonValue::Object)
-				icon = QIcon::fromTheme("labplot-json-object");
-
-			if (qApp->palette().color(QPalette::Base).lightness() < 128) {
-				//dark theme is used -> invert the icons which use black colors
-				QImage image = icon.pixmap(64, 64).toImage(); //TODO: use different(standard?) pixel size?
-				image.invertPixels();
-				icon = QIcon(QPixmap::fromImage(image));
-			}
-			return icon;
+				return mObjectIcon;
 		}
-		return QIcon();
 	}
 
 	return QVariant();
@@ -246,10 +287,7 @@ bool QJsonModel::setData(const QModelIndex& index, const QVariant& value, int ro
 }
 
 QVariant QJsonModel::headerData(int section, Qt::Orientation orientation, int role) const {
-	if (role != Qt::DisplayRole)
-		return QVariant();
-
-	if (orientation == Qt::Horizontal)
+	if (role == Qt::DisplayRole && orientation == Qt::Horizontal)
 		return mHeaders.value(section);
 
 	return QVariant();
@@ -301,7 +339,7 @@ int QJsonModel::rowCount(const QModelIndex& parent) const {
 
 int QJsonModel::columnCount(const QModelIndex& parent) const {
 	Q_UNUSED(parent)
-	return 2;
+	return 3;
 }
 
 Qt::ItemFlags QJsonModel::flags(const QModelIndex& index) const {
@@ -310,7 +348,7 @@ Qt::ItemFlags QJsonModel::flags(const QModelIndex& index) const {
 	else
 		return QAbstractItemModel::flags(index);
 }
-
+/*
 QJsonDocument QJsonModel::json() const {
 	auto v = genJson(mRootItem);
 	QJsonDocument doc;
@@ -322,8 +360,8 @@ QJsonDocument QJsonModel::json() const {
 
 	return doc;
 }
-
-QJsonValue  QJsonModel::genJson(QJsonTreeItem* item) const {
+*/
+QJsonValue QJsonModel::genJson(QJsonTreeItem* item) const {
 	auto type = item->type();
 	const int nchild = item->childCount();
 
