@@ -79,7 +79,7 @@ private:
 	PlotArea::BackgroundColorStyle backgroundColorStyle(Origin::ColorGradientDirection) const;
 
 	QList<QPair<QString, QString>> charReplacementList() const;
-	QString replaceSpecialChars(QString text) const;
+	QString replaceSpecialChars(const QString&) const;
 
 	OriginFile* m_originFile{nullptr};
 	QStringList m_spreadNameList;
@@ -89,6 +89,8 @@ private:
 	QStringList m_noteNameList;
 	bool m_importUnusedObjects{false};
 
+	friend class ProjectImportTest;
+
 protected:
 	bool load(Project*, bool) override;
 };
