@@ -43,12 +43,12 @@ class Matrix : public AbstractDataSource {
 	Q_ENUMS(HeaderFormat)
 
 public:
-	enum HeaderFormat {HeaderRowsColumns, HeaderValues, HeaderRowsColumnsValues};
+	enum class HeaderFormat {HeaderRowsColumns, HeaderValues, HeaderRowsColumnsValues};
 
 	explicit Matrix(const QString& name, bool loading = false,
-		   const AbstractColumn::ColumnMode = AbstractColumn::Numeric);
+		   const AbstractColumn::ColumnMode = AbstractColumn::ColumnMode::Numeric);
 	Matrix(int rows, int cols, const QString& name,
-		   const AbstractColumn::ColumnMode = AbstractColumn::Numeric);
+		   const AbstractColumn::ColumnMode = AbstractColumn::ColumnMode::Numeric);
 	~Matrix() override;
 
 	QIcon icon() const override;
@@ -110,9 +110,6 @@ public:
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
 
-	void registerShortcuts() override;
-	void unregisterShortcuts() override;
-
 	int prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode,
 		int rows, int cols, QStringList colNameList, QVector<AbstractColumn::ColumnMode>) override;
 	void finalizeImport(int columnOffset, int startColumn, int endColumn,
