@@ -54,6 +54,9 @@ public:
 	void setModel(SpreadsheetModel*);
 	SpreadsheetModel* model();
 
+	void updateHorizontalHeader();
+	void updateLocale();
+
 	int columnCount() const;
 	int columnCount(AbstractColumn::PlotDesignation) const;
 	Column* column(int index) const;
@@ -80,9 +83,6 @@ public:
 	void emitRowCountChanged() { emit rowCountChanged(rowCount()); }
 	void emitColumnCountChanged() { emit columnCountChanged(columnCount()); }
 
-	void registerShortcuts() override;
-	void unregisterShortcuts() override;
-
 	//data import
 	int prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode,
 		int rows, int cols, QStringList colNameList, QVector<AbstractColumn::ColumnMode>) override;
@@ -104,7 +104,7 @@ public slots:
 	void clearMasks();
 
 	void moveColumn(int from, int to);
-	void sortColumns(Column* leading, QVector<Column*>, bool ascending);
+	void sortColumns(Column* leading, const QVector<Column*>&, bool ascending);
 
 private:
 	void init();
