@@ -36,7 +36,6 @@
 #include <QIcon>
 
 #include <KLocalizedString>
-#include <cmath>
 
 /*!
 	\class SpreadsheetModel
@@ -121,6 +120,16 @@ QVariant SpreadsheetModel::data(const QModelIndex& index, int role) const {
 				return QVariant(i18n("invalid cell (ignored in all operations)"));
 		}
 	case Qt::EditRole:
+		if (col_ptr->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			double value = col_ptr->valueAt(row);
+			if (std::isnan(value))
+				return QVariant("-");
+			else if (std::isinf(value))
+				return QVariant(QLatin1String("inf"));
+			else
+				return QVariant(col_ptr->asStringColumn()->textAt(row));
+		}
+
 		if (col_ptr->isValid(row))
 			return QVariant(col_ptr->asStringColumn()->textAt(row));
 
@@ -130,6 +139,16 @@ QVariant SpreadsheetModel::data(const QModelIndex& index, int role) const {
 
 		break;
 	case Qt::DisplayRole:
+		if (col_ptr->columnMode() == AbstractColumn::ColumnMode::Numeric) {
+			double value = col_ptr->valueAt(row);
+			if (std::isnan(value))
+				return QVariant("-");
+			else if (std::isinf(value))
+				return QVariant(UTF8_QSTRING("∞"));
+			else
+				return QVariant(col_ptr->asStringColumn()->textAt(row));
+		}
+
 		if (!col_ptr->isValid(row))
 			return QVariant("-");
 
@@ -139,12 +158,12 @@ QVariant SpreadsheetModel::data(const QModelIndex& index, int role) const {
 
 		return QVariant(col_ptr->asStringColumn()->textAt(row));
 	case Qt::ForegroundRole:
-		if (!col_ptr->isValid(index.row()))
+		if (!col_ptr->isValid(row))
 			return QVariant(QBrush(Qt::red));
 		break;
-	case MaskingRole:
+	case static_cast<int>(CustomDataRole::MaskingRole):
 		return QVariant(col_ptr->isMasked(row));
-	case FormulaRole:
+	case static_cast<int>(CustomDataRole::FormulaRole):
 		return QVariant(col_ptr->formula(row));
 // 	case Qt::DecorationRole:
 // 		if (m_formula_mode)
@@ -168,7 +187,7 @@ QVariant SpreadsheetModel::headerData(int section, Qt::Orientation orientation,
 			return m_horizontal_header_data.at(section);
 		case Qt::DecorationRole:
 			return m_spreadsheet->child<Column>(section)->icon();
-		case SpreadsheetModel::CommentRole:
+		case static_cast<int>(CustomDataRole::CommentRole):
 			return m_spreadsheet->child<Column>(section)->comment();
 		}
 		break;
@@ -200,13 +219,15 @@ bool SpreadsheetModel::setData(const QModelIndex& index, const QVariant& value,
 	int row = index.row();
 	Column* column = m_spreadsheet->column(index.column());
 
+	SET_NUMBER_LOCALE
+	//DEBUG("SpreadsheetModel::setData() value = " << STDSTRING(value.toString()))
+
 	//don't do anything if no new value was provided
-	if (column->columnMode() == AbstractColumn::Numeric) {
+	if (column->columnMode() == AbstractColumn::ColumnMode::Numeric) {
 		bool ok;
-		QLocale locale;
-		double new_value = locale.toDouble(value.toString(), &ok);
+		double new_value = numberLocale.toDouble(value.toString(), &ok);
 		if (ok) {
-			if (column->valueAt(row) == new_value )
+			if (column->valueAt(row) == new_value)
 				return false;
 		} else {
 			//an empty (non-numeric value) was provided
@@ -219,24 +240,20 @@ bool SpreadsheetModel::setData(const QModelIndex& index, const QVariant& value,
 	}
 
 	switch (role) {
-	case Qt::EditRole: {
+	case Qt::EditRole:
 		// remark: the validity of the cell is determined by the input filter
 		if (m_formula_mode)
 			column->setFormula(row, value.toString());
 		else
 			column->asStringColumn()->setTextAt(row, value.toString());
-
 		return true;
-	}
-	case MaskingRole: {
+	case static_cast<int>(CustomDataRole::MaskingRole):
 		m_spreadsheet->column(index.column())->setMasked(row, value.toBool());
 		return true;
-	}
-	case FormulaRole: {
+	case static_cast<int>(CustomDataRole::FormulaRole):
 		m_spreadsheet->column(index.column())->setFormula(row, value.toString());
 		return true;
 	}
-	}
 
 	return false;
 }
@@ -258,8 +275,7 @@ bool SpreadsheetModel::hasChildren(const QModelIndex& parent) const {
 
 void SpreadsheetModel::handleAspectAdded(const AbstractAspect* aspect) {
 	const Column* col = dynamic_cast<const Column*>(aspect);
-
-	if (!col || aspect->parentAspect() != static_cast<AbstractAspect*>(m_spreadsheet))
+	if (!col || aspect->parentAspect() != m_spreadsheet)
 		return;
 
 	connect(col, &Column::plotDesignationChanged, this, &SpreadsheetModel::handlePlotDesignationChange);
@@ -273,16 +289,15 @@ void SpreadsheetModel::handleAspectAdded(const AbstractAspect* aspect) {
 	connect(col->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &SpreadsheetModel::handleDigitsChange);
 
 	if (!m_suppressSignals) {
+		beginResetModel();
 		updateVerticalHeader();
 		updateHorizontalHeader();
-
-		beginResetModel();
-		//TODO: breaks undo/redo
-		//endInsertColumns();
 		endResetModel();
 
+		int index = m_spreadsheet->indexOfChild<AbstractAspect>(aspect);
 		m_columnCount = m_spreadsheet->columnCount();
 		m_spreadsheet->emitColumnCountChanged();
+		emit headerDataChanged(Qt::Horizontal, index, m_columnCount - 1);
 	}
 }
 
@@ -291,8 +306,7 @@ void SpreadsheetModel::handleAspectAboutToBeRemoved(const AbstractAspect* aspect
 		return;
 
 	const Column* col = dynamic_cast<const Column*>(aspect);
-
-	if (!col || aspect->parentAspect() != static_cast<AbstractAspect*>(m_spreadsheet))
+	if (!col || aspect->parentAspect() != m_spreadsheet)
 		return;
 
 	beginResetModel();
@@ -302,16 +316,16 @@ void SpreadsheetModel::handleAspectAboutToBeRemoved(const AbstractAspect* aspect
 void SpreadsheetModel::handleAspectRemoved(const AbstractAspect* parent, const AbstractAspect* before, const AbstractAspect* child) {
 	Q_UNUSED(before)
 	const Column* col = dynamic_cast<const Column*>(child);
-
-	if (!col || parent != static_cast<AbstractAspect*>(m_spreadsheet))
+	if (!col || parent != m_spreadsheet)
 		return;
 
 	updateVerticalHeader();
 	updateHorizontalHeader();
-	endResetModel();
 
 	m_columnCount = m_spreadsheet->columnCount();
 	m_spreadsheet->emitColumnCountChanged();
+
+	endResetModel();
 }
 
 void SpreadsheetModel::handleDescriptionChange(const AbstractAspect* aspect) {
@@ -319,13 +333,14 @@ void SpreadsheetModel::handleDescriptionChange(const AbstractAspect* aspect) {
 		return;
 
 	const Column* col = dynamic_cast<const Column*>(aspect);
-
-	if (!col || aspect->parentAspect() != static_cast<AbstractAspect*>(m_spreadsheet))
+	if (!col || aspect->parentAspect() != m_spreadsheet)
 		return;
 
-	updateHorizontalHeader();
-	int index = m_spreadsheet->indexOfChild<Column>(col);
-	emit headerDataChanged(Qt::Horizontal, index, index);
+	if (!m_suppressSignals) {
+		updateHorizontalHeader();
+		int index = m_spreadsheet->indexOfChild<Column>(col);
+		emit headerDataChanged(Qt::Horizontal, index, index);
+	}
 }
 
 void SpreadsheetModel::handleModeChange(const AbstractColumn* col) {
@@ -339,7 +354,7 @@ void SpreadsheetModel::handleModeChange(const AbstractColumn* col) {
 
 	//output filter was changed after the mode change, update the signal-slot connection
 	disconnect(nullptr, SIGNAL(digitsChanged()), this, SLOT(handledigitsChange()));
-	connect(dynamic_cast<const Column*>(col)->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &SpreadsheetModel::handleDigitsChange);
+	connect(static_cast<const Column*>(col)->outputFilter(), &AbstractSimpleFilter::digitsChanged, this, &SpreadsheetModel::handleDigitsChange);
 }
 
 void SpreadsheetModel::handleDigitsChange() {
@@ -425,64 +440,74 @@ void SpreadsheetModel::updateHorizontalHeader() {
 	while (m_horizontal_header_data.size() > column_count)
 		m_horizontal_header_data.removeLast();
 
+	KConfigGroup group = KSharedConfig::openConfig()->group("Settings_Spreadsheet");
+	bool showColumnType = group.readEntry(QLatin1String("ShowColumnType"), true);
+	bool showPlotDesignation = group.readEntry(QLatin1String("ShowPlotDesignation"), true);
+
 	for (int i = 0; i < column_count; i++) {
 		Column* col = m_spreadsheet->child<Column>(i);
+		QString header = col->name();
 
-		QString type;
-		switch (col->columnMode()) {
-		case AbstractColumn::Numeric:
-			type = QLatin1String(" {") + i18n("Numeric") + QLatin1Char('}');
-			break;
-		case AbstractColumn::Integer:
-			type = QLatin1String(" {") + i18n("Integer") + QLatin1Char('}');
-			break;
-		case AbstractColumn::Text:
-			type = QLatin1String(" {") + i18n("Text") + QLatin1Char('}');
-			break;
-		case AbstractColumn::Month:
-			type = QLatin1String(" {") + i18n("Month Names") + QLatin1Char('}');
-			break;
-		case AbstractColumn::Day:
-			type = QLatin1String(" {") + i18n("Day Names") + QLatin1Char('}');
-			break;
-		case AbstractColumn::DateTime:
-			type = QLatin1String(" {") + i18n("Date and Time") + QLatin1Char('}');
-			break;
+		if (showColumnType) {
+			switch (col->columnMode()) {
+			case AbstractColumn::ColumnMode::Numeric:
+				header += QLatin1String(" {") + i18n("Numeric") + QLatin1Char('}');
+				break;
+			case AbstractColumn::ColumnMode::Integer:
+				header += QLatin1String(" {") + i18n("Integer") + QLatin1Char('}');
+				break;
+			case AbstractColumn::ColumnMode::BigInt:
+				header += QLatin1String(" {") + i18n("Big Integer") + QLatin1Char('}');
+				break;
+			case AbstractColumn::ColumnMode::Text:
+				header += QLatin1String(" {") + i18n("Text") + QLatin1Char('}');
+				break;
+			case AbstractColumn::ColumnMode::Month:
+				header += QLatin1String(" {") + i18n("Month Names") + QLatin1Char('}');
+				break;
+			case AbstractColumn::ColumnMode::Day:
+				header += QLatin1String(" {") + i18n("Day Names") + QLatin1Char('}');
+				break;
+			case AbstractColumn::ColumnMode::DateTime:
+				header += QLatin1String(" {") + i18n("Date and Time") + QLatin1Char('}');
+				break;
+			}
 		}
 
-		QString designation;
-		switch (col->plotDesignation()) {
-		case AbstractColumn::NoDesignation:
-			break;
-		case AbstractColumn::X:
-			designation = QLatin1String(" [X]");
-			break;
-		case AbstractColumn::Y:
-			designation = QLatin1String(" [Y]");
-			break;
-		case AbstractColumn::Z:
-			designation = QLatin1String(" [Z]");
-			break;
-		case AbstractColumn::XError:
-			designation = QLatin1String(" [") + i18n("X-error") + QLatin1Char(']');
-			break;
-		case AbstractColumn::XErrorPlus:
-			designation = QLatin1String(" [") + i18n("X-error +") + QLatin1Char(']');
-			break;
-		case AbstractColumn::XErrorMinus:
-			designation = QLatin1String(" [") + i18n("X-error -") + QLatin1Char(']');
-			break;
-		case AbstractColumn::YError:
-			designation = QLatin1String(" [") + i18n("Y-error") + QLatin1Char(']');
-			break;
-		case AbstractColumn::YErrorPlus:
-			designation = QLatin1String(" [") + i18n("Y-error +") + QLatin1Char(']');
-			break;
-		case AbstractColumn::YErrorMinus:
-			designation = QLatin1String(" [") + i18n("Y-error -") + QLatin1Char(']');
-			break;
+		if (showPlotDesignation) {
+			switch (col->plotDesignation()) {
+			case AbstractColumn::PlotDesignation::NoDesignation:
+				break;
+			case AbstractColumn::PlotDesignation::X:
+				header += QLatin1String(" [X]");
+				break;
+			case AbstractColumn::PlotDesignation::Y:
+				header += QLatin1String(" [Y]");
+				break;
+			case AbstractColumn::PlotDesignation::Z:
+				header += QLatin1String(" [Z]");
+				break;
+			case AbstractColumn::PlotDesignation::XError:
+				header += QLatin1String(" [") + i18n("X-error") + QLatin1Char(']');
+				break;
+			case AbstractColumn::PlotDesignation::XErrorPlus:
+				header += QLatin1String(" [") + i18n("X-error +") + QLatin1Char(']');
+				break;
+			case AbstractColumn::PlotDesignation::XErrorMinus:
+				header += QLatin1String(" [") + i18n("X-error -") + QLatin1Char(']');
+				break;
+			case AbstractColumn::PlotDesignation::YError:
+				header += QLatin1String(" [") + i18n("Y-error") + QLatin1Char(']');
+				break;
+			case AbstractColumn::PlotDesignation::YErrorPlus:
+				header += QLatin1String(" [") + i18n("Y-error +") + QLatin1Char(']');
+				break;
+			case AbstractColumn::PlotDesignation::YErrorMinus:
+				header += QLatin1String(" [") + i18n("Y-error -") + QLatin1Char(']');
+				break;
+			}
 		}
-		m_horizontal_header_data.replace(i, col->name() + type + designation);
+		m_horizontal_header_data.replace(i, header);
 	}
 }
 
