@@ -42,10 +42,10 @@ public:
 	explicit PlotArea(const QString& name, CartesianPlot *parent);
 	~PlotArea() override;
 
-	enum BackgroundType {Color, Image, Pattern};
-	enum BackgroundColorStyle {SingleColor, HorizontalLinearGradient, VerticalLinearGradient,
+	enum class BackgroundType {Color, Image, Pattern};
+	enum class BackgroundColorStyle {SingleColor, HorizontalLinearGradient, VerticalLinearGradient,
 			TopLeftDiagonalLinearGradient, BottomLeftDiagonalLinearGradient, RadialGradient};
-	enum BackgroundImageStyle {ScaledCropped, Scaled, ScaledAspectRatio, Centered, Tiled, CenterTiled};
+	enum class BackgroundImageStyle {ScaledCropped, Scaled, ScaledAspectRatio, Centered, Tiled, CenterTiled};
 
 	QGraphicsItem* graphicsItem() const override;
 	void setVisible(bool on) override;
