@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : A xy-curve
     --------------------------------------------------------------------
-    Copyright            : (C) 2010-2015 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2010-2020 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2013 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -31,6 +31,7 @@
 #define XYCURVE_H
 
 #include "backend/worksheet/WorksheetElement.h"
+#include "backend/worksheet/plots/cartesian/Curve.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
 #include "backend/worksheet/plots/PlotArea.h"
 #include "backend/lib/macros.h"
@@ -42,7 +43,7 @@
 
 class XYCurvePrivate;
 
-class XYCurve: public WorksheetElement {
+class XYCurve: public WorksheetElement, public Curve {
 	Q_OBJECT
 
 public:
@@ -53,15 +54,15 @@ public:
 	friend class XYCurveSetYErrorPlusColumnCmd;
 	friend class XYCurveSetYErrorMinusColumnCmd;
 	friend class XYCurveSetValuesColumnCmd;
-	enum LineType {NoLine, Line, StartHorizontal, StartVertical, MidpointHorizontal, MidpointVertical, Segments2, Segments3,
+	enum class LineType {NoLine, Line, StartHorizontal, StartVertical, MidpointHorizontal, MidpointVertical, Segments2, Segments3,
 	               SplineCubicNatural, SplineCubicPeriodic, SplineAkimaNatural, SplineAkimaPeriodic
 	              };
-	enum DropLineType {NoDropLine, DropLineX, DropLineY, DropLineXY, DropLineXZeroBaseline, DropLineXMinBaseline, DropLineXMaxBaseline};
-	enum ValuesType {NoValues, ValuesX, ValuesY, ValuesXY, ValuesXYBracketed, ValuesCustomColumn};
-	enum ValuesPosition {ValuesAbove, ValuesUnder, ValuesLeft, ValuesRight};
-	enum ErrorType {NoError, SymmetricError, AsymmetricError};
-	enum FillingPosition {NoFilling, FillingAbove, FillingBelow, FillingZeroBaseline, FillingLeft, FillingRight};
-	enum ErrorBarsType {ErrorBarsSimple, ErrorBarsWithEnds};
+	enum class DropLineType {NoDropLine, X, Y, XY, XZeroBaseline, XMinBaseline, XMaxBaseline};
+	enum class ValuesType {NoValues, X, Y, XY, XYBracketed, CustomColumn};
+	enum class ValuesPosition {Above, Under, Left, Right};
+	enum class ErrorType {NoError, Symmetric, Asymmetric};
+	enum class FillingPosition {NoFilling, Above, Below, ZeroBaseline, Left, Right};
+	enum class ErrorBarsType {Simple, WithEnds};
 
 	explicit XYCurve(const QString &name, AspectType type = AspectType::XYCurve);
 	~XYCurve() override;
@@ -79,8 +80,9 @@ public:
 	bool minMax(const AbstractColumn *column1, const AbstractColumn *column2, const ErrorType errorType, const AbstractColumn *errorPlusColumn, const AbstractColumn *errorMinusColumn, int indexMin, int indexMax, double& yMin, double& yMax, bool includeErrorBars) const;
 	bool minMaxX(int indexMin, int indexMax, double& yMin, double& yMax, bool includeErrorBars = true) const;
 	bool minMaxY(int indexMin, int indexMax, double& yMin, double& yMax, bool includeErrorBars = true) const;
-	bool activateCurve(QPointF mouseScenePos, double maxDist = -1);
-	void setHover(bool on);
+
+	bool activateCurve(QPointF mouseScenePos, double maxDist = -1) override;
+	void setHover(bool on) override;
 
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, xColumn, XColumn)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, yColumn, YColumn)
@@ -112,6 +114,9 @@ public:
 	BASIC_D_ACCESSOR_DECL(qreal, valuesDistance, ValuesDistance)
 	BASIC_D_ACCESSOR_DECL(qreal, valuesRotationAngle, ValuesRotationAngle)
 	BASIC_D_ACCESSOR_DECL(qreal, valuesOpacity, ValuesOpacity)
+	BASIC_D_ACCESSOR_DECL(char, valuesNumericFormat, ValuesNumericFormat)
+	BASIC_D_ACCESSOR_DECL(int, valuesPrecision, ValuesPrecision)
+	CLASS_D_ACCESSOR_DECL(QString, valuesDateTimeFormat, ValuesDateTimeFormat)
 	CLASS_D_ACCESSOR_DECL(QString, valuesPrefix, ValuesPrefix)
 	CLASS_D_ACCESSOR_DECL(QString, valuesSuffix, ValuesSuffix)
 	CLASS_D_ACCESSOR_DECL(QColor, valuesColor, ValuesColor)
@@ -238,6 +243,9 @@ signals:
 	void valuesDistanceChanged(qreal);
 	void valuesRotationAngleChanged(qreal);
 	void valuesOpacityChanged(qreal);
+	void valuesNumericFormatChanged(char);
+	void valuesPrecisionChanged(int);
+	void valuesDateTimeFormatChanged(QString);
 	void valuesPrefixChanged(QString);
 	void valuesSuffixChanged(QString);
 	void valuesFontChanged(QFont);
