@@ -110,8 +110,8 @@ void XYDifferentiationCurvePrivate::recalculate() {
 
 	//create differentiation result columns if not available yet, clear them otherwise
 	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::Numeric);
-		yColumn = new Column("y", AbstractColumn::Numeric);
+		xColumn = new Column("x", AbstractColumn::ColumnMode::Numeric);
+		yColumn = new Column("y", AbstractColumn::ColumnMode::Numeric);
 		xVector = static_cast<QVector<double>* >(xColumn->data());
 		yVector = static_cast<QVector<double>* >(yColumn->data());
 
@@ -135,7 +135,7 @@ void XYDifferentiationCurvePrivate::recalculate() {
 	//determine the data source columns
 	const AbstractColumn* tmpXDataColumn = nullptr;
 	const AbstractColumn* tmpYDataColumn = nullptr;
-	if (dataSourceType == XYAnalysisCurve::DataSourceSpreadsheet) {
+	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
 		//spreadsheet columns as data source
 		tmpXDataColumn = xDataColumn;
 		tmpYDataColumn = yDataColumn;
@@ -165,19 +165,7 @@ void XYDifferentiationCurvePrivate::recalculate() {
 		xmax = differentiationData.xRange.last();
 	}
 
-	int rowCount = qMin(tmpXDataColumn->rowCount(), tmpYDataColumn->rowCount());
-	for (int row = 0; row < rowCount; ++row) {
-		//only copy those data where _all_ values (for x and y, if given) are valid
-		if (std::isnan(tmpXDataColumn->valueAt(row)) || std::isnan(tmpYDataColumn->valueAt(row))
-			|| tmpXDataColumn->isMasked(row) || tmpYDataColumn->isMasked(row))
-			continue;
-
-		// only when inside given range
-		if (tmpXDataColumn->valueAt(row) >= xmin && tmpXDataColumn->valueAt(row) <= xmax) {
-			xdataVector.append(tmpXDataColumn->valueAt(row));
-			ydataVector.append(tmpYDataColumn->valueAt(row));
-		}
-	}
+	XYAnalysisCurve::copyData(xdataVector, ydataVector, tmpXDataColumn, tmpYDataColumn, xmin, xmax);
 
 	//number of data points to differentiate
 	const size_t n = (size_t)xdataVector.size();
@@ -315,7 +303,7 @@ bool XYDifferentiationCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_STRING_VALUE("status", differentiationResult.status);
 			READ_INT_VALUE("time", differentiationResult.elapsedTime, int);
 		} else if (reader->name() == "column") {
-			Column* column = new Column(QString(), AbstractColumn::Numeric);
+			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Numeric);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
