@@ -196,11 +196,11 @@ QString TreeViewComboBox::currentText() const {
 		return QString();
 }
 
-void TreeViewComboBox::setText(QString text) {
+void TreeViewComboBox::setText(const QString& text) {
 	m_lineEditText = text;
 }
 
-void TreeViewComboBox::setInvalid(bool invalid, QString tooltip) {
+void TreeViewComboBox::setInvalid(bool invalid, const QString& tooltip) {
 	if (invalid) {
 		setStyleSheet("background: red;");
 		setToolTip(tooltip);
@@ -233,7 +233,7 @@ bool TreeViewComboBox::eventFilter(QObject* object, QEvent* event) {
 		this->setFocus();
 		return true;
 	}
-	return false;
+	return QComboBox::eventFilter(object, event);
 }
 
 //SLOTs
@@ -298,6 +298,10 @@ bool TreeViewComboBox::isTopLevel(const AbstractAspect* aspect) const {
 	for (AspectType type : m_topLevelClasses) {
 		if (aspect->type() == type)
 			return true;
+
+		if (type == AspectType::XYAnalysisCurve)
+			if (aspect->inherits(AspectType::XYAnalysisCurve))
+				return true;
 	}
 	return false;
 }
