@@ -44,15 +44,19 @@ class QTimeLine;
 class AbstractAspect;
 class WorksheetElement;
 
+#ifdef Q_OS_MAC
+	class KDMacTouchBar;
+#endif
+
 class WorksheetView : public QGraphicsView {
 	Q_OBJECT
 
 public:
 	explicit WorksheetView(Worksheet* worksheet);
 
-	enum ExportFormat {Pdf, Svg, Png};
-	enum GridStyle {NoGrid, LineGrid, DotGrid};
-	enum ExportArea {ExportBoundingBox, ExportSelection, ExportWorksheet};
+	enum class ExportFormat {PDF, SVG, PNG};
+	enum class GridStyle {NoGrid, Line, Dot};
+	enum class ExportArea {BoundingBox, Selection, Worksheet};
 
 	struct GridSettings {
 		GridStyle style;
@@ -62,16 +66,18 @@ public:
 		double opacity;
 	};
 
-	enum MouseMode {SelectionMode, NavigationMode, ZoomSelectionMode};
+	enum class MouseMode {Selection, Navigation, ZoomSelection};
 
 	void setScene(QGraphicsScene*);
 	void exportToFile(const QString&, const ExportFormat, const ExportArea, const bool, const int);
+	void exportToClipboard(const ExportFormat, const ExportArea, const bool, const int);
 	void exportToClipboard();
 	void setIsClosing();
 	void setIsBeingPresented(bool presenting);
 	void setCartesianPlotActionMode(Worksheet::CartesianPlotActionMode mode);
 	void setCartesianPlotCursorMode(Worksheet::CartesianPlotActionMode mode);
 	void setPlotLock(bool lock);
+	void suppressSelectionChangedEvent(bool);
 
 	Worksheet::CartesianPlotActionMode getCartesianPlotActionMode();
 	void registerShortcuts();
@@ -95,6 +101,7 @@ private:
 	void contextMenuEvent(QContextMenuEvent*) override;
 	void wheelEvent(QWheelEvent*) override;
 	void mousePressEvent(QMouseEvent*) override;
+	void mouseDoubleClickEvent(QMouseEvent*) override;
 	void mouseReleaseEvent(QMouseEvent*) override;
 	void mouseMoveEvent(QMouseEvent*) override;
 	void keyPressEvent(QKeyEvent*) override;
@@ -104,8 +111,8 @@ private:
 	void dropEvent(QDropEvent*) override;
 
 	Worksheet* m_worksheet;
-	MouseMode m_mouseMode{SelectionMode};
-	CartesianPlot::MouseMode m_cartesianPlotMouseMode{CartesianPlot::SelectionMode};
+	MouseMode m_mouseMode{MouseMode::Selection};
+	CartesianPlot::MouseMode m_cartesianPlotMouseMode{CartesianPlot::MouseMode::Selection};
 	bool m_selectionBandIsShown{false};
 	QPoint m_selectionStart;
 	QPoint m_selectionEnd;
@@ -168,8 +175,8 @@ private:
 	QAction* addCartesianPlot3Action{nullptr};
 	QAction* addCartesianPlot4Action{nullptr};
 	QAction* addTextLabelAction{nullptr};
+	QAction* addImageAction{nullptr};
 	QAction* addHistogram{nullptr};
-	QAction* addBarChartPlot{nullptr};
 
 	QAction* verticalLayoutAction{nullptr};
 	QAction* horizontalLayoutAction{nullptr};
@@ -223,6 +230,7 @@ private:
 	QAction* addVerticalAxisAction{nullptr};
 	QAction* addLegendAction{nullptr};
 	QAction* addPlotTextLabelAction{nullptr};
+	QAction* addPlotImageAction{nullptr};
 	QAction* addCustomPointAction{nullptr};
 
 	QAction* scaleAutoXAction{nullptr};
@@ -256,6 +264,9 @@ public slots:
 	void createContextMenu(QMenu*);
 	void createAnalysisMenu(QMenu*);
 	void fillToolBar(QToolBar*);
+#ifdef Q_OS_MAC
+	void fillTouchBar(KDMacTouchBar*);
+#endif
 	void fillCartesianPlotToolBar(QToolBar*);
 	void print(QPrinter*);
 	void selectItem(QGraphicsItem*);
@@ -299,6 +310,7 @@ private slots:
 
 signals:
 	void statusInfo(const QString&);
+	void propertiesExplorerRequested();
 };
 
 #endif
