@@ -40,7 +40,9 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/plots/cartesian/Axis.h"
 #include "backend/worksheet/plots/cartesian/CustomPoint.h"
+#include "backend/worksheet/plots/cartesian/ReferenceLine.h"
 #include "backend/worksheet/plots/cartesian/Histogram.h"
+#include "backend/worksheet/Image.h"
 #include "backend/worksheet/TextLabel.h"
 #ifdef HAVE_CANTOR_LIBS
 #include "backend/cantorWorksheet/CantorWorksheet.h"
@@ -62,6 +64,7 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "kdefrontend/dockwidgets/CartesianPlotDock.h"
 #include "kdefrontend/dockwidgets/CartesianPlotLegendDock.h"
 #include "kdefrontend/dockwidgets/ColumnDock.h"
+#include "kdefrontend/dockwidgets/ImageDock.h"
 #include "kdefrontend/dockwidgets/LiveDataDock.h"
 #include "kdefrontend/dockwidgets/MatrixDock.h"
 #include "kdefrontend/dockwidgets/ProjectDock.h"
@@ -80,6 +83,7 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
 #include "kdefrontend/dockwidgets/XYConvolutionCurveDock.h"
 #include "kdefrontend/dockwidgets/XYCorrelationCurveDock.h"
 #include "kdefrontend/dockwidgets/CustomPointDock.h"
+#include "kdefrontend/dockwidgets/ReferenceLineDock.h"
 #include "kdefrontend/dockwidgets/WorksheetDock.h"
 #ifdef HAVE_CANTOR_LIBS
 #include "kdefrontend/dockwidgets/CantorWorksheetDock.h"
@@ -103,48 +107,57 @@ Copyright            : (C) 2016 Garvit Khatri (garvitdelhi@gmail.com)
   \ingroup kdefrontend
 */
 
-namespace GuiObserverHelper
-{
+namespace GuiObserverHelper {
 
 template<class T>
-bool raiseDock(T*& dock, QStackedWidget* parent)
-{
+bool raiseDock(T*& dock, QStackedWidget* parent) {
+	Q_ASSERT(parent);
+	DEBUG(Q_FUNC_INFO << ", number of stacked widgets = " << parent->count())
+
 	const bool generated = !dock;
 	if (generated) {
 		dock = new T(parent);
 		parent->addWidget(dock);
 	}
-	parent->setCurrentWidget(dock);
 
+	// see https://wiki.qt.io/Technical_FAQ#How_can_I_get_a_QStackedWidget_to_automatically_switch_size_depending_on_the_content_of_the_page
+	if (parent->currentWidget())
+		parent->currentWidget()->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
+	parent->setCurrentWidget(dock);
+	parent->currentWidget()->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
+	// scroll the scroll area up to the top
+	if (parent->parent() && parent->parent()->parent()) {
+		auto* scrollArea = dynamic_cast<QScrollArea*>(parent->parent()->parent());
+		if (scrollArea)
+			scrollArea->ensureVisible(0, 0);
+	}
 	return generated;
 }
 
 template<class T>
-void raiseDockConnect(T*& dock, QStatusBar* statusBar, QStackedWidget* parent)
-{
+void raiseDockConnect(T*& dock, QStatusBar* statusBar, QStackedWidget* parent) {
 	if (raiseDock(dock, parent))
 		QObject::connect(dock, &T::info, [=](const QString& text){ statusBar->showMessage(text); });
 }
 
 template<class T>
-void raiseDockSetupConnect(T*& dock, QStatusBar* statusBar, QStackedWidget* parent)
-{
+void raiseDockSetupConnect(T*& dock, QStatusBar* statusBar, QStackedWidget* parent) {
 	if (raiseDock(dock, parent)) {
 		dock->setupGeneral();
 		QObject::connect(dock, &T::info, [=](const QString& text){ statusBar->showMessage(text); });
 	}
 }
 
-template<class R>
-QList<R*> castList(QList<AbstractAspect*>& selectedAspects)
-{
-	QList<R*> list;
+template<class T>
+QList<T*> castList(QList<AbstractAspect*>& selectedAspects) {
+	QList<T*> list;
 	for (auto* aspect : selectedAspects)
-		list << static_cast<R*>(aspect);
+		list << static_cast<T*>(aspect);
 	return list;
 }
 
-}
+} // namespace GuiObserverHelper
 
 using namespace GuiObserverHelper;
 
@@ -160,7 +173,7 @@ GuiObserver::GuiObserver(MainWin* mainWin) {
   and activates the corresponding dockwidgets, toolbars etc.
 */
 void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects) const {
-	auto clearDock = [&](){
+	auto clearDock = [&]() {
 		if (m_mainWindow->stackedWidget->currentWidget())
 			m_mainWindow->stackedWidget->currentWidget()->hide();
 
@@ -172,25 +185,26 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		return;
 	}
 
+	const AspectType type{ selectedAspects.front()->type() };
+	DEBUG(Q_FUNC_INFO << ", type: " << std::hex << static_cast<quint64>(type))
+
 	// update cursor dock
-	AbstractAspect* parent = selectedAspects[0]->parent(AspectType::Worksheet);
-	if (selectedAspects[0]->inherits(AspectType::Worksheet)) {
-		if (m_mainWindow->cursorWidget) {
-			Worksheet* worksheet = static_cast<Worksheet*>(selectedAspects[0]);
-			m_mainWindow->cursorWidget->setWorksheet(worksheet);
-		}
-	} else if (parent) {
-		if (m_mainWindow->cursorWidget) {
-			Worksheet* worksheet = static_cast<Worksheet*>(parent);
+	if (m_mainWindow->cursorWidget) {
+		if (type == AspectType::Worksheet) {
+			Worksheet* worksheet = static_cast<Worksheet*>(selectedAspects.front());
 			m_mainWindow->cursorWidget->setWorksheet(worksheet);
+		} else {
+			AbstractAspect* parent = selectedAspects.front()->parent(AspectType::Worksheet);
+			if (parent) {
+				Worksheet* worksheet = static_cast<Worksheet*>(parent);
+				m_mainWindow->cursorWidget->setWorksheet(worksheet);
+			}
 		}
 	}
 
-	const AspectType type = selectedAspects.front()->type();
-
 	// Check, whether objects of different types were selected.
 	// Don't show any dock widgets in this case.
-	for (auto* aspect : selectedAspects) {
+	for (const auto* aspect : selectedAspects) {
 		if (aspect->type() != type) {
 			clearDock();
 			return;
@@ -318,11 +332,21 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		raiseDock(m_mainWindow->textLabelDock, m_mainWindow->stackedWidget);
 		m_mainWindow->textLabelDock->setLabels(castList<TextLabel>(selectedAspects));
 		break;
+	case AspectType::Image:
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Image"));
+		raiseDock(m_mainWindow->imageDock, m_mainWindow->stackedWidget);
+		m_mainWindow->imageDock->setImages(castList<Image>(selectedAspects));
+		break;
 	case AspectType::CustomPoint:
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Custom Point"));
 		raiseDock(m_mainWindow->customPointDock, m_mainWindow->stackedWidget);
 		m_mainWindow->customPointDock->setPoints(castList<CustomPoint>(selectedAspects));
 		break;
+	case AspectType::ReferenceLine:
+		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Reference Line"));
+		raiseDock(m_mainWindow->referenceLineDock, m_mainWindow->stackedWidget);
+		m_mainWindow->referenceLineDock->setReferenceLines(castList<ReferenceLine>(selectedAspects));
+		break;
 	case AspectType::DatapickerCurve:
 		m_mainWindow->m_propertiesDock->setWindowTitle(i18nc("@title:window", "Datapicker Curve"));
 		raiseDock(m_mainWindow->datapickerCurveDock, m_mainWindow->stackedWidget);
@@ -335,7 +359,7 @@ void GuiObserver::selectedAspectsChanged(QList<AbstractAspect*>& selectedAspects
 		{
 			QList<DatapickerImage*> list;
 			for (auto* aspect : selectedAspects)
-				list << qobject_cast<Datapicker*>(aspect)->image();
+				list << static_cast<Datapicker*>(aspect)->image();
 			m_mainWindow->datapickerImageDock->setImages(list);
 		}
 		break;
