@@ -126,6 +126,7 @@
 #include <KActionMenu>
 #include <KColorScheme>
 #include <KColorSchemeManager>
+#include <KToggleFullScreenAction>
 #include <kconfigwidgets_version.h>
 
 #ifdef HAVE_CANTOR_LIBS
@@ -187,11 +188,11 @@ MainWin::~MainWin() {
 	KSharedConfig::openConfig()->sync();
 
 	//if welcome screen is shown, save its settings prior to deleting it
-// 	if(dynamic_cast<QQuickWidget*>(centralWidget()))
+// 	if (dynamic_cast<QQuickWidget*>(centralWidget()))
 // 		QMetaObject::invokeMethod(m_welcomeWidget->rootObject(), "saveWidgetDimensions");
 
 	if (m_project) {
-// 		if(dynamic_cast<QQuickWidget*>(centralWidget()) == nullptr)
+// 		if (dynamic_cast<QQuickWidget*>(centralWidget()) == nullptr)
 // 			m_mdiArea->closeAllSubWindows();
 
 		disconnect(m_project, nullptr, this, nullptr);
@@ -204,7 +205,7 @@ MainWin::~MainWin() {
 	if (m_guiObserver)
 		delete m_guiObserver;
 
-// 	if(m_welcomeScreenHelper)
+// 	if (m_welcomeScreenHelper)
 // 		delete m_welcomeScreenHelper;
 }
 
@@ -394,7 +395,7 @@ QQuickWidget* MainWin::createWelcomeScreen() {
 	showMaximized();
 
 	KToolBar* toolbar = toolBar();
-	if(toolbar)
+	if (toolbar)
 		toolbar->setVisible(false);
 
 	QList<QVariant> recentList;
@@ -408,7 +409,7 @@ QQuickWidget* MainWin::createWelcomeScreen() {
 	ctxt->setContextProperty("recentProjects", variant);
 
 	//Create helper object
-	if(m_welcomeScreenHelper)
+	if (m_welcomeScreenHelper)
 		delete m_welcomeScreenHelper;
 	m_welcomeScreenHelper = new WelcomeScreenHelper();
 	connect(m_welcomeScreenHelper, &WelcomeScreenHelper::openExampleProject,
@@ -436,7 +437,7 @@ QQuickWidget* MainWin::createWelcomeScreen() {
  */
 /*
 void MainWin::resetWelcomeScreen() {
-	if(dynamic_cast<QQuickWidget*>(centralWidget()))
+	if (dynamic_cast<QQuickWidget*>(centralWidget()))
 		QMetaObject::invokeMethod(m_welcomeWidget->rootObject(), "restoreOriginalLayout");
 }
 */
@@ -446,11 +447,11 @@ void MainWin::resetWelcomeScreen() {
  */
 void MainWin::createMdiArea() {
 	KToolBar* toolbar = toolBar();
-	if(toolbar)
+	if (toolbar)
 		toolbar->setVisible(true);
 
 	//Save welcome screen's dimensions.
-// 	if(m_showWelcomeScreen)
+// 	if (m_showWelcomeScreen)
 // 		QMetaObject::invokeMethod(m_welcomeWidget->rootObject(), "saveWidgetDimensions");
 
 	m_mdiArea = new QMdiArea;
@@ -481,20 +482,22 @@ void MainWin::createMdiArea() {
 void MainWin::initActions() {
 	// ******************** File-menu *******************************
 	//add some standard actions
-	m_newProjectAction = KStandardAction::openNew(this, SLOT(newProject()),actionCollection());
-	m_openProjectAction = KStandardAction::open(this, SLOT(openProject()),actionCollection());
-	m_recentProjectsAction = KStandardAction::openRecent(this, SLOT(openRecentProject(QUrl)),actionCollection());
-	m_closeAction = KStandardAction::close(this, SLOT(closeProject()),actionCollection());
+	m_newProjectAction = KStandardAction::openNew(this, &MainWin::newProject, actionCollection());
+	m_openProjectAction = KStandardAction::open(this, static_cast<void (MainWin::*)()>(&MainWin::openProject), actionCollection());
+	m_recentProjectsAction = KStandardAction::openRecent(this, &MainWin::openRecentProject, actionCollection());
+	m_closeAction = KStandardAction::close(this, &MainWin::closeProject, actionCollection());
 	actionCollection()->setDefaultShortcut(m_closeAction, QKeySequence()); //remove the shortcut, QKeySequence::Close will be used for closing sub-windows
-	m_saveAction = KStandardAction::save(this, SLOT(saveProject()),actionCollection());
-	m_saveAsAction = KStandardAction::saveAs(this, SLOT(saveProjectAs()),actionCollection());
-	m_printAction = KStandardAction::print(this, SLOT(print()),actionCollection());
-	m_printPreviewAction = KStandardAction::printPreview(this, SLOT(printPreview()),actionCollection());
+	m_saveAction = KStandardAction::save(this, &MainWin::saveProject, actionCollection());
+	m_saveAsAction = KStandardAction::saveAs(this, &MainWin::saveProjectAs, actionCollection());
+	m_printAction = KStandardAction::print(this, &MainWin::print, actionCollection());
+	m_printPreviewAction = KStandardAction::printPreview(this, &MainWin::printPreview, actionCollection());
 
-	//TODO: on Mac OS when going full-screen we get a crash because of an stack-overflow
-#ifndef Q_OS_MAC
-	KStandardAction::fullScreen(this, SLOT(toggleFullScreen()), this, actionCollection());
-#endif
+	m_toggleFullScreenAction = KStandardAction::fullScreen(this, &MainWin::toggleFullScreen, this, actionCollection());
+
+	//QDEBUG(Q_FUNC_INFO << ", preferences action name:" << KStandardAction::name(KStandardAction::Preferences))
+	KStandardAction::preferences(this, &MainWin::settingsDialog, actionCollection());
+	// QAction* action = actionCollection()->action(KStandardAction::name(KStandardAction::Preferences)));
+	KStandardAction::quit(this, &MainWin::close, actionCollection());
 
 	//New Folder/Workbook/Spreadsheet/Matrix/Worksheet/Datasources
 	m_newWorkbookAction = new QAction(QIcon::fromTheme("labplot-workbook-new"),i18n("Workbook"),this);
@@ -634,10 +637,6 @@ void MainWin::initActions() {
 	m_prevWindowAction->setStatusTip(i18n("Move the focus to the previous window"));
 	actionCollection()->addAction("previous window", m_prevWindowAction);
 
-	//"Standard actions"
-	KStandardAction::preferences(this, SLOT(settingsDialog()), actionCollection());
-	KStandardAction::quit(this, SLOT(close()), actionCollection());
-
 	//Actions for window visibility
 	auto* windowVisibilityActions = new QActionGroup(this);
 	windowVisibilityActions->setExclusive(true);
@@ -701,12 +700,8 @@ void MainWin::initActions() {
 
 void MainWin::initMenus() {
 	//add the actions to toggle the status bar and the project and properties explorer widgets to the "View" menu.
-	//this menu is created automatically when the defualt "full screen" action is created in initActions().
-	//because of a bug on macOS we don't have this action and menu on macOS, so we add available the explorer
-	//toggle actions to the menu "Windows".
+	//this menu is created automatically when the default "full screen" action is created in initActions().
 	auto* menu = dynamic_cast<QMenu*>(factory()->container("view", this));
-	if (!menu)
-		menu = dynamic_cast<QMenu*>(factory()->container("windows", this));
 
 	if (menu) {
 		menu->addSeparator();
@@ -807,6 +802,7 @@ void MainWin::initMenus() {
 #ifdef HAVE_CANTOR_LIBS
 	QAction* action = new QAction(QIcon::fromTheme(QLatin1String("cantor")), i18n("Configure CAS"), this);
 	connect(action, &QAction::triggered, this, &MainWin::cantorSettingsDialog);
+	action->setMenuRole(QAction::NoRole);	// prevent macOS Qt heuristics to select this action for preferences
 	if (settingsMenu)
 		settingsMenu->addAction(action);
 #endif
@@ -982,6 +978,8 @@ void MainWin::updateGUI() {
 	}
 #endif
 
+	Q_ASSERT(m_currentAspect);
+
 	//Handle the Worksheet-object
 	const Worksheet* w = dynamic_cast<Worksheet*>(m_currentAspect);
 	if (!w)
@@ -1104,7 +1102,7 @@ void MainWin::updateGUI() {
 	if (!datapicker)
 		datapicker = dynamic_cast<Datapicker*>(m_currentAspect->parent(AspectType::Datapicker));
 	if (!datapicker) {
-		if (m_currentAspect->type() == AspectType::DatapickerCurve)
+		if (m_currentAspect && m_currentAspect->type() == AspectType::DatapickerCurve)
 			datapicker = dynamic_cast<Datapicker*>(m_currentAspect->parentAspect());
 	}
 
@@ -1135,7 +1133,7 @@ bool MainWin::newProject() {
 	if (!closeProject())
 		return false;
 
-// 	if(dynamic_cast<QQuickWidget*>(centralWidget())) {
+// 	if (dynamic_cast<QQuickWidget*>(centralWidget())) {
 // 		createMdiArea();
 // 		setCentralWidget(m_mdiArea);
 // 	}
@@ -1153,7 +1151,7 @@ bool MainWin::newProject() {
 	m_currentFolder = m_project;
 
 	KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Settings_General"));
-	Project::MdiWindowVisibility vis = Project::MdiWindowVisibility(group.readEntry("MdiWindowVisibility", 0));
+	auto vis = Project::MdiWindowVisibility(group.readEntry("MdiWindowVisibility", 0));
 	m_project->setMdiWindowVisibility( vis );
 	if (vis == Project::MdiWindowVisibility::folderOnly)
 		m_visibilityFolderAction->setChecked(true);
@@ -1167,7 +1165,7 @@ bool MainWin::newProject() {
 
 	//newProject is called for the first time, there is no project explorer yet
 	//-> initialize the project explorer,  the GUI-observer and the dock widgets.
-	if (m_projectExplorer == nullptr) {
+	if (!m_projectExplorer) {
 		group = KSharedConfig::openConfig()->group(QLatin1String("MainWin"));
 
 		m_projectExplorerDock = new QDockWidget(this);
@@ -1178,6 +1176,7 @@ bool MainWin::newProject() {
 		m_projectExplorerDock->setWidget(m_projectExplorer);
 
 		connect(m_projectExplorer, &ProjectExplorer::currentAspectChanged, this, &MainWin::handleCurrentAspectChanged);
+		connect(m_projectExplorer, &ProjectExplorer::activateView, this, &MainWin::activateSubWindowForAspect);
 		connect(m_projectExplorerDock, &QDockWidget::visibilityChanged, this, &MainWin::projectExplorerDockVisibilityChanged);
 
 		//Properties dock
@@ -1193,13 +1192,12 @@ bool MainWin::newProject() {
 			addDockWidget(Qt::RightDockWidgetArea, m_propertiesDock);
 		}
 
-		auto* sa = new QScrollArea(m_propertiesDock);
-		stackedWidget = new QStackedWidget(sa);
-		stackedWidget->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-		stackedWidget->setMinimumSize(0, 0);
-		sa->setWidget(stackedWidget);
-		sa->setWidgetResizable(true);
-		m_propertiesDock->setWidget(sa);
+		auto* scrollArea = new QScrollArea(m_propertiesDock);
+		scrollArea->setWidgetResizable(true);
+
+		stackedWidget = new QStackedWidget(scrollArea);
+		scrollArea->setWidget(stackedWidget);		// stacked widget inside scroll area
+		m_propertiesDock->setWidget(scrollArea);	// scroll area inside dock
 
 		connect(m_propertiesDock, &QDockWidget::visibilityChanged, this, &MainWin::propertiesDockVisibilityChanged);
 
@@ -1278,7 +1276,7 @@ void MainWin::openProject(const QString& filename) {
 		return;
 	}
 
-// 	if(dynamic_cast<QQuickWidget*>(centralWidget())) {
+// 	if (dynamic_cast<QQuickWidget*>(centralWidget())) {
 // 		createMdiArea();
 // 		setCentralWidget(m_mdiArea);
 // 	}
@@ -1287,11 +1285,11 @@ void MainWin::openProject(const QString& filename) {
 		return;
 
 	WAIT_CURSOR;
+	m_project->setFileName(filename);
 	QElapsedTimer timer;
 	timer.start();
 	bool rc = false;
 	if (Project::isLabPlotProject(filename)) {
-		m_project->setFileName(filename);
 		rc = m_project->load(filename);
 	}
 #ifdef HAVE_LIBORIGIN
@@ -1436,6 +1434,7 @@ void MainWin::openProject(const QString& filename) {
 	updateTitleBar();
 	updateGUIOnProjectChanges();
 	updateGUI(); //there are most probably worksheets or spreadsheets in the open project -> update the GUI
+	updateMdiWindowVisibility();
 	m_saveAction->setEnabled(false);
 
 	statusBar()->showMessage( i18n("Project successfully opened (in %1 seconds).", (float)timer.elapsed()/1000) );
@@ -1450,7 +1449,7 @@ void MainWin::openProject(const QString& filename) {
 }
 
 void MainWin::openRecentProject(const QUrl& url) {
-// 	if(dynamic_cast<QQuickWidget*>(centralWidget())) {
+// 	if (dynamic_cast<QQuickWidget*>(centralWidget())) {
 // 		createMdiArea();
 // 		setCentralWidget(m_mdiArea);
 // 	}
@@ -1471,13 +1470,21 @@ bool MainWin::closeProject() {
 	if (warnModified())
 		return false;
 
-	if(!m_closing) {
-// 		if(dynamic_cast<QQuickWidget*>(centralWidget()) && m_showWelcomeScreen) {
+	if (!m_closing) {
+// 		if (dynamic_cast<QQuickWidget*>(centralWidget()) && m_showWelcomeScreen) {
 // 			m_welcomeWidget = createWelcomeScreen();
 // 			setCentralWidget(m_welcomeWidget);
 // 		}
 	}
 
+	//hide the sub-windows prior to deleting them in order to get rid of the shadows
+	//drawn across the sub-windows by the style. The shadow is removed by closing/hiding
+	//the sub-window exlicitely but not if we just delete it.
+	//TODO: the actual fix is in https://invent.kde.org/plasma/breeze/-/merge_requests/43,
+	//we can remove this hack later.
+	for (auto* window : m_mdiArea->subWindowList())
+		window->hide();
+
 	m_projectClosing = true;
 	statusBar()->clearMessage();
 	delete m_aspectTreeModel;
@@ -1504,6 +1511,7 @@ bool MainWin::closeProject() {
 	delete cursorDock;
 	cursorDock = nullptr;
 	cursorWidget = nullptr; // is deleted, because it's the cild of cursorDock
+
 	return true;
 }
 
@@ -1776,7 +1784,7 @@ void MainWin::newNotes() {
 	Otherwise returns \c 0.
 */
 Spreadsheet* MainWin::activeSpreadsheet() const {
-// 	if(dynamic_cast<QQuickWidget*>(centralWidget()))
+// 	if (dynamic_cast<QQuickWidget*>(centralWidget()))
 // 		return nullptr;
 
 	if (!m_currentAspect)
@@ -1800,7 +1808,7 @@ Spreadsheet* MainWin::activeSpreadsheet() const {
 	adds a new Cantor Spreadsheet to the project.
 */
 void MainWin::newCantorWorksheet(QAction* action) {
-	CantorWorksheet* cantorworksheet = new CantorWorksheet(action->data().toString());
+	auto* cantorworksheet = new CantorWorksheet(action->data().toString());
 	this->addAspectToProject(cantorworksheet);
 }
 
@@ -1891,7 +1899,7 @@ void MainWin::handleAspectAboutToBeRemoved(const AbstractAspect *aspect) {
 	called when the current aspect in the tree of the project explorer was changed.
 	Selects the new aspect.
 */
-void MainWin::handleCurrentAspectChanged(AbstractAspect *aspect) {
+void MainWin::handleCurrentAspectChanged(AbstractAspect* aspect) {
 	if (!aspect)
 		aspect = m_project; // should never happen, just in case
 
@@ -1911,6 +1919,7 @@ void MainWin::handleCurrentAspectChanged(AbstractAspect *aspect) {
 }
 
 void MainWin::activateSubWindowForAspect(const AbstractAspect* aspect) const {
+	Q_ASSERT(aspect);
 	const auto* part = dynamic_cast<const AbstractPart*>(aspect);
 	if (part) {
 		PartMdiView* win{nullptr};
@@ -1980,7 +1989,8 @@ void MainWin::setMdiWindowVisibility(QAction* action) {
 	the window again via the context menu in the project explorer.
 */
 void MainWin::handleShowSubWindowRequested() {
-	activateSubWindowForAspect(m_currentAspect);
+	if (m_currentAspect)
+		activateSubWindowForAspect(m_currentAspect);
 }
 
 /*!
@@ -2042,8 +2052,7 @@ void MainWin::redo() {
 	Shows/hides mdi sub-windows depending on the current visibility policy.
 */
 void MainWin::updateMdiWindowVisibility() const {
-	QList<QMdiSubWindow *> windows = m_mdiArea->subWindowList();
-	PartMdiView* part_view;
+	auto windows = m_mdiArea->subWindowList();
 	switch (m_project->mdiWindowVisibility()) {
 	case Project::MdiWindowVisibility::allMdiWindows:
 		for (auto* window : windows)
@@ -2052,21 +2061,16 @@ void MainWin::updateMdiWindowVisibility() const {
 		break;
 	case Project::MdiWindowVisibility::folderOnly:
 		for (auto* window : windows) {
-			part_view = qobject_cast<PartMdiView *>(window);
-			Q_ASSERT(part_view);
-			if (part_view->part()->folder() == m_currentFolder)
-				part_view->show();
-			else
-				part_view->hide();
+			auto* view = static_cast<PartMdiView*>(window);
+			bool visible = view->part()->folder() == m_currentFolder;
+			window->setVisible(visible);
 		}
 		break;
 	case Project::MdiWindowVisibility::folderAndSubfolders:
 		for (auto* window : windows) {
-			part_view = qobject_cast<PartMdiView *>(window);
-			if (part_view->part()->isDescendantOf(m_currentFolder))
-				part_view->show();
-			else
-				part_view->hide();
+			auto* view = static_cast<PartMdiView*>(window);
+			bool visible = view->part()->isDescendantOf(m_currentFolder);
+			window->setVisible(visible);
 		}
 		break;
 	}
@@ -2214,13 +2218,8 @@ void MainWin::cartesianPlotMouseModeChanged(CartesianPlot::MouseMode mode) {
 	}
 }
 
-void MainWin::toggleFullScreen() {
-	if (this->windowState() == Qt::WindowFullScreen)
-		this->setWindowState(m_lastWindowState);
-	else {
-		m_lastWindowState = this->windowState();
-		this->showFullScreen();
-	}
+void MainWin::toggleFullScreen(bool t) {
+	m_toggleFullScreenAction->setFullScreen(this, t);
 }
 
 void MainWin::closeEvent(QCloseEvent* event) {
@@ -2277,7 +2276,7 @@ void MainWin::handleSettingsChanges() {
 	}
 
 	//view mode
-// 	if(dynamic_cast<QQuickWidget*>(centralWidget()) == nullptr) {
+// 	if (dynamic_cast<QQuickWidget*>(centralWidget()) == nullptr) {
 	QMdiArea::ViewMode viewMode = QMdiArea::ViewMode(group.readEntry("ViewMode", 0));
 	if (m_mdiArea->viewMode() != viewMode) {
 		m_mdiArea->setViewMode(viewMode);
@@ -2297,6 +2296,18 @@ void MainWin::handleSettingsChanges() {
 	}
 // 	}
 
+	//window visibility
+	auto vis = Project::MdiWindowVisibility(group.readEntry("MdiWindowVisibility", 0));
+	if (m_project && (vis != m_project->mdiWindowVisibility())) {
+		if (vis == Project::MdiWindowVisibility::folderOnly)
+			m_visibilityFolderAction->setChecked(true);
+		else if (vis == Project::MdiWindowVisibility::folderAndSubfolders)
+			m_visibilitySubfolderAction->setChecked(true);
+		else
+			m_visibilityAllAction->setChecked(true);
+		m_project->setMdiWindowVisibility(vis);
+	}
+
 	//autosave
 	bool autoSave = group.readEntry("AutoSave", 0);
 	if (m_autoSaveActive != autoSave) {
@@ -2329,14 +2340,16 @@ void MainWin::handleSettingsChanges() {
 	}
 
 	//update spreadsheet header
-	auto spreadsheets = m_project->children<Spreadsheet>(AbstractAspect::ChildIndexFlag::Recursive);
-	for (auto* spreadsheet : spreadsheets) {
-		spreadsheet->updateHorizontalHeader();
-		spreadsheet->updateLocale();
+	if (m_project) {
+		auto spreadsheets = m_project->children<Spreadsheet>(AbstractAspect::ChildIndexFlag::Recursive);
+		for (auto* spreadsheet : spreadsheets) {
+			spreadsheet->updateHorizontalHeader();
+			spreadsheet->updateLocale();
+		}
 	}
 
 	bool showWelcomeScreen = group.readEntry<bool>(QLatin1String("ShowWelcomeScreen"), true);
-	if(m_showWelcomeScreen != showWelcomeScreen)
+	if (m_showWelcomeScreen != showWelcomeScreen)
 		m_showWelcomeScreen = showWelcomeScreen;
 }
 
@@ -2446,10 +2459,10 @@ void MainWin::importProjectDialog() {
  * \brief opens a dialog to import datasets
  */
 void MainWin::importDatasetDialog() {
-	ImportDatasetDialog* dlg = new ImportDatasetDialog(this);
+	auto* dlg = new ImportDatasetDialog(this);
 	if (dlg->exec() == QDialog::Accepted) {
 			Spreadsheet* spreadsheet = new Spreadsheet(i18n("Dataset%1", 1));
-			DatasetHandler* dataset = new DatasetHandler(spreadsheet);
+			auto* dataset = new DatasetHandler(spreadsheet);
 			dlg->importToDataset(dataset, statusBar());
 
 			QTimer timer;
@@ -2460,13 +2473,11 @@ void MainWin::importDatasetDialog() {
 			timer.start(1500);
 			loop.exec();
 
-			if(timer.isActive()){
+			if (timer.isActive()) {
 				timer.stop();
 				addAspectToProject(spreadsheet);
-				delete dataset;
 			}
-			else
-				delete dataset;
+			delete dataset;
 	}
 	delete dlg;
 }
@@ -2496,35 +2507,33 @@ void MainWin::editFitsFileDialog() {
   adds a new file data source to the current project.
 */
 void MainWin::newLiveDataSourceActionTriggered() {
-	ImportFileDialog* dlg = new ImportFileDialog(this, true);
+	auto* dlg = new ImportFileDialog(this, true);
 	if (dlg->exec() == QDialog::Accepted) {
-		if (static_cast<LiveDataSource::SourceType>(dlg->sourceType()) == LiveDataSource::SourceType::MQTT) {
+		if (dlg->sourceType() == LiveDataSource::SourceType::MQTT) {
 #ifdef HAVE_MQTT
-			MQTTClient* mqttClient = new MQTTClient(i18n("MQTT Client%1", 1));
+			auto* mqttClient = new MQTTClient(i18n("MQTT Client%1", 1));
 			dlg->importToMQTT(mqttClient);
 
-			mqttClient->setName(mqttClient->clientHostName());
-
-			QVector<const MQTTClient*> existingClients = m_project->children<const MQTTClient>(AbstractAspect::ChildIndexFlag::Recursive);
-
 			//doesn't make sense to have more MQTTClients connected to the same broker
+			auto clients = m_project->children<const MQTTClient>(AbstractAspect::ChildIndexFlag::Recursive);
 			bool found = false;
-			for (const auto* client : existingClients) {
+			for (const auto* client : clients) {
 				if (client->clientHostName() == mqttClient->clientHostName() && client->clientPort() == mqttClient->clientPort()) {
 					found = true;
 					break;
 				}
 			}
 
-			if (!found)
+			if (!found) {
+				mqttClient->setName(mqttClient->clientHostName());
 				addAspectToProject(mqttClient);
-			else {
+			} else {
 				delete mqttClient;
 				QMessageBox::warning(this, "Warning", "There already is a MQTTClient with this host!");
 			}
 #endif
 		} else {
-			LiveDataSource* dataSource = new LiveDataSource(i18n("Live data source%1", 1), false);
+			auto* dataSource = new LiveDataSource(i18n("Live data source%1", 1), false);
 			dlg->importToLiveDataSource(dataSource, statusBar());
 			addAspectToProject(dataSource);
 		}
@@ -2559,8 +2568,8 @@ void MainWin::settingsDialog() {
 
 #ifdef HAVE_CANTOR_LIBS
 void MainWin::cantorSettingsDialog() {
-	static KCoreConfigSkeleton* emptyConfig = new KCoreConfigSkeleton();
-	KConfigDialog* cantorDialog = new KConfigDialog(this,  QLatin1String("Cantor Settings"), emptyConfig);
+	static auto* emptyConfig = new KCoreConfigSkeleton();
+	auto* cantorDialog = new KConfigDialog(this,  QLatin1String("Cantor Settings"), emptyConfig);
 	for (auto* backend : Cantor::Backend::availableBackends())
 		if (backend->config()) //It has something to configure, so add it to the dialog
 			cantorDialog->addPage(backend->settingsWidget(cantorDialog), backend->config(), backend->name(),  backend->icon());
