@@ -62,7 +62,7 @@ QString FITSOptionsWidget::currentExtensionName() {
 }
 
 void FITSOptionsWidget::updateContent(FITSFilter* filter, const QString& fileName) {
-	DEBUG("FITSOptionsWidget::updateContent() file name = " << fileName.toStdString());
+	DEBUG("FITSOptionsWidget::updateContent() file name = " << STDSTRING(fileName));
 	ui.twExtensions->clear();
 	filter->parseExtensions(fileName, ui.twExtensions, true);
 	DEBUG("FITSOptionsWidget::updateContent() DONE");
