@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : file info dialog
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2017 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2009-2019 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2015-2016 Stefan-Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -34,18 +34,16 @@
 #include <QTextEdit>
 
 class FileInfoDialog : public QDialog {
-Q_OBJECT
+	Q_OBJECT
 
 public:
 	explicit FileInfoDialog(QWidget*);
-	~FileInfoDialog();
+	~FileInfoDialog() override;
 	void setFiles(QStringList&);
 
 private:
 	QTextEdit m_textEditWidget;
-
-private slots:
-	void loadSettings();
+	QString fileInfoString(const QString&) const;
 };
 
 #endif //IMPORTFILEDIALOG_H
