@@ -30,7 +30,6 @@
 #include "ImportFileDialog.h"
 #include "ImportFileWidget.h"
 #include "backend/core/AspectTreeModel.h"
-#include "backend/datasources/LiveDataSource.h"
 #include "backend/datasources/filters/AbstractFileFilter.h"
 #include "backend/datasources/filters/filters.h"
 #include "backend/spreadsheet/Spreadsheet.h"
@@ -43,12 +42,14 @@
 #include "backend/datasources/MQTTClient.h"
 #endif
 
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KMessageWidget>
 #include <KSharedConfig>
 #include <KWindowConfig>
-#include <KLocalizedString>
 
 #include <QDialogButtonBox>
+#include <QElapsedTimer>
 #include <QProgressBar>
 #include <QTcpSocket>
 #include <QLocalSocket>
@@ -72,7 +73,7 @@ ImportFileDialog::ImportFileDialog(MainWin* parent, bool liveDataSource, const Q
 	vLayout->addWidget(m_importFileWidget);
 
 	//dialog buttons
-	QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Reset |QDialogButtonBox::Cancel);
+	auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Reset |QDialogButtonBox::Cancel);
 	okButton = buttonBox->button(QDialogButtonBox::Ok);
 	m_optionsButton = buttonBox->button(QDialogButtonBox::Reset); //we highjack the default "Reset" button and use if for showing/hiding the options
 	okButton->setEnabled(false); //ok is only available if a valid container was selected
@@ -115,9 +116,7 @@ ImportFileDialog::ImportFileDialog(MainWin* parent, bool liveDataSource, const Q
 	connect(m_importFileWidget, static_cast<void (ImportFileWidget::*)()>(&ImportFileWidget::sourceTypeChanged), this, &ImportFileDialog::checkOkButton);
 	connect(m_importFileWidget, &ImportFileWidget::hostChanged, this, &ImportFileDialog::checkOkButton);
 	connect(m_importFileWidget, &ImportFileWidget::portChanged, this, &ImportFileDialog::checkOkButton);
-	//TODO: do we really need to check the ok button when the preview was refreshed?
-	//If not, remove this together with the previewRefreshed signal in ImportFileWidget
-	//connect(m_importFileWidget, &ImportFileWidget::previewRefreshed, this, &ImportFileDialog::checkOkButton);
+	connect(m_importFileWidget, &ImportFileWidget::error, this, &ImportFileDialog::showErrorMessage);
 #ifdef HAVE_MQTT
 	connect(m_importFileWidget, &ImportFileWidget::subscriptionsChanged, this, &ImportFileDialog::checkOkButton);
 	connect(m_importFileWidget, &ImportFileWidget::checkFileType, this, &ImportFileDialog::checkOkButton);
@@ -139,8 +138,8 @@ ImportFileDialog::~ImportFileDialog() {
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 }
 
-int ImportFileDialog::sourceType() const {
-	return static_cast<int>(m_importFileWidget->currentSourceType());
+LiveDataSource::SourceType ImportFileDialog::sourceType() const {
+	return m_importFileWidget->currentSourceType();
 }
 
 /*!
@@ -159,7 +158,7 @@ void ImportFileDialog::importToLiveDataSource(LiveDataSource* source, QStatusBar
 	statusBar->addWidget(progressBar, 1);
 	WAIT_CURSOR;
 
-	QTime timer;
+	QElapsedTimer timer;
 	timer.start();
 	DEBUG("	Initial read()");
 	source->read();
@@ -214,7 +213,7 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 	WAIT_CURSOR;
 	QApplication::processEvents(QEventLoop::AllEvents, 100);
 
-	QTime timer;
+	QElapsedTimer timer;
 	timer.start();
 
 	if (aspect->inherits(AspectType::Matrix)) {
@@ -234,12 +233,12 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 
 		AbstractFileFilter::FileType fileType = m_importFileWidget->currentFileType();
 		// multiple data sets/variables for HDF5, NetCDF and ROOT
-		if (fileType == AbstractFileFilter::HDF5 || fileType == AbstractFileFilter::NETCDF ||
-			fileType == AbstractFileFilter::ROOT) {
+		if (fileType == AbstractFileFilter::FileType::HDF5 || fileType == AbstractFileFilter::FileType::NETCDF ||
+			fileType == AbstractFileFilter::FileType::ROOT) {
 			QStringList names;
-			if (fileType == AbstractFileFilter::HDF5)
+			if (fileType == AbstractFileFilter::FileType::HDF5)
 				names = m_importFileWidget->selectedHDF5Names();
-			else if (fileType == AbstractFileFilter::NETCDF)
+			else if (fileType == AbstractFileFilter::FileType::NETCDF)
 				names = m_importFileWidget->selectedNetCDFNames();
 			else
 				names = m_importFileWidget->selectedROOTNames();
@@ -252,7 +251,7 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 
 			//in replace mode add only missing sheets (from offset to nrNames)
 			//and rename the already available sheets
-			if (mode == AbstractFileFilter::Replace) {
+			if (mode == AbstractFileFilter::ImportMode::Replace) {
 				start = offset;
 
 				// if there are more available spreadsheets, than needed,
@@ -267,7 +266,7 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 				for (int i = 0; i < offset; ++i) {
 					//HDF5 variable names contain the whole path, remove it and keep the name only
 					QString sheetName = names.at(i);
-					if (fileType == AbstractFileFilter::HDF5)
+					if (fileType == AbstractFileFilter::FileType::HDF5)
 						sheetName = names[i].mid(names[i].lastIndexOf("/") + 1);
 
 					auto* sheet = sheets.at(i);
@@ -281,26 +280,26 @@ void ImportFileDialog::importTo(QStatusBar* statusBar) const {
 			for (int i = start; i < nrNames; ++i) {
 				//HDF5 variable names contain the whole path, remove it and keep the name only
 				QString sheetName = names.at(i);
-				if (fileType == AbstractFileFilter::HDF5)
+				if (fileType == AbstractFileFilter::FileType::HDF5)
 					sheetName = names[i].mid(names[i].lastIndexOf("/") + 1);
 
 				auto* spreadsheet = new Spreadsheet(sheetName);
-				if (mode == AbstractFileFilter::Prepend && !sheets.isEmpty())
+				if (mode == AbstractFileFilter::ImportMode::Prepend && !sheets.isEmpty())
 					workbook->insertChildBefore(spreadsheet, sheets[0]);
 				else
 					workbook->addChildFast(spreadsheet);
 			}
 
 			// start at offset for append, else at 0
-			if (mode != AbstractFileFilter::Append)
+			if (mode != AbstractFileFilter::ImportMode::Append)
 				offset = 0;
 
 			// import all sets to a different sheet
 			sheets = workbook->children<AbstractAspect>();
 			for (int i = 0; i < nrNames; ++i) {
-				if (fileType == AbstractFileFilter::HDF5)
+				if (fileType == AbstractFileFilter::FileType::HDF5)
 					static_cast<HDF5Filter*>(filter)->setCurrentDataSetName(names[i]);
-				else if (fileType == AbstractFileFilter::NETCDF)
+				else if (fileType == AbstractFileFilter::FileType::NETCDF)
 					static_cast<NetCDFFilter*>(filter)->setCurrentVarName(names[i]);
 				else
 					static_cast<ROOTFilter*>(filter)->setCurrentObject(names[i]);
@@ -369,6 +368,7 @@ void ImportFileDialog::checkOkButton() {
 			okButton->setToolTip(i18n("Select a data container where the data has to be imported into."));
 			lPosition->setEnabled(false);
 			cbPosition->setEnabled(false);
+			cbAddTo->setFocus(); //set the focus to make the user aware about the fact that a data container needs to be provided
 			return;
 		} else {
 			lPosition->setEnabled(true);
@@ -382,10 +382,12 @@ void ImportFileDialog::checkOkButton() {
 	}
 
 	QString fileName = m_importFileWidget->fileName();
-#ifndef HAVE_WINDOWS
-	if (!fileName.isEmpty() && fileName.at(0) != QDir::separator())
-		fileName = QDir::homePath() + QDir::separator() + fileName;
+#ifdef HAVE_WINDOWS
+	if (!fileName.isEmpty() && fileName.at(1) != QLatin1String(":"))
+#else
+	if (!fileName.isEmpty() && fileName.at(0) != QLatin1String("/"))
 #endif
+		fileName = QDir::homePath() + QLatin1String("/") + fileName;
 
 	DEBUG("Data Source Type: " << ENUM_TO_STRING(LiveDataSource, SourceType, m_importFileWidget->currentSourceType()));
 	switch (m_importFileWidget->currentSourceType()) {
@@ -393,10 +395,14 @@ void ImportFileDialog::checkOkButton() {
 		DEBUG("	fileName = " << fileName.toUtf8().constData());
 		const bool enable = QFile::exists(fileName);
 		okButton->setEnabled(enable);
-		if (enable)
+		if (enable) {
 			okButton->setToolTip(i18n("Close the dialog and import the data."));
-		else
-			okButton->setToolTip(i18n("Provide an existing file."));
+			showErrorMessage(QString());
+		} else {
+			QString msg = i18n("The provided file doesn't exist.");
+			okButton->setToolTip(msg);
+			showErrorMessage(msg);
+		}
 
 		break;
 	}
@@ -416,14 +422,18 @@ void ImportFileDialog::checkOkButton() {
 				// read-only socket is disconnected immediately (no waitForDisconnected())
 				okButton->setEnabled(true);
 				okButton->setToolTip(i18n("Close the dialog and import the data."));
+				showErrorMessage(QString());
 			} else {
-				DEBUG("failed connect to local socket - " << lsocket.errorString().toStdString());
 				okButton->setEnabled(false);
-				okButton->setToolTip(i18n("Could not connect to the provided local socket."));
+				QString msg = i18n("Could not connect to the provided local socket. Error: %1.", lsocket.errorString());
+				okButton->setToolTip(msg);
+				showErrorMessage(msg);
 			}
 		} else {
 			okButton->setEnabled(false);
-			okButton->setToolTip(i18n("Selected local socket does not exist."));
+			QString msg = i18n("Could not connect to the provided local socket. The socket does not exist.");
+			okButton->setToolTip(msg);
+			showErrorMessage(msg);
 		}
 
 		break;
@@ -436,15 +446,19 @@ void ImportFileDialog::checkOkButton() {
 			if (socket.waitForConnected()) {
 				okButton->setEnabled(true);
 				okButton->setToolTip(i18n("Close the dialog and import the data."));
+				showErrorMessage(QString());
 				socket.disconnectFromHost();
 			} else {
-				DEBUG("failed to connect to TCP socket - " << socket.errorString().toStdString());
 				okButton->setEnabled(false);
-				okButton->setToolTip(i18n("Could not connect to the provided TCP socket."));
+				QString msg = i18n("Could not connect to the provided TCP socket. Error: %1.", socket.errorString());
+				okButton->setToolTip(msg);
+				showErrorMessage(msg);
 			}
 		} else {
 			okButton->setEnabled(false);
-			okButton->setToolTip(i18n("Either the host name or the port number is missing."));
+			QString msg = i18n("Either the host name or the port number is missing.");
+			okButton->setToolTip(msg);
+			showErrorMessage(msg);
 		}
 		break;
 	}
@@ -457,12 +471,14 @@ void ImportFileDialog::checkOkButton() {
 			if (socket.waitForConnected()) {
 				okButton->setEnabled(true);
 				okButton->setToolTip(i18n("Close the dialog and import the data."));
+				showErrorMessage(QString());
 				socket.disconnectFromHost();
 				// read-only socket is disconnected immediately (no waitForDisconnected())
 			} else {
-				DEBUG("failed to connect to UDP socket - " << socket.errorString().toStdString());
 				okButton->setEnabled(false);
-				okButton->setToolTip(i18n("Could not connect to the provided UDP socket."));
+				QString msg = i18n("Could not connect to the provided UDP socket. Error: %1.", socket.errorString());
+				okButton->setToolTip(msg);
+				showErrorMessage(msg);
 			}
 		} else {
 			okButton->setEnabled(false);
@@ -472,13 +488,14 @@ void ImportFileDialog::checkOkButton() {
 		break;
 	}
 	case LiveDataSource::SourceType::SerialPort: {
+#ifdef HAVE_QTSERIALPORT
 		const QString sPort = m_importFileWidget->serialPort();
 		const int baudRate = m_importFileWidget->baudRate();
 
 		if (!sPort.isEmpty()) {
 			QSerialPort serialPort{this};
 
-			DEBUG("	Port: " << sPort.toStdString() << ", Settings: " << baudRate << ',' << serialPort.dataBits()
+			DEBUG("	Port: " << STDSTRING(sPort) << ", Settings: " << baudRate << ',' << serialPort.dataBits()
 					<< ',' << serialPort.parity() << ',' << serialPort.stopBits());
 			serialPort.setPortName(sPort);
 			serialPort.setBaudRate(baudRate);
@@ -487,20 +504,26 @@ void ImportFileDialog::checkOkButton() {
 			okButton->setEnabled(serialPortOpened);
 			if (serialPortOpened) {
 				okButton->setToolTip(i18n("Close the dialog and import the data."));
+				showErrorMessage(QString());
 				serialPort.close();
 			} else {
-				DEBUG("Could not connect to the provided serial port");
-				okButton->setToolTip(i18n("Could not connect to the provided serial port."));
+				QString msg = i18n("Could not connect to the provided serial port.");
+				okButton->setToolTip(msg);
+				showErrorMessage(msg);
 			}
 		} else {
 			okButton->setEnabled(false);
-			okButton->setToolTip(i18n("Serial port number is missing."));
+			QString msg = i18n("Serial port number is missing.");
+			okButton->setToolTip(msg);
+			showErrorMessage(msg);
 		}
+#endif
 		break;
-    }
+	}
 	case LiveDataSource::SourceType::MQTT: {
 #ifdef HAVE_MQTT
 		const bool enable = m_importFileWidget->isMqttValid();
+		showErrorMessage(QString());
 		if (enable) {
 			okButton->setEnabled(true);
 			okButton->setToolTip(i18n("Close the dialog and import the data."));
@@ -518,3 +541,18 @@ void ImportFileDialog::checkOkButton() {
 QString ImportFileDialog::selectedObject() const {
 	return m_importFileWidget->selectedObject();
 }
+
+void ImportFileDialog::showErrorMessage(const QString& message) {
+	if (message.isEmpty()) {
+		if (m_messageWidget && m_messageWidget->isVisible())
+			m_messageWidget->close();
+	} else {
+		if (!m_messageWidget) {
+			m_messageWidget = new KMessageWidget(this);
+			m_messageWidget->setMessageType(KMessageWidget::Error);
+			vLayout->insertWidget(vLayout->count() - 1, m_messageWidget);
+		}
+		m_messageWidget->setText(message);
+        m_messageWidget->animatedShow();
+	}
+}
