@@ -4,7 +4,7 @@ Project              : LabPlot
 Description          : import file data widget
 --------------------------------------------------------------------
 Copyright            : (C) 2009-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
-Copyright            : (C) 2009-2019 Alexander Semke (alexander.semke@web.de)
+Copyright            : (C) 2009-2020 Alexander Semke (alexander.semke@web.de)
 Copyright            : (C) 2017-2018 Fabian Kristof (fkristofszabolcs@gmail.com)
 Copyright            : (C) 2018-2019 Kovacs Ferencz (kferike98@gmail.com)
 
@@ -45,19 +45,15 @@ Copyright            : (C) 2018-2019 Kovacs Ferencz (kferike98@gmail.com)
 #include <QDir>
 #include <QDirModel>
 #include <QFileDialog>
-#include <QImageReader>
 #include <QInputDialog>
 #include <QIntValidator>
 #include <QLocalSocket>
-#include <QProcess>
 #include <QStandardItemModel>
 #include <QTableWidget>
 #include <QTcpSocket>
 #include <QTimer>
 #include <QUdpSocket>
-#include <QCheckBox>
 #include <QTreeWidgetItem>
-#include <QStringList>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
@@ -99,7 +95,6 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, bool liveDataSource, const Q
 	m_liveDataSource(liveDataSource)
 #ifdef HAVE_MQTT
 	,
-	m_connectTimeoutTimer(new QTimer(this)),
 	m_subscriptionWidget(new MQTTSubscriptionWidget(this))
 #endif
 {
@@ -149,10 +144,6 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, bool liveDataSource, const Q
 
 		ui.chbLinkFile->setToolTip(i18n("If this option is checked, only the link to the file is stored in the project file but not its content."));
 		ui.chbRelativePath->setToolTip(i18n("If this option is checked, the relative path of the file (relative to project's folder) will be saved."));
-
-#ifdef HAVE_MQTT
-		m_connectTimeoutTimer->setInterval(6000);
-#endif
 	}
 
 	QStringList filterItems {i18n("Automatic"), i18n("Custom")};
@@ -435,14 +426,13 @@ void ImportFileWidget::initSlots() {
 
 #ifdef HAVE_MQTT
 	connect(ui.cbConnection, static_cast<void (QComboBox::*) (int)>(&QComboBox::currentIndexChanged), this, &ImportFileWidget::mqttConnectionChanged);
-	connect(m_connectTimeoutTimer, &QTimer::timeout, this, &ImportFileWidget::mqttConnectTimeout);
 	connect(ui.cbFileType, static_cast<void (QComboBox::*) (int)>(&QComboBox::currentIndexChanged), [this]() {
 		emit checkFileType();
 	});
 	connect(ui.bManageConnections, &QPushButton::clicked, this, &ImportFileWidget::showMQTTConnectionManager);
 	connect(ui.bLWT, &QPushButton::clicked, this, &ImportFileWidget::showWillSettings);
-	connect(m_subscriptionWidget, &MQTTSubscriptionWidget::makeSubscription, this, &ImportFileWidget::mqttSubscribe);
-	connect(m_subscriptionWidget, &MQTTSubscriptionWidget::MQTTUnsubscribeFromTopic, this, &ImportFileWidget::unsubscribeFromTopic);
+	connect(m_subscriptionWidget, &MQTTSubscriptionWidget::makeSubscription, this, &ImportFileWidget::subscribeTopic);
+	connect(m_subscriptionWidget, &MQTTSubscriptionWidget::MQTTUnsubscribeFromTopic, this, &ImportFileWidget::unsubscribeTopic);
 	connect(m_subscriptionWidget, &MQTTSubscriptionWidget::enableWill, this, &ImportFileWidget::enableWill);
 	connect(m_subscriptionWidget, &MQTTSubscriptionWidget::subscriptionChanged, this, &ImportFileWidget::refreshPreview);
 #endif
@@ -468,7 +458,6 @@ void ImportFileWidget::showOptions(bool b) {
 }
 
 QString ImportFileWidget::fileName() const {
-	DEBUG("ImportFileWidget::fileName() : " << STDSTRING(m_cbFileName->currentText()))
 	return m_cbFileName->currentText();
 }
 
@@ -538,7 +527,6 @@ void ImportFileWidget::saveSettings(LiveDataSource* source) const {
 	LiveDataSource::SourceType sourceType = currentSourceType();
 	auto readingType = static_cast<LiveDataSource::ReadingType>(ui.cbReadingType->currentIndex());
 
-	source->setComment( fileName() );
 	source->setFileType(fileType);
 	currentFileFilter();
 	source->setFilter(m_currentFilter.release()); // pass ownership of the filter to the LiveDataSource
@@ -549,12 +537,14 @@ void ImportFileWidget::saveSettings(LiveDataSource* source) const {
 	case LiveDataSource::SourceType::FileOrPipe:
 		source->setFileName(fileName());
 		source->setFileLinked(ui.chbLinkFile->isChecked());
+		source->setComment(fileName());
 		if (m_liveDataSource)
 			source->setUseRelativePath(ui.chbRelativePath->isChecked());
 		break;
 	case LiveDataSource::SourceType::LocalSocket:
 		source->setFileName(fileName());
 		source->setLocalSocketName(fileName());
+		source->setComment(fileName());
 		break;
 	case LiveDataSource::SourceType::NetworkTcpSocket:
 	case LiveDataSource::SourceType::NetworkUdpSocket:
@@ -582,57 +572,6 @@ void ImportFileWidget::saveSettings(LiveDataSource* source) const {
 		source->setSampleSize(ui.sbSampleSize->value());
 }
 
-#ifdef HAVE_MQTT
-/*!
-	saves the settings to the MQTTClient \c client.
-*/
-void ImportFileWidget::saveMQTTSettings(MQTTClient* client) const {
-	DEBUG("ImportFileWidget::saveMQTTSettings");
-	MQTTClient::UpdateType updateType = static_cast<MQTTClient::UpdateType>(ui.cbUpdateType->currentIndex());
-	MQTTClient::ReadingType readingType = static_cast<MQTTClient::ReadingType>(ui.cbReadingType->currentIndex());
-
-	client->setComment(fileName());
-	currentFileFilter();
-	client->setFilter(static_cast<AsciiFilter*>(m_currentFilter.release())); // pass ownership of the filter to MQTTClient
-
-	client->setReadingType(readingType);
-
-	if (updateType == MQTTClient::UpdateType::TimeInterval)
-		client->setUpdateInterval(ui.sbUpdateInterval->value());
-
-	client->setKeepNValues(ui.sbKeepNValues->value());
-	client->setUpdateType(updateType);
-
-	if (readingType != MQTTClient::ReadingType::TillEnd)
-		client->setSampleSize(ui.sbSampleSize->value());
-
-	client->setMQTTClientHostPort(m_client->hostname(), m_client->port());
-
-	KConfig config(m_configPath, KConfig::SimpleConfig);
-	KConfigGroup group = config.group(ui.cbConnection->currentText());
-
-	bool useID = group.readEntry("UseID").toUInt();
-	bool useAuthentication = group.readEntry("UseAuthentication").toUInt();
-
-	client->setMQTTUseAuthentication(useAuthentication);
-	if (useAuthentication)
-		client->setMQTTClientAuthentication(m_client->username(), m_client->password());
-
-	client->setMQTTUseID(useID);
-	if (useID)
-		client->setMQTTClientId(m_client->clientId());
-
-	for (int i = 0; i < m_mqttSubscriptions.count(); ++i)
-		client->addInitialMQTTSubscriptions(m_mqttSubscriptions[i]->topic(), m_mqttSubscriptions[i]->qos());
-
-	const bool retain = group.readEntry("Retain").toUInt();
-	client->setMQTTRetain(retain);
-
-	if (m_willSettings.enabled)
-		client->setWillSettings(m_willSettings);
-}
-#endif
-
 /*!
 	returns the currently used file type.
 */
@@ -872,69 +811,6 @@ void ImportFileWidget::setMQTTVisible(bool visible) {
 	ui.bLWT->setVisible(visible);
 }
 
-#ifdef HAVE_MQTT
-/*!
- * returns \c true if there is a valid connection to an MQTT broker and the user has subscribed to at least 1 topic,
- * returns \c false otherwise.
- */
-bool ImportFileWidget::isMqttValid() {
-	if (!m_client)
-		return false;
-
-	bool connected = (m_client->state() == QMqttClient::ClientState::Connected);
-	bool subscribed = (m_subscriptionWidget->subscriptionCount() > 0);
-	bool fileTypeOk = false;
-	if (this->currentFileType() == AbstractFileFilter::FileType::Ascii)
-		fileTypeOk = true;
-
-	return connected && subscribed && fileTypeOk;
-}
-
-/*!
- *\brief Unsubscribes from the given topic, and removes any data connected to it
- *
- * \param topicName the name of a topic we want to unsubscribe from
- */
-void ImportFileWidget::unsubscribeFromTopic(const QString& topicName, QVector<QTreeWidgetItem*> children) {
-	if (topicName.isEmpty())
-		return;
-
-	QMqttTopicFilter filter{topicName};
-	m_client->unsubscribe(filter);
-
-	for (int i = 0; i< m_mqttSubscriptions.count(); ++i)
-		if (m_mqttSubscriptions[i]->topic().filter() == topicName) {
-			m_mqttSubscriptions.remove(i);
-			break;
-		}
-
-	QMapIterator<QMqttTopicName, QMqttMessage> j(m_lastMessage);
-	while (j.hasNext()) {
-		j.next();
-        if (MQTTSubscriptionWidget::checkTopicContains(topicName, j.key().name()))
-			m_lastMessage.remove(j.key());
-	}
-
-	for (int i = 0; i < m_subscribedTopicNames.size(); ++i) {
-        if (MQTTSubscriptionWidget::checkTopicContains(topicName, m_subscribedTopicNames[i])) {
-			m_subscribedTopicNames.remove(i);
-			i--;
-		}
-	}
-
-	if (m_willSettings.willTopic == topicName) {
-		if (m_subscriptionWidget->subscriptionCount() > 0)
-			m_willSettings.willTopic = children[0]->text(0);
-		else
-			m_willSettings.willTopic.clear();
-	}
-
-	//signals that there was a change among the subscribed topics
-	emit subscriptionsChanged();
-	refreshPreview();
-}
-#endif
-
 /************** SLOTS **************************************************************/
 /*!
 	called on file name changes.
@@ -946,11 +822,6 @@ void ImportFileWidget::fileNameChanged(const QString& name) {
 	const QString fileName = absolutePath(name);
 
 	bool fileExists = QFile::exists(fileName);
-	if (fileExists)
-		m_cbFileName->setStyleSheet(QString());
-	else
-		m_cbFileName->setStyleSheet("QComboBox{background:red;}");
-
 	ui.gbOptions->setEnabled(fileExists);
 	ui.bManageFilters->setEnabled(fileExists);
 	ui.cbFilter->setEnabled(fileExists);
@@ -1138,15 +1009,13 @@ void ImportFileWidget::initOptionsWidget() {
 			QWidget* asciiw = new QWidget();
 			m_asciiOptionsWidget = std::unique_ptr<AsciiOptionsWidget>(new AsciiOptionsWidget(asciiw));
 			m_asciiOptionsWidget->loadSettings();
+
+			//allow to add timestamp column for live data sources
+			if (m_liveDataSource)
+				m_asciiOptionsWidget->showTimestampOptions(true);
 			ui.swOptions->addWidget(asciiw);
 		}
 
-		//for MQTT topics we don't allow to set the vector names since the different topics
-		//can have different number of columns
-		bool isMQTT = (currentSourceType() == LiveDataSource::SourceType::MQTT);
-		m_asciiOptionsWidget->showAsciiHeaderOptions(!isMQTT);
-		m_asciiOptionsWidget->showTimestampOptions(isMQTT);
-
 		ui.swOptions->setCurrentWidget(m_asciiOptionsWidget->parentWidget());
 		break;
 	}
@@ -1449,7 +1318,6 @@ void ImportFileWidget::refreshPreview() {
 			DEBUG("	extension name = " << STDSTRING(extensionName));
 			fileName = extensionName;
 		}
-		DEBUG("	file name = " << STDSTRING(fileName));
 
 		bool readFitsTableToMatrix;
 		importedStrings = filter->readChdu(fileName, &readFitsTableToMatrix, lines);
@@ -1550,8 +1418,6 @@ void ImportFileWidget::refreshPreview() {
 	} else
 		m_fileEmpty = true;
 
-	emit previewRefreshed();
-
 	RESET_CURSOR;
 }
 
@@ -1634,6 +1500,13 @@ void ImportFileWidget::readingTypeChanged(int idx) {
 void ImportFileWidget::sourceTypeChanged(int idx) {
 	const auto sourceType = static_cast<LiveDataSource::SourceType>(idx);
 
+#ifdef HAVE_MQTT
+	//when switching from mqtt to another source type, make sure we disconnect from
+	//the current broker, if connected, in order not to get any notification anymore
+	if (sourceType != LiveDataSource::SourceType::MQTT)
+		disconnectMqttConnection();
+#endif
+
 	// enable/disable "on new data"-option
 	const auto* model = qobject_cast<const QStandardItemModel*>(ui.cbUpdateType->model());
 	QStandardItem* item = model->item(static_cast<int>(LiveDataSource::UpdateType::NewData));
@@ -1850,6 +1723,17 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
 		item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
 	}
 
+	//disable the header options for non-file sources because:
+	//* for sockets we allow to import one single value only at the moment
+	//* for MQTT topics we don't allow to set the vector names since the different topics can have different number of columns
+	//For files this option still can be usefull if the user have to re-read the whole file
+	//and wants to use the header to set the column names or the user provides manually the column names.
+	//TODO: adjust this logic later once we allow to import multiple columns from sockets,
+	//it should be possible to provide the names of the columns
+	bool visible = (currentSourceType() == LiveDataSource::SourceType::FileOrPipe);
+	if (m_asciiOptionsWidget)
+		m_asciiOptionsWidget->showAsciiHeaderOptions(visible);
+
 	emit sourceTypeChanged();
 	refreshPreview();
 }
@@ -1861,19 +1745,18 @@ void ImportFileWidget::sourceTypeChanged(int idx) {
  * connects to the MQTT broker according to the connection settings.
  */
 void ImportFileWidget::mqttConnectionChanged() {
-	if (m_initialisingMQTT || ui.cbConnection->currentIndex() == -1)
+	if (m_initialisingMQTT || ui.cbConnection->currentIndex() == -1) {
+		ui.lLWT->hide();
+		ui.bLWT->hide();
+		ui.lTopics->hide();
 		return;
+	}
 
 	WAIT_CURSOR;
+	emit error(QString());
 
-	//disconnected from the broker that was selected before, if this is the case
-	if (m_client && m_client->state() == QMqttClient::ClientState::Connected) {
-		emit MQTTClearTopics();
-		disconnect(m_client, &QMqttClient::disconnected, this, &ImportFileWidget::onMqttDisconnect);
-		QDEBUG("Disconnecting from " << m_client->hostname());
-		m_client->disconnectFromHost();
-		delete m_client;
-	}
+	//disconnected from the broker that was selected before
+	disconnectMqttConnection();
 
 	//determine the connection settings for the new broker and initialize the mqtt client
 	KConfig config(m_configPath, KConfig::SimpleConfig);
@@ -1900,24 +1783,65 @@ void ImportFileWidget::mqttConnectionChanged() {
 
 	//connect to the selected broker
 	QDEBUG("Connect to " << m_client->hostname() << ":" << m_client->port());
+	if (!m_connectTimeoutTimer) {
+		m_connectTimeoutTimer = new QTimer(this);
+		m_connectTimeoutTimer->setInterval(6000);
+		connect(m_connectTimeoutTimer, &QTimer::timeout, this, &ImportFileWidget::mqttConnectTimeout);
+	}
 	m_connectTimeoutTimer->start();
 	m_client->connectToHost();
 }
 
+void ImportFileWidget::disconnectMqttConnection() {
+	if (m_client && m_client->state() == QMqttClient::ClientState::Connected) {
+		emit MQTTClearTopics();
+		disconnect(m_client, &QMqttClient::disconnected, this, &ImportFileWidget::onMqttDisconnect);
+		QDEBUG("Disconnecting from " << m_client->hostname());
+		m_client->disconnectFromHost();
+		delete m_client;
+		m_client = nullptr;
+	}
+}
+
+/*!
+ * returns \c true if there is a valid connection to an MQTT broker and the user has subscribed to at least 1 topic,
+ * returns \c false otherwise.
+ */
+bool ImportFileWidget::isMqttValid() {
+	if (!m_client)
+		return false;
+
+	bool connected = (m_client->state() == QMqttClient::ClientState::Connected);
+	bool subscribed = (m_subscriptionWidget->subscriptionCount() > 0);
+	bool fileTypeOk = false;
+	if (this->currentFileType() == AbstractFileFilter::FileType::Ascii)
+		fileTypeOk = true;
+
+	return connected && subscribed && fileTypeOk;
+}
+
 /*!
  *\brief called when the client connects to the broker successfully.
  * subscribes to every topic (# wildcard) in order to later list every available topic
  */
 void ImportFileWidget::onMqttConnect() {
+	m_connectTimeoutTimer->stop();
 	if (m_client->error() == QMqttClient::NoError) {
-		m_connectTimeoutTimer->stop();
 		ui.frameSubscriptions->setVisible(true);
 		m_subscriptionWidget->setVisible(true);
 		m_subscriptionWidget->makeVisible(true);
 
 		if (!m_client->subscribe(QMqttTopicFilter(QLatin1String("#")), 1))
-			QMessageBox::critical(this, i18n("Couldn't subscribe"), i18n("Couldn't subscribe to all available topics. Something went wrong"));
-	}
+			emit error(i18n("Couldn't subscribe to all available topics."));
+		else {
+			emit error(QString());
+			ui.lLWT->show();
+			ui.bLWT->show();
+			ui.lTopics->show();
+		}
+	} else
+		emit error("on mqtt connect error " + QString::number(m_client->error()));
+
 	emit subscriptionsChanged();
 	RESET_CURSOR;
 }
@@ -1935,19 +1859,18 @@ void ImportFileWidget::onMqttDisconnect() {
 	ui.lLWT->hide();
 	ui.bLWT->hide();
 
-	ui.cbConnection->setItemText(ui.cbConnection->currentIndex(), ui.cbConnection->currentText() + ' ' + i18n("(Disconnected)"));
+	ui.cbConnection->setCurrentIndex(-1);
 
 	emit subscriptionsChanged();
+	emit error(i18n("Disconnected from '%1'.", m_client->hostname()));
 	RESET_CURSOR;
-	QMessageBox::critical(this, i18n("Disconnected"),
-		i18n("Disconnected from the broker '%1' before the connection was successful.", m_client->hostname()));
 }
 
 /*!
  *\brief called when the subscribe button is pressed
  * subscribes to the topic represented by the current item of twTopics
  */
-void ImportFileWidget::mqttSubscribe(const QString& name, uint QoS) {
+void ImportFileWidget::subscribeTopic(const QString& name, uint QoS) {
 	const QMqttTopicFilter filter {name};
 	QMqttSubscription* tempSubscription = m_client->subscribe(filter, static_cast<quint8>(QoS) );
 
@@ -1958,6 +1881,46 @@ void ImportFileWidget::mqttSubscribe(const QString& name, uint QoS) {
 	}
 }
 
+/*!
+ *\brief Unsubscribes from the given topic, and removes any data connected to it
+ *
+ * \param topicName the name of a topic we want to unsubscribe from
+ */
+void ImportFileWidget::unsubscribeTopic(const QString& topicName, QVector<QTreeWidgetItem*> children) {
+	if (topicName.isEmpty())
+		return;
+
+	for (int i = 0; i< m_mqttSubscriptions.count(); ++i) {
+		if (m_mqttSubscriptions[i]->topic().filter() == topicName) {
+			//explicitely disconnect from the signal, callling QMqttClient::unsubscribe() below is not enough
+			disconnect(m_mqttSubscriptions.at(i), &QMqttSubscription::messageReceived, this, &ImportFileWidget::mqttSubscriptionMessageReceived);
+			m_mqttSubscriptions.remove(i);
+			break;
+		}
+	}
+
+	QMqttTopicFilter filter{topicName};
+	m_client->unsubscribe(filter);
+
+	QMapIterator<QMqttTopicName, QMqttMessage> j(m_lastMessage);
+	while (j.hasNext()) {
+		j.next();
+        if (MQTTSubscriptionWidget::checkTopicContains(topicName, j.key().name()))
+			m_lastMessage.remove(j.key());
+	}
+
+	if (m_willSettings.willTopic == topicName) {
+		if (m_subscriptionWidget->subscriptionCount() > 0)
+			m_willSettings.willTopic = children[0]->text(0);
+		else
+			m_willSettings.willTopic.clear();
+	}
+
+	//signals that there was a change among the subscribed topics
+	emit subscriptionsChanged();
+	refreshPreview();
+}
+
 /*!
  *\brief called when the client receives a message
  * if the message arrived from a new topic, the topic is put in twTopics
@@ -1991,7 +1954,7 @@ void ImportFileWidget::mqttMessageReceived(const QByteArray& message, const QMqt
 
 			//if not we simply add every level of the topic to the tree
 			if (topItemIdx < 0) {
-				QTreeWidgetItem* currentItem = new QTreeWidgetItem(name);
+				auto* currentItem = new QTreeWidgetItem(name);
 				m_subscriptionWidget->addTopic(currentItem);
 				for (int i = 1; i < list.size(); ++i) {
 					name.clear();
@@ -2039,12 +2002,12 @@ void ImportFileWidget::mqttMessageReceived(const QByteArray& message, const QMqt
 
 	//if a subscribed topic contains the new topic, we have to update twSubscriptions
 	for (int i = 0; i < m_subscriptionWidget->subscriptionCount(); ++i) {
-		const QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split('/', QString::SkipEmptyParts);
+		const QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split(sep, QString::SkipEmptyParts);
 		if (!subscriptionName.isEmpty()) {
 			if (rootName == subscriptionName.first()) {
 				QVector<QString> subscriptions;
-				for(int i = 0; i < m_mqttSubscriptions.size(); ++i)
-					subscriptions.push_back(m_mqttSubscriptions[i]->topic().filter());
+				for (const auto& sub : m_mqttSubscriptions)
+					subscriptions.push_back(sub->topic().filter());
 				emit updateSubscriptionTree(subscriptions);
 				break;
 			}
@@ -2061,9 +2024,6 @@ void ImportFileWidget::mqttMessageReceived(const QByteArray& message, const QMqt
 void ImportFileWidget::mqttSubscriptionMessageReceived(const QMqttMessage &msg) {
 	QDEBUG("message received from: " << msg.topic().name());
 
-	if (!m_subscribedTopicNames.contains(msg.topic().name()))
-		m_subscribedTopicNames.push_back(msg.topic().name());
-
 	//update the last message for the topic
 	m_lastMessage[msg.topic()] = msg;
 }
@@ -2076,29 +2036,32 @@ void ImportFileWidget::mqttSubscriptionMessageReceived(const QMqttMessage &msg)
 void ImportFileWidget::mqttErrorChanged(QMqttClient::ClientError clientError) {
 	switch (clientError) {
 	case QMqttClient::BadUsernameOrPassword:
-		QMessageBox::critical(this, i18n("Couldn't connect"), i18n("Wrong username or password"));
+		emit error(i18n("Wrong username or password"));
 		break;
 	case QMqttClient::IdRejected:
-		QMessageBox::critical(this, i18n("Couldn't connect"), i18n("The client ID wasn't accepted"));
+		emit error(i18n("The client ID wasn't accepted"));
 		break;
 	case QMqttClient::ServerUnavailable:
-		QMessageBox::critical(this, i18n("Server unavailable"), i18n("The broker couldn't be reached."));
+	case QMqttClient::TransportInvalid:
+		emit error(i18n("The broker %1 couldn't be reached.", m_client->hostname()));
 		break;
 	case QMqttClient::NotAuthorized:
-		QMessageBox::critical(this, i18n("Not authorized"), i18n("The client is not authorized to connect."));
+		emit error(i18n("The client is not authorized to connect."));
 		break;
 	case QMqttClient::UnknownError:
-		QMessageBox::critical(this, i18n("Unknown MQTT error"), i18n("An unknown error occurred."));
+		emit error(i18n("An unknown error occurred."));
 		break;
 	case QMqttClient::NoError:
 	case QMqttClient::InvalidProtocolVersion:
-	case QMqttClient::TransportInvalid:
 	case QMqttClient::ProtocolViolation:
 	case QMqttClient::Mqtt5SpecificError:
+		emit error(i18n("An error occurred."));
 		break;
 	default:
+		emit error(i18n("An error occurred."));
 		break;
 	}
+	m_connectTimeoutTimer->stop();
 }
 
 /*!
@@ -2107,11 +2070,10 @@ void ImportFileWidget::mqttErrorChanged(QMqttClient::ClientError clientError) {
  *		 disconnects the client, stops the timer, and warns the user
  */
 void ImportFileWidget::mqttConnectTimeout() {
-	m_connectionTimedOut = true;
 	m_client->disconnectFromHost();
 	m_connectTimeoutTimer->stop();
+	emit error(i18n("Connecting to '%1:%2' timed out.", m_client->hostname(), m_client->port()));
 	RESET_CURSOR;
-	QMessageBox::warning(this, i18n("Warning"), i18n("Connecting to the given broker timed out! Try changing the settings"));
 }
 
 /*!
@@ -2120,7 +2082,7 @@ void ImportFileWidget::mqttConnectTimeout() {
 */
 void ImportFileWidget::showMQTTConnectionManager() {
 	bool previousConnectionChanged = false;
-	MQTTConnectionManagerDialog* dlg = new MQTTConnectionManagerDialog(this, ui.cbConnection->currentText(), previousConnectionChanged);
+	auto* dlg = new MQTTConnectionManagerDialog(this, ui.cbConnection->currentText(), previousConnectionChanged);
 
 	if (dlg->exec() == QDialog::Accepted) {
 		//re-read the available connections to be in sync with the changes in MQTTConnectionManager
@@ -2174,8 +2136,8 @@ void ImportFileWidget::showWillSettings() {
 		MQTTSubscriptionWidget::findSubscriptionLeafChildren(children, m_subscriptionWidget->topLevelSubscription(i));
 
 	QVector<QString> topics;
-	for (int i = 0; i < children.size(); ++i)
-		topics.append(children[i]->text(0));
+	for (const auto& child : children)
+		topics.append(child->text(0));
 
 	MQTTWillSettingsWidget willSettingsWidget(&menu, m_willSettings, topics);
 
@@ -2183,7 +2145,7 @@ void ImportFileWidget::showWillSettings() {
 		m_willSettings = willSettingsWidget.will();
 		menu.close();
 	});
-	QWidgetAction* widgetAction = new QWidgetAction(this);
+	auto* widgetAction = new QWidgetAction(this);
 	widgetAction->setDefaultWidget(&willSettingsWidget);
 	menu.addAction(widgetAction);
 
@@ -2192,11 +2154,59 @@ void ImportFileWidget::showWillSettings() {
 }
 
 void ImportFileWidget::enableWill(bool enable) {
-	if(enable) {
-		if(!ui.bLWT->isEnabled())
+	if (enable) {
+		if (!ui.bLWT->isEnabled())
 			ui.bLWT->setEnabled(enable);
 	} else
 		ui.bLWT->setEnabled(enable);
 }
 
+
+/*!
+	saves the settings to the MQTTClient \c client.
+*/
+void ImportFileWidget::saveMQTTSettings(MQTTClient* client) const {
+	DEBUG("ImportFileWidget::saveMQTTSettings");
+	auto updateType = static_cast<MQTTClient::UpdateType>(ui.cbUpdateType->currentIndex());
+	auto readingType = static_cast<MQTTClient::ReadingType>(ui.cbReadingType->currentIndex());
+
+	currentFileFilter();
+	client->setFilter(static_cast<AsciiFilter*>(m_currentFilter.release())); // pass ownership of the filter to MQTTClient
+
+	client->setReadingType(readingType);
+
+	if (updateType == MQTTClient::UpdateType::TimeInterval)
+		client->setUpdateInterval(ui.sbUpdateInterval->value());
+
+	client->setKeepNValues(ui.sbKeepNValues->value());
+	client->setUpdateType(updateType);
+
+	if (readingType != MQTTClient::ReadingType::TillEnd)
+		client->setSampleSize(ui.sbSampleSize->value());
+
+	client->setMQTTClientHostPort(m_client->hostname(), m_client->port());
+
+	KConfig config(m_configPath, KConfig::SimpleConfig);
+	KConfigGroup group = config.group(ui.cbConnection->currentText());
+
+	bool useID = group.readEntry("UseID").toUInt();
+	bool useAuthentication = group.readEntry("UseAuthentication").toUInt();
+
+	client->setMQTTUseAuthentication(useAuthentication);
+	if (useAuthentication)
+		client->setMQTTClientAuthentication(m_client->username(), m_client->password());
+
+	client->setMQTTUseID(useID);
+	if (useID)
+		client->setMQTTClientId(m_client->clientId());
+
+	for (int i = 0; i < m_mqttSubscriptions.count(); ++i)
+		client->addInitialMQTTSubscriptions(m_mqttSubscriptions[i]->topic(), m_mqttSubscriptions[i]->qos());
+
+	const bool retain = group.readEntry("Retain").toUInt();
+	client->setMQTTRetain(retain);
+
+	if (m_willSettings.enabled)
+		client->setWillSettings(m_willSettings);
+}
 #endif
