@@ -25,34 +25,28 @@ Copyright            : (C) 2019 by Kovacs Ferencz (kferike98@gmail.com)
 *                                                                         *
 ***************************************************************************/
 
-
 #include "MQTTSubscriptionWidget.h"
 
-#ifdef HAVE_MQTT
 #include "backend/datasources/MQTTClient.h"
 #include "ImportFileWidget.h"
 #include "kdefrontend/dockwidgets/LiveDataDock.h"
 
-#include <QMqttSubscription>
-#include <QMessageBox>
-#include <KLocalizedString>
 #include <QCompleter>
+#include <QMessageBox>
+#include <QMqttSubscription>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 
+#include <KLocalizedString>
+
 /*!
    \class MQTTSubscriptionWidget
    \brief Widget for managing topics and subscribing.
 
    \ingroup kdefrontend
 */
-MQTTSubscriptionWidget::MQTTSubscriptionWidget( QWidget* parent): QWidget(parent),
-	m_parentWidget(parent),
+MQTTSubscriptionWidget::MQTTSubscriptionWidget(QWidget* parent) : QWidget(parent),
 	m_searchTimer(new QTimer(this)) {
-	if(dynamic_cast<class ImportFileWidget*>(parent) != nullptr)
-		m_parent = MQTTParentWidget::ImportFileWidget;
-	else
-		m_parent = MQTTParentWidget::LiveDataDock;
 
 	ui.setupUi(this);
 
@@ -86,14 +80,18 @@ MQTTSubscriptionWidget::MQTTSubscriptionWidget( QWidget* parent): QWidget(parent
 	            "</ul>");
 	ui.cbQos->setToolTip(info);
 
-	if(m_parent == MQTTParentWidget::ImportFileWidget) {
-		connect(dynamic_cast<class ImportFileWidget*>(m_parentWidget), &ImportFileWidget::newTopic, this, &MQTTSubscriptionWidget::setTopicCompleter);
-		connect(dynamic_cast<class ImportFileWidget*>(m_parentWidget), &ImportFileWidget::updateSubscriptionTree, this, &MQTTSubscriptionWidget::updateSubscriptionTree);
-		connect(dynamic_cast<class ImportFileWidget*>(m_parentWidget), &ImportFileWidget::MQTTClearTopics, this, &MQTTSubscriptionWidget::clearWidgets);
+	auto* importWidget = dynamic_cast<ImportFileWidget*>(parent);
+	if (importWidget) {
+		m_parent = MQTTParentWidget::ImportFileWidget;
+		connect(importWidget, &ImportFileWidget::newTopic, this, &MQTTSubscriptionWidget::setTopicCompleter);
+		connect(importWidget, &ImportFileWidget::updateSubscriptionTree, this, &MQTTSubscriptionWidget::updateSubscriptionTree);
+		connect(importWidget, &ImportFileWidget::MQTTClearTopics, this, &MQTTSubscriptionWidget::clearWidgets);
 	} else {
-		connect(dynamic_cast<class LiveDataDock*>(m_parentWidget), &LiveDataDock::MQTTClearTopics, this, &MQTTSubscriptionWidget::clearWidgets);
-		connect(dynamic_cast<class LiveDataDock*>(m_parentWidget), &LiveDataDock::newTopic, this, &MQTTSubscriptionWidget::setTopicCompleter);
-		connect(dynamic_cast<class LiveDataDock*>(m_parentWidget), &LiveDataDock::updateSubscriptionTree, this, &MQTTSubscriptionWidget::updateSubscriptionTree);
+		auto* liveDock = static_cast<LiveDataDock*>(parent);
+		m_parent = MQTTParentWidget::ImportFileWidget;
+		connect(liveDock, &LiveDataDock::MQTTClearTopics, this, &MQTTSubscriptionWidget::clearWidgets);
+		connect(liveDock, &LiveDataDock::newTopic, this, &MQTTSubscriptionWidget::setTopicCompleter);
+		connect(liveDock, &LiveDataDock::updateSubscriptionTree, this, &MQTTSubscriptionWidget::updateSubscriptionTree);
 	}
 
 	connect(ui.bSubscribe,  &QPushButton::clicked, this, &MQTTSubscriptionWidget::mqttSubscribe);
@@ -120,7 +118,7 @@ MQTTSubscriptionWidget::~MQTTSubscriptionWidget() {
 	delete m_searchTimer;
 }
 
-void MQTTSubscriptionWidget::setTopicList(QStringList topicList) {
+void MQTTSubscriptionWidget::setTopicList(const QStringList& topicList) {
 	m_topicList = topicList;
 }
 
@@ -335,27 +333,28 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 					}
 				}
 				QDEBUG("Manage: " << commonTopics[topicIdx]);
-				equalTopics.append(equalTopicsMap[commonTopics[topicIdx]]);
+				if (topicIdx != -1)
+					equalTopics.append(equalTopicsMap[commonTopics[topicIdx]]);
 
 				//Add the common topic ("merging")
 				QString commonTopic;
 				commonTopic = checkCommonLevel(equalTopics.first(), equalTopics.last());
 				QStringList nameList;
 				nameList.append(commonTopic);
-				QTreeWidgetItem* newTopic = new QTreeWidgetItem(nameList);
+				auto* newTopic = new QTreeWidgetItem(nameList);
 				ui.twSubscriptions->addTopLevelItem(newTopic);
 
-				if(m_parent == MQTTParentWidget::ImportFileWidget)
+				if (m_parent == MQTTParentWidget::ImportFileWidget)
 					emit makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
 
 				//remove the "merged" topics
-				for (int i = 0; i < equalTopics.size(); ++i) {
+				for (const auto& topic : equalTopics) {
 					for (int j = 0; j < ui.twSubscriptions->topLevelItemCount(); ++j) {
-						if (ui.twSubscriptions->topLevelItem(j)->text(0) == equalTopics[i]) {
+						if (ui.twSubscriptions->topLevelItem(j)->text(0) == topic) {
 							newTopic->addChild(ui.twSubscriptions->takeTopLevelItem(j));
 
-							if(m_parent == MQTTParentWidget::ImportFileWidget)
-								unsubscribeFromTopic(equalTopics[i]);
+							if (m_parent == MQTTParentWidget::ImportFileWidget)
+								unsubscribeFromTopic(topic);
 
 							break;
 						}
@@ -366,7 +365,7 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				for (int i = 0; i < ui.twSubscriptions->topLevelItemCount(); ++i) {
 					if (checkTopicContains(commonTopic, ui.twSubscriptions->topLevelItem(i)->text(0)) &&
 					        commonTopic != ui.twSubscriptions->topLevelItem(i)->text(0) ) {
-						if(m_parent == MQTTParentWidget::ImportFileWidget)
+						if (m_parent == MQTTParentWidget::ImportFileWidget)
 							unsubscribeFromTopic(ui.twSubscriptions->topLevelItem(i)->text(0));
 						else {
 							ui.twSubscriptions->topLevelItem(i)->takeChildren();
@@ -376,7 +375,7 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 					}
 				}
 
-				if(m_parent == MQTTParentWidget::LiveDataDock)
+				if (m_parent == MQTTParentWidget::LiveDataDock)
 					emit makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
 			}
 		}
@@ -390,13 +389,13 @@ void MQTTSubscriptionWidget::updateSubscriptionTree(const QVector<QString>& mqtt
 	DEBUG("ImportFileWidget::updateSubscriptionTree()");
 	ui.twSubscriptions->clear();
 
-	for (int i = 0; i < mqttSubscriptions.size(); ++i) {
+	for (const auto& sub : mqttSubscriptions) {
 		QStringList name;
-		name.append(mqttSubscriptions[i]);
+		name.append(sub);
 
 		bool found = false;
 		for (int j = 0; j < ui.twSubscriptions->topLevelItemCount(); ++j) {
-			if (ui.twSubscriptions->topLevelItem(j)->text(0) == mqttSubscriptions[i]) {
+			if (ui.twSubscriptions->topLevelItem(j)->text(0) == sub) {
 				found = true;
 				break;
 			}
@@ -404,10 +403,10 @@ void MQTTSubscriptionWidget::updateSubscriptionTree(const QVector<QString>& mqtt
 
 		if (!found) {
 			//Add the subscription to the tree widget
-			QTreeWidgetItem* newItem = new QTreeWidgetItem(name);
+			auto* newItem = new QTreeWidgetItem(name);
 			ui.twSubscriptions->addTopLevelItem(newItem);
 			name.clear();
-			name = mqttSubscriptions[i].split('/', QString::SkipEmptyParts);
+			name = sub.split('/', QString::SkipEmptyParts);
 
 			//find the corresponding "root" item in twTopics
 			QTreeWidgetItem* topic = nullptr;
@@ -461,7 +460,7 @@ void MQTTSubscriptionWidget::addSubscriptionChildren(QTreeWidgetItem* topic, QTr
 
 		QStringList nameList;
 		nameList.append(name);
-		QTreeWidgetItem* childItem = new QTreeWidgetItem(nameList);
+		auto* childItem = new QTreeWidgetItem(nameList);
 		subscription->addChild(childItem);
 		//we use the function recursively on the given item
 		addSubscriptionChildren(topic->child(i), childItem);
@@ -502,7 +501,7 @@ void MQTTSubscriptionWidget::restoreSubscriptionChildren(QTreeWidgetItem * topic
 			//Add the topic as child of the subscription
 			QStringList nameList;
 			nameList.append(name);
-			QTreeWidgetItem* newItem = new QTreeWidgetItem(nameList);
+			auto* newItem = new QTreeWidgetItem(nameList);
 			subscription->addChild(newItem);
 			//Continue adding children recursively to the new item
 			restoreSubscriptionChildren(topic->child(i), newItem, list, level + 1);
@@ -757,7 +756,7 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 			//if the new subscirptions contains an already existing one, we remove the inferior one
 			if (checkTopicContains(name, ui.twSubscriptions->topLevelItem(i)->text(0))
 			        && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
-				if(m_parent == MQTTParentWidget::ImportFileWidget)
+				if (m_parent == MQTTParentWidget::ImportFileWidget)
 					unsubscribeFromTopic(ui.twSubscriptions->topLevelItem(i)->text(0));
 				else {
 					ui.twSubscriptions->topLevelItem(i)->takeChildren();
@@ -780,7 +779,7 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 		if (!foundSuperior) {
 			QStringList toplevelName;
 			toplevelName.push_back(name);
-			QTreeWidgetItem* newTopLevelItem = new QTreeWidgetItem(toplevelName);
+			auto* newTopLevelItem = new QTreeWidgetItem(toplevelName);
 			ui.twSubscriptions->addTopLevelItem(newTopLevelItem);
 
 			if (name.endsWith('#')) {
@@ -803,15 +802,15 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 						children.clear();
 						//get the "leaf" children of the inspected subscription
 						findSubscriptionLeafChildren(children, ui.twSubscriptions->topLevelItem(i));
-						for (int j = 0; j < children.size(); ++j) {
-							if (checkTopicContains(name, children[j]->text(0))) {
+						for (const auto& child : children) {
+							if (checkTopicContains(name, child->text(0))) {
 								//if the new subscription contains a topic, we unsubscribe from it
-								if(m_parent == MQTTParentWidget::ImportFileWidget) {
-									ui.twSubscriptions->setCurrentItem(children[j]);
+								if (m_parent == MQTTParentWidget::ImportFileWidget) {
+									ui.twSubscriptions->setCurrentItem(child);
 									mqttUnsubscribe();
 									--i;
 								} else {
-									QTreeWidgetItem* unsubscribeItem = children[j];
+									QTreeWidgetItem* unsubscribeItem = child;
 									while (unsubscribeItem->parent() != nullptr) {
 										for (int i = 0; i < unsubscribeItem->parent()->childCount(); ++i) {
 											const QString& childText = unsubscribeItem->parent()->child(i)->text(0);
@@ -831,7 +830,7 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 										unsubscribeItem = unsubscribeItem->parent();
 									}
 
-									qDebug()<<"Remove: "<<unsubscribeItem->text(0);
+									qDebug() << "Remove: " << unsubscribeItem->text(0);
 									emit removeMQTTSubscription(unsubscribeItem->text(0));
 
 									ui.twSubscriptions->takeTopLevelItem(ui.twSubscriptions->indexOfTopLevelItem(unsubscribeItem));
@@ -885,7 +884,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 	//if it is a top level item, meaning a topic that we really subscribed to(not one that belongs to a subscription)
 	//we can simply unsubscribe from it
 	if (unsubscribeItem->parent() == nullptr) {
-		if(m_parent == MQTTParentWidget::ImportFileWidget)
+		if (m_parent == MQTTParentWidget::ImportFileWidget)
 			unsubscribeFromTopic(unsubscribeItem->text(0));
 		else {
 			emit removeMQTTSubscription(unsubscribeItem->text(0));
@@ -901,7 +900,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 				const QString& childText = unsubscribeItem->parent()->child(i)->text(0);
 				if (unsubscribeItem->text(0) != childText) {
 					quint8 qos = static_cast<quint8>(ui.cbQos->currentText().toUInt());
-					if(m_parent == MQTTParentWidget::ImportFileWidget)
+					if (m_parent == MQTTParentWidget::ImportFileWidget)
 						emit makeSubscription(childText, qos);
 					else
 						emit addBeforeRemoveSubscription(childText, qos);
@@ -913,7 +912,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 			unsubscribeItem = unsubscribeItem->parent();
 		}
 
-		if(m_parent == MQTTParentWidget::ImportFileWidget)
+		if (m_parent == MQTTParentWidget::ImportFileWidget)
 			unsubscribeFromTopic(unsubscribeItem->text(0));
 		else {
 			emit removeMQTTSubscription(unsubscribeItem->text(0));
@@ -1015,4 +1014,3 @@ void MQTTSubscriptionWidget::onDisconnect() {
 	delete m_topicCompleter;
 	delete m_subscriptionCompleter;
 }
-#endif
