@@ -44,7 +44,6 @@
 #include <QPainter>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KSharedConfig>
 
 extern "C" {
 #include <gsl/gsl_math.h>
@@ -210,6 +209,9 @@ AxisDock::AxisDock(QWidget* parent) : BaseDock(parent) {
 			this, &AxisDock::labelsRotationChanged);
 	connect(ui.kfrLabelsFont, &KFontRequester::fontSelected, this, &AxisDock::labelsFontChanged);
 	connect(ui.kcbLabelsFontColor, &KColorButton::changed, this, &AxisDock::labelsFontColorChanged);
+	connect(ui.cbLabelsBackgroundType, QOverload<int>::of(&QComboBox::currentIndexChanged),
+			this, &AxisDock::labelsBackgroundTypeChanged);
+	connect(ui.kcbLabelsBackgroundColor, &KColorButton::changed, this, &AxisDock::labelsBackgroundColorChanged);
 	connect(ui.leLabelsPrefix, &QLineEdit::textChanged, this, &AxisDock::labelsPrefixChanged);
 	connect(ui.leLabelsSuffix, &QLineEdit::textChanged, this, &AxisDock::labelsSuffixChanged);
 	connect(ui.sbLabelsOpacity, QOverload<int>::of(&QSpinBox::valueChanged),
@@ -329,8 +331,8 @@ void AxisDock::init() {
 	pa.setRenderHint(QPainter::Antialiasing);
 	pa.setBrush(Qt::SolidPattern);
 	pa.drawLine(3, 10, 17, 10);
-	//TODO: QPolygon?
-	QPointF points3[3] = {QPointF(17, 10), QPointF(10, 10-4*cos_phi), QPointF(10, 10+4*cos_phi) };
+	//TODO: use QPolygon?
+	QPointF points3[3] = { QPointF(17, 10), QPointF(10, 10-4*cos_phi), QPointF(10, 10+4*cos_phi) };
 	pa.drawPolygon(points3, 3);
 	pa.end();
 	ui.cbArrowType->setItemIcon(3, pm);
@@ -341,7 +343,7 @@ void AxisDock::init() {
 	pa.setRenderHint(QPainter::Antialiasing);
 	pa.setBrush(Qt::SolidPattern);
 	pa.drawLine(3, 10, 17, 10);
-	QPointF points4[3] = {QPointF(17, 10), QPointF(10, 10-10*cos_phi), QPointF(10, 10+10*cos_phi) };
+	QPointF points4[3] = { QPointF(17, 10), QPointF(10, 10-10*cos_phi), QPointF(10, 10+10*cos_phi) };
 	pa.drawPolygon(points4, 3);
 	pa.end();
 	ui.cbArrowType->setItemIcon(4, pm);
@@ -352,7 +354,7 @@ void AxisDock::init() {
 	pa.setRenderHint(QPainter::Antialiasing);
 	pa.setBrush(Qt::SolidPattern);
 	pa.drawLine(3, 10, 17, 10);
-	QPointF points5[4] = {QPointF(17, 10), QPointF(10, 10-4*cos_phi), QPointF(13, 10), QPointF(10, 10+4*cos_phi) };
+	QPointF points5[4] = { QPointF(17, 10), QPointF(10, 10-4*cos_phi), QPointF(13, 10), QPointF(10, 10+4*cos_phi) };
 	pa.drawPolygon(points5, 4);
 	pa.end();
 	ui.cbArrowType->setItemIcon(5, pm);
@@ -363,7 +365,7 @@ void AxisDock::init() {
 	pa.setRenderHint(QPainter::Antialiasing);
 	pa.setBrush(Qt::SolidPattern);
 	pa.drawLine(3, 10, 17, 10);
-	QPointF points6[4] = {QPointF(17, 10), QPointF(10, 10-10*cos_phi), QPointF(13, 10), QPointF(10, 10+10*cos_phi) };
+	QPointF points6[4] = { QPointF(17, 10), QPointF(10, 10-10*cos_phi), QPointF(13, 10), QPointF(10, 10+10*cos_phi) };
 	pa.drawPolygon(points6, 4);
 	pa.end();
 	ui.cbArrowType->setItemIcon(6, pm);
@@ -409,6 +411,9 @@ void AxisDock::init() {
 	ui.cbLabelsFormat->addItem( i18n("Multiples of π") );
 
 	ui.cbLabelsDateTimeFormat->addItems(AbstractColumn::dateTimeFormats());
+
+	ui.cbLabelsBackgroundType->addItem(i18n("Transparent"));
+	ui.cbLabelsBackgroundType->addItem(i18n("Color"));
 }
 
 void AxisDock::setModel() {
@@ -508,6 +513,8 @@ void AxisDock::setAxes(QList<Axis*> list) {
 	connect(m_axis, &Axis::labelsRotationAngleChanged, this, &AxisDock::axisLabelsRotationAngleChanged);
 	connect(m_axis, &Axis::labelsFontChanged, this, &AxisDock::axisLabelsFontChanged);
 	connect(m_axis, &Axis::labelsColorChanged, this, &AxisDock::axisLabelsFontColorChanged);
+	connect(m_axis, &Axis::labelsBackgroundTypeChanged, this, &AxisDock::axisLabelsBackgroundTypeChanged);
+	connect(m_axis, &Axis::labelsBackgroundColorChanged, this, &AxisDock::axisLabelsBackgroundColorChanged);
 	connect(m_axis, &Axis::labelsPrefixChanged, this, &AxisDock::axisLabelsPrefixChanged);
 	connect(m_axis, &Axis::labelsSuffixChanged, this, &AxisDock::axisLabelsSuffixChanged);
 	connect(m_axis, &Axis::labelsOpacityChanged, this, &AxisDock::axisLabelsOpacityChanged);
@@ -798,6 +805,9 @@ void AxisDock::scalingFactorChanged() {
 
 // "Line"-tab
 void AxisDock::lineStyleChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto penStyle = Qt::PenStyle(index);
 
 	bool b = (penStyle != Qt::NoPen);
@@ -910,8 +920,11 @@ void AxisDock::majorTicksDirectionChanged(int index) {
 	ui.cbMajorTicksLineStyle->setEnabled(b);
 	dtsbMinorTicksIncrement->setEnabled(b);
 	if (b) {
-		auto penStyle = Qt::PenStyle(ui.cbMajorTicksLineStyle->currentIndex());
-		b = (penStyle != Qt::NoPen);
+		if (ui.cbMajorTicksLineStyle->currentIndex() != -1) {
+			auto penStyle = Qt::PenStyle(ui.cbMajorTicksLineStyle->currentIndex());
+			b = (penStyle != Qt::NoPen);
+		} else
+			b = false;
 	}
 	ui.lMajorTicksColor->setEnabled(b);
 	ui.kcbMajorTicksColor->setEnabled(b);
@@ -1039,6 +1052,9 @@ void AxisDock::majorTicksSpacingChanged() {
 }
 
 void AxisDock::majorTicksLineStyleChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto penStyle = Qt::PenStyle(index);
 
 	bool b = (penStyle != Qt::NoPen);
@@ -1139,8 +1155,11 @@ void AxisDock::minorTicksDirectionChanged(int index) {
 	ui.lMinorTicksLineStyle->setEnabled(b);
 	ui.cbMinorTicksLineStyle->setEnabled(b);
 	if (b) {
-		auto penStyle = Qt::PenStyle(ui.cbMinorTicksLineStyle->currentIndex());
-		b = (penStyle != Qt::NoPen);
+		if (ui.cbMinorTicksLineStyle->currentIndex() != -1) {
+			auto penStyle = Qt::PenStyle(ui.cbMinorTicksLineStyle->currentIndex());
+			b = (penStyle != Qt::NoPen);
+		} else
+			b = false;
 	}
 	ui.lMinorTicksColor->setEnabled(b);
 	ui.kcbMinorTicksColor->setEnabled(b);
@@ -1284,6 +1303,9 @@ void AxisDock::minorTicksColumnChanged(const QModelIndex& index) {
 }
 
 void AxisDock::minorTicksLineStyleChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto penStyle = Qt::PenStyle(index);
 
 	bool b = (penStyle != Qt::NoPen);
@@ -1467,6 +1489,28 @@ void AxisDock::labelsFontColorChanged(const QColor& color) {
 		axis->setLabelsColor(color);
 }
 
+void AxisDock::labelsBackgroundTypeChanged(int index) {
+	auto type = Axis::LabelsBackgroundType(index);
+
+	bool transparent = (type == Axis::LabelsBackgroundType::Transparent);
+	ui.lLabelsBackgroundColor->setVisible(!transparent);
+	ui.kcbLabelsBackgroundColor->setVisible(!transparent);
+
+	if (m_initializing)
+		return;
+
+	for (auto* axis : m_axesList)
+		axis->setLabelsBackgroundType(type);
+}
+
+void AxisDock::labelsBackgroundColorChanged(const QColor& color) {
+	if (m_initializing)
+		return;
+
+	for (auto* axis : m_axesList)
+		axis->setLabelsBackgroundColor(color);
+}
+
 void AxisDock::labelsOpacityChanged(int value) {
 	if (m_initializing)
 		return;
@@ -1479,6 +1523,9 @@ void AxisDock::labelsOpacityChanged(int value) {
 // "Grid"-tab
 //major grid
 void AxisDock::majorGridStyleChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto penStyle = Qt::PenStyle(index);
 
 	bool b = (penStyle != Qt::NoPen);
@@ -1539,6 +1586,9 @@ void AxisDock::majorGridOpacityChanged(int value) {
 
 //minor grid
 void AxisDock::minorGridStyleChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto penStyle = Qt::PenStyle(index);
 
 	bool b = (penStyle != Qt::NoPen);
@@ -1880,6 +1930,16 @@ void AxisDock::axisLabelsFontColorChanged(const QColor& color) {
 	ui.kcbLabelsFontColor->setColor(color);
 	m_initializing = false;
 }
+void AxisDock::axisLabelsBackgroundTypeChanged(Axis::LabelsBackgroundType type) {
+	m_initializing = true;
+	ui.cbLabelsBackgroundType->setCurrentIndex(static_cast<int>(type));
+	m_initializing = false;
+}
+void AxisDock::axisLabelsBackgroundColorChanged(const QColor& color) {
+	m_initializing = true;
+	ui.kcbLabelsBackgroundColor->setColor(color);
+	m_initializing = false;
+}
 void AxisDock::axisLabelsPrefixChanged(const QString& prefix) {
 	m_initializing = true;
 	ui.leLabelsPrefix->setText(prefix);
@@ -2041,6 +2101,8 @@ void AxisDock::load() {
 	font.setPointSizeF( round(Worksheet::convertFromSceneUnits(font.pixelSize(), Worksheet::Unit::Point)) );
 	ui.kfrLabelsFont->setFont( font );
 	ui.kcbLabelsFontColor->setColor( m_axis->labelsColor() );
+	ui.cbLabelsBackgroundType->setCurrentIndex( (int) m_axis->labelsBackgroundType() );
+	ui.kcbLabelsBackgroundColor->setColor( m_axis->labelsBackgroundColor() );
 	ui.leLabelsPrefix->setText( m_axis->labelsPrefix() );
 	ui.leLabelsSuffix->setText( m_axis->labelsSuffix() );
 	ui.sbLabelsOpacity->setValue( round(m_axis->labelsOpacity()*100.0) );
@@ -2170,6 +2232,8 @@ void AxisDock::loadConfig(KConfig& config) {
 	font.setPointSizeF( round(Worksheet::convertFromSceneUnits(font.pixelSize(), Worksheet::Unit::Point)) );
 	ui.kfrLabelsFont->setFont( group.readEntry("LabelsFont", font) );
 	ui.kcbLabelsFontColor->setColor( group.readEntry("LabelsFontColor", m_axis->labelsColor()) );
+	ui.cbLabelsBackgroundType->setCurrentIndex( group.readEntry("LabelsBackgroundType", (int) m_axis->labelsBackgroundType()) );
+	ui.kcbLabelsBackgroundColor->setColor( group.readEntry("LabelsBackgroundColor", m_axis->labelsBackgroundColor()) );
 	ui.leLabelsPrefix->setText( group.readEntry("LabelsPrefix", m_axis->labelsPrefix()) );
 	ui.leLabelsSuffix->setText( group.readEntry("LabelsSuffix", m_axis->labelsSuffix()) );
 	ui.sbLabelsOpacity->setValue( round(group.readEntry("LabelsOpacity", m_axis->labelsOpacity())*100.0) );
@@ -2278,6 +2342,8 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry("LabelsRotation", ui.sbLabelsRotation->value());
 	group.writeEntry("LabelsFont", ui.kfrLabelsFont->font());
 	group.writeEntry("LabelsFontColor", ui.kcbLabelsFontColor->color());
+	group.writeEntry("LabelsBackgroundType", ui.cbLabelsBackgroundType->currentIndex());
+	group.writeEntry("LabelsBackgroundColor", ui.kcbLabelsBackgroundColor->color());
 	group.writeEntry("LabelsPrefix", ui.leLabelsPrefix->text());
 	group.writeEntry("LabelsSuffix", ui.leLabelsSuffix->text());
 	group.writeEntry("LabelsOpacity", ui.sbLabelsOpacity->value()/100.);
