@@ -40,7 +40,6 @@
 #include <QImageReader>
 
 #include <KLocalizedString>
-#include <KSharedConfig>
 
 /*!
   \class CartesianPlotLegendDock
@@ -77,7 +76,7 @@ CartesianPlotLegendDock::CartesianPlotLegendDock(QWidget* parent) : BaseDock(par
 		layout->setVerticalSpacing(2);
 	}
 
-	updateLocale();
+	CartesianPlotLegendDock::updateLocale();
 
 	//SIGNAL/SLOT
 
