@@ -4,6 +4,7 @@ Project              : LabPlot
 Description 	     : This dock represents the data from the cursors in the cartesian plots
 --------------------------------------------------------------------
 Copyright            : (C) 2019 Martin Marmsoler (martin.marmsoler@gmail.com)
+Copyright            : (C) 2019-2020 Alexander Semke (alexander.semke@web.de)
 
 ***************************************************************************/
 
@@ -34,6 +35,10 @@ Copyright            : (C) 2019 Martin Marmsoler (martin.marmsoler@gmail.com)
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/TreeModel.h"
 
+#include <QKeyEvent>
+#include <QMenu>
+#include <QClipboard>
+
 CursorDock::CursorDock(QWidget* parent) : QWidget(parent), ui(new Ui::CursorDock) {
 	ui->setupUi(this);
 	ui->tvCursorData->setModel(nullptr);
@@ -46,9 +51,16 @@ CursorDock::CursorDock(QWidget* parent) : QWidget(parent), ui(new Ui::CursorDock
 
 	connect(ui->bCollapseAll, &QPushButton::clicked, this, &CursorDock::collapseAll);
 	connect(ui->bExpandAll, &QPushButton::clicked, this, &CursorDock::expandAll);
-
 	connect(ui->cbCursor0en, &QCheckBox::clicked, this, &CursorDock::cursor0EnableChanged);
 	connect(ui->cbCursor1en, &QCheckBox::clicked, this, &CursorDock::cursor1EnableChanged);
+
+	//CTRL+C copies only the last cell in the selection, we want to copy the whole selection.
+	//install event filters to handle CTRL+C key events.
+	ui->tvCursorData->installEventFilter(this);
+
+	ui->tvCursorData->setContextMenuPolicy(Qt::CustomContextMenu);
+	connect(ui->tvCursorData, &QTreeView::customContextMenuRequested,
+			this, &CursorDock::contextMenuRequested);
 }
 
 void CursorDock::setWorksheet(Worksheet* worksheet) {
@@ -143,3 +155,69 @@ void CursorDock::plotCursor1EnableChanged(bool enable) {
 
 	m_initializing = false;
 }
+
+bool CursorDock::eventFilter(QObject* obj, QEvent* event) {
+	if (event->type() == QEvent::KeyPress && obj == ui->tvCursorData) {
+		auto* key_event = static_cast<QKeyEvent*>(event);
+		if (key_event->matches(QKeySequence::Copy)) {
+			resultCopy();
+			return true;
+		}
+	}
+	return QWidget::eventFilter(obj, event);
+}
+
+void CursorDock::contextMenuRequested(QPoint pos) {
+	auto* menu = new QMenu;
+	menu->addAction(i18n("Copy Selection"), this, &CursorDock::resultCopy, QKeySequence::Copy);
+	menu->addAction(i18n("Copy All"), this, &CursorDock::resultCopyAll);
+	menu->exec(ui->tvCursorData->mapToGlobal(pos));
+}
+
+void CursorDock::resultCopy() {
+	QString str;
+	auto* model = ui->tvCursorData->model();
+	auto* selection = ui->tvCursorData->selectionModel();
+	const auto& indices = selection->selectedRows();
+	for (auto index : indices) {
+		int row = index.row();
+		auto parent = index.parent();
+		for (int col = 0; col < model->columnCount(); ++col) {
+			if (col != 0)
+				str += QLatin1Char('\t');
+			str += model->data(model->index(row, col, parent)).toString();
+		}
+
+		str += QLatin1Char('\n');
+	}
+
+	QApplication::clipboard()->setText(str);
+}
+
+void CursorDock::resultCopyAll() {
+	QString str;
+	auto* model = ui->tvCursorData->model();
+	for (int row = 0; row < model->rowCount(); ++row) {
+		for (int col = 0; col < model->columnCount(); ++col) {
+			if (col != 0)
+				str += QLatin1Char('\t');
+			str += model->data(model->index(row, col)).toString();
+		}
+
+		str += QLatin1Char('\n');
+
+		//iterate over all children of the current row
+		auto index = model->index(row, 0);
+		for (int row = 0; row < model->rowCount(index); ++row) {
+			for (int col = 0; col < model->columnCount(); ++col) {
+				if (col != 0)
+					str += QLatin1Char('\t');
+				str += model->data(model->index(row, col, index)).toString();
+			}
+
+			str += QLatin1Char('\n');
+		}
+	}
+
+	QApplication::clipboard()->setText(str);
+}
