@@ -33,8 +33,6 @@
 
 #include <KLocalizedString>
 #include <KConfig>
-#include <KConfigGroup>
-#include <KSharedConfig>
 
 #include <QPainter>
 #include <QDir>
@@ -59,7 +57,7 @@ CustomPointDock::CustomPointDock(QWidget *parent): BaseDock(parent) {
 		layout->setVerticalSpacing(2);
 	}
 
-	updateLocale();
+	CustomPointDock::updateLocale();
 
 	//SLOTS
 	//General
