@@ -40,9 +40,7 @@
 #include <QPageSize>
 
 #include <KConfig>
-#include <KConfigGroup>
 #include <KLocalizedString>
-#include <KSharedConfig>
 
 /*!
   \class ImageDock
@@ -100,7 +98,7 @@ ImageDock::ImageDock(QWidget* parent) : BaseDock(parent) {
 	ui.cbBorderStyle->addItem(i18n("Dash dot line"));
 	ui.cbBorderStyle->addItem(i18n("Dash dot dot line"));
 
-	updateLocale();
+	ImageDock::updateLocale();
 
 	//SLOTs
 	//General
