@@ -31,8 +31,6 @@
 #include "kdefrontend/TemplateHandler.h"
 
 #include <KConfig>
-#include <KConfigGroup>
-#include <KSharedConfig>
 
 #include <QDir>
 
