@@ -30,12 +30,13 @@
 #define MATRIXDOCK_H
 
 #include "backend/matrix/Matrix.h"
+#include "kdefrontend/dockwidgets/BaseDock.h"
 #include "ui_matrixdock.h"
 
 class Matrix;
 class KConfig;
 
-class MatrixDock : public QWidget {
+class MatrixDock : public BaseDock {
 	Q_OBJECT
 
 public:
@@ -46,15 +47,12 @@ private:
 	Ui::MatrixDock ui;
 	QList<Matrix*> m_matrixList;
 	Matrix* m_matrix{nullptr};
-	bool m_initializing{false};
 
 	void load();
 	void loadConfig(KConfig&);
 
 private slots:
 	//SLOTs for changes triggered in MatrixDock
-	void nameChanged();
-	void commentChanged();
 
 	void rowCountChanged(int);
 	void columnCountChanged(int);
