@@ -39,9 +39,7 @@
 #include <QPageSize>
 
 #include <KConfig>
-#include <KConfigGroup>
 #include <KLocalizedString>
-#include <KSharedConfig>
 
 /*!
   \class WorksheetDock
@@ -80,7 +78,7 @@ WorksheetDock::WorksheetDock(QWidget *parent): BaseDock(parent) {
 		layout->setVerticalSpacing(2);
 	}
 
-	updateLocale();
+	WorksheetDock::updateLocale();
 
 	//SLOTs
 	//General
@@ -495,6 +493,9 @@ void WorksheetDock::orientationChanged(int index) {
 
 // "Background"-tab
 void WorksheetDock::backgroundTypeChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto type = (PlotArea::BackgroundType)index;
 
 	if (type == PlotArea::BackgroundType::Color) {
@@ -563,6 +564,9 @@ void WorksheetDock::backgroundTypeChanged(int index) {
 }
 
 void WorksheetDock::backgroundColorStyleChanged(int index) {
+	if (index == -1)
+		return;
+
 	auto style = (PlotArea::BackgroundColorStyle)index;
 
 	if (style == PlotArea::BackgroundColorStyle::SingleColor) {
