@@ -40,8 +40,6 @@
 #include "kdefrontend/widgets/FitParametersWidget.h"
 
 #include <KMessageWidget>
-#include <KConfigGroup>
-#include <KSharedConfig>
 
 #include <QMenu>
 #include <QWidgetAction>
@@ -990,13 +988,12 @@ void XYFitCurveDock::showOptions() {
 	menu.exec(uiGeneralTab.pbOptions->mapToGlobal(pos));
 }
 
-void XYFitCurveDock::insertFunction(const QString& str) const {
-	//TODO: not all function have only one argument!
-	uiGeneralTab.teEquation->insertPlainText(str + "(x)");
+void XYFitCurveDock::insertFunction(const QString& functionName) const {
+	uiGeneralTab.teEquation->insertPlainText(functionName + ExpressionParser::functionArgumentString(functionName, XYEquationCurve::EquationType::Cartesian));
 }
 
-void XYFitCurveDock::insertConstant(const QString& str) const {
-	uiGeneralTab.teEquation->insertPlainText(str);
+void XYFitCurveDock::insertConstant(const QString& constantsName) const {
+	uiGeneralTab.teEquation->insertPlainText(constantsName);
 }
 
 /*!
@@ -1008,8 +1005,8 @@ void XYFitCurveDock::setPlotXRange() {
 
 	auto* plot = dynamic_cast<CartesianPlot*>(m_curve->parentAspect());
 	if (plot != nullptr) {
-		const Range<double> range = m_fitData.evalRange;
-		const double extend = range.size() * 0.05;	// + 5 %
+		const Range<double> range{ m_fitData.evalRange };
+		const double extend{ range.size() * 0.05 };	// + 5 %
 		if (!range.isZero()) {
 			plot->setXMin(range.min() - extend);
 			plot->setXMax(range.max() + extend);
@@ -1222,8 +1219,8 @@ void XYFitCurveDock::showFitResult() {
 	SET_NUMBER_LOCALE
 	// used confidence interval
 	double confidenceInterval{m_fitData.confidenceInterval};
-	uiGeneralTab.twParameters->horizontalHeaderItem(6)->setToolTip(i18n("%1\% lower confidence level", numberLocale.toString(confidenceInterval, 'g', 7)));
-	uiGeneralTab.twParameters->horizontalHeaderItem(7)->setToolTip(i18n("%1\% upper confidence level", numberLocale.toString(confidenceInterval, 'g', 7)));
+	uiGeneralTab.twParameters->horizontalHeaderItem(6)->setToolTip(i18n("%1 % lower confidence level", numberLocale.toString(confidenceInterval, 'g', 7)));
+	uiGeneralTab.twParameters->horizontalHeaderItem(7)->setToolTip(i18n("%1 % upper confidence level", numberLocale.toString(confidenceInterval, 'g', 7)));
 
 	// log
 	uiGeneralTab.twLog->item(1, 1)->setText(numberLocale.toString(fitResult.iterations));
