@@ -38,7 +38,6 @@
 #include <QWindow>
 
 #include <KLocalizedString>
-#include <KSharedConfig>
 #include <KWindowConfig>
 
 /*!
@@ -109,7 +108,7 @@ void AddSubtractValueDialog::init() {
 	ui.setupUi(this);
 	setAttribute(Qt::WA_DeleteOnClose);
 
-	QDialogButtonBox* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+	auto* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
 	ui.gridLayout->addWidget(btnBox, 3, 0, 1, 2);
 	m_okButton = btnBox->button(QDialogButtonBox::Ok);
@@ -272,7 +271,7 @@ void AddSubtractValueDialog::generateForColumns() {
 
 	SET_NUMBER_LOCALE
 	bool ok;
-	auto mode = m_columns.first()->columnMode();
+	const auto mode = m_columns.first()->columnMode();
 	const int rows = m_spreadsheet->rowCount();
 	if (mode == AbstractColumn::ColumnMode::Integer) {
 		QVector<int> new_data(rows);
@@ -290,7 +289,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Add:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<int>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) + value;
 
 				col->replaceInteger(0, new_data);
@@ -299,7 +298,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Multiply:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<int>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) * value;
 
 				col->replaceInteger(0, new_data);
@@ -308,7 +307,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Divide:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<int>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) / value;
 
 				col->replaceInteger(0, new_data);
@@ -331,7 +330,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Add:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<qint64>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) + value;
 
 				col->replaceBigInt(0, new_data);
@@ -340,7 +339,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Multiply:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<qint64>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) * value;
 
 				col->replaceBigInt(0, new_data);
@@ -349,7 +348,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Divide:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<qint64>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) / value;
 
 				col->replaceBigInt(0, new_data);
@@ -371,7 +370,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Add:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<double>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) + value;
 
 				col->replaceValues(0, new_data);
@@ -380,7 +379,7 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Multiply:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<double>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) * value;
 
 				col->replaceValues(0, new_data);
@@ -389,25 +388,31 @@ void AddSubtractValueDialog::generateForColumns() {
 		case Divide:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<double>* >(col->data());
-				for (int i = 0; i<rows; ++i)
+				for (int i = 0; i < rows; ++i)
 					new_data[i] = data->operator[](i) / value;
 
 				col->replaceValues(0, new_data);
 			}
 			break;
-	}
+		}
 	} else { //datetime
 		QVector<QDateTime> new_data(rows);
-		quint64 value = ui.dateTimeEdit->dateTime().toMSecsSinceEpoch();
+		qint64 value = ui.dateTimeEdit->dateTime().toMSecsSinceEpoch();
+		//QDEBUG(Q_FUNC_INFO << ", DT CHANGE:" << ui.dateTimeEdit->dateTime())
+		//QDEBUG(Q_FUNC_INFO << ", VALUE:" << value)
 		switch (m_operation) {
 		case Subtract:
-			value *= -1.;
+			value *= -1;
 			//fall through
 		case Add:
 			for (auto* col : m_columns) {
 				auto* data = static_cast<QVector<QDateTime>* >(col->data());
-				for (int i = 0; i<rows; ++i)
-					new_data[i] = QDateTime::fromMSecsSinceEpoch(data->operator[](i).toMSecsSinceEpoch() + value);
+				//QDEBUG(Q_FUNC_INFO << ", DT OLD:" << data->operator[](0))
+				//QDEBUG(Q_FUNC_INFO << ", OLD VALUE:" << data->operator[](0).toMSecsSinceEpoch())
+				//QDEBUG(Q_FUNC_INFO << ", NEW VALUE:" << data->operator[](0).toMSecsSinceEpoch() + value)
+				//QDEBUG(Q_FUNC_INFO << ", DT NEW:" << QDateTime::fromMSecsSinceEpoch(data->operator[](0).toMSecsSinceEpoch() + value, timeSpec))
+				for (int i = 0; i < rows; ++i)
+					new_data[i] = QDateTime::fromMSecsSinceEpoch(data->operator[](i).toMSecsSinceEpoch() + value, data->operator[](i).timeSpec());
 
 				col->replaceDateTimes(0, new_data);
 			}
@@ -450,28 +455,25 @@ void AddSubtractValueDialog::generateForMatrices() {
 			value *= -1;
 			//fall through
 		case Add:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j)
-				{
-					new_data = m_matrix->cell<int>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<int>(i, j);
 					new_data += value;
 					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		case Multiply:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j)
-				{
-					new_data = m_matrix->cell<int>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<int>(i, j);
 					new_data *= value;
 					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		case Divide:
-		for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j)
-				{
-					new_data = m_matrix->cell<int>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<int>(i, j);
 					new_data /= value;
 					m_matrix->setCell(i, j, new_data);
 				}
@@ -491,27 +493,27 @@ void AddSubtractValueDialog::generateForMatrices() {
 			value *= -1;
 			//fall through
 		case Add:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j) {
-					new_data = m_matrix->cell<qint64>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<qint64>(i, j);
 					new_data += value;
 					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		case Multiply:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j) {
-					new_data = m_matrix->cell<qint64>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<qint64>(i, j);
 					new_data *= value;
 					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		case Divide:
-		for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j) {
-					new_data = m_matrix->cell<qint64>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<qint64>(i, j);
 					new_data /= value;
-					m_matrix->setCell(i,j,new_data);
+					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		}
@@ -529,49 +531,45 @@ void AddSubtractValueDialog::generateForMatrices() {
 			value *= -1.;
 			//fall through
 		case Add:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j)
-				{
-					new_data = m_matrix->cell<double>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<double>(i, j);
 					new_data += value;
-					m_matrix->setCell(i,j,new_data);
+					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		case Multiply:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j)
-				{
-					new_data = m_matrix->cell<double>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<double>(i, j);
 					new_data *= value;
-					m_matrix->setCell(i,j,new_data);
+					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 		case Divide:
-			for (int i = 0; i<rows; ++i)
-				for(int j = 0; j<cols; ++j)
-				{
-					new_data = m_matrix->cell<double>(i,j);
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					new_data = m_matrix->cell<double>(i, j);
 					new_data /= value;
-					m_matrix->setCell(i,j,new_data);
+					m_matrix->setCell(i, j, new_data);
 				}
 			break;
 	}
 	} else { //datetime
 		QDateTime new_data;
-		quint64 value = ui.dateTimeEdit->dateTime().toMSecsSinceEpoch();
+		qint64 value = ui.dateTimeEdit->dateTime().toMSecsSinceEpoch();
 		switch (m_operation) {
 		case Subtract:
-			value *= -1.;
+			value *= -1;
 			//fall through
 		case Add:
-			for (int i = 0; i<rows; ++i)
-			for(int j = 0; j<cols; ++j)
-			{
-				quint64 data = (m_matrix->cell<QDateTime>(i,j)).toMSecsSinceEpoch();
-				new_data = QDateTime::fromMSecsSinceEpoch(data + value);
-				m_matrix->setCell(i,j,new_data);
-			}
-		break;
+			for (int i = 0; i < rows; ++i)
+				for(int j = 0; j < cols; ++j) {
+					auto dateTime = m_matrix->cell<QDateTime>(i, j);
+					new_data = QDateTime::fromMSecsSinceEpoch(dateTime.toMSecsSinceEpoch() + value, dateTime.timeSpec());
+					m_matrix->setCell(i, j, new_data);
+				}
+			break;
 		case Multiply:
 		case Divide:
 			break;
