@@ -47,13 +47,13 @@ class PlotDataDialog : public QDialog {
 	Q_OBJECT
 
 public:
-	enum PlotType {PlotXYCurve, PlotHistogram};
-	enum AnalysisAction {DataReduction,
+	enum class PlotType {XYCurve, Histogram};
+	enum class AnalysisAction {DataReduction,
 		Differentiation, Integration, Interpolation, Smoothing,
 		FitLinear, FitPower, FitExp1, FitExp2, FitInvExp, FitGauss, FitCauchyLorentz, FitTan, FitTanh, FitErrFunc, FitCustom,
 		FourierFilter};
 
-	explicit PlotDataDialog(Spreadsheet*, PlotType = PlotXYCurve, QWidget* parent = nullptr);
+	explicit PlotDataDialog(Spreadsheet*, PlotType = PlotType::XYCurve, QWidget* parent = nullptr);
 	~PlotDataDialog() override;
 
 	void setAnalysisAction(AnalysisAction);
@@ -69,7 +69,7 @@ private:
 	AspectTreeModel* m_plotsModel;
 	AspectTreeModel* m_worksheetsModel;
 	PlotType m_plotType;
-	AnalysisAction m_analysisAction{Differentiation};
+	AnalysisAction m_analysisAction{AnalysisAction::Differentiation};
 	bool m_analysisMode{false};
 	AbstractAspect* m_lastAddedCurve{nullptr};
 
@@ -82,13 +82,11 @@ private:
 	void addHistogram(const QString& name, Column* column, CartesianPlot*);
 	Column* columnFromName(const QString&) const;
 
-protected  slots:
-	virtual void checkOkButton();
-
 private slots:
 	void plot();
 	void curvePlacementChanged();
 	void plotPlacementChanged();
+	void checkOkButton();
 };
 
 #endif
