@@ -4,7 +4,7 @@
     --------------------------------------------------------------------
     Copyright        : (C) 2014-2017 Alexander Semke (alexander.semke@web.de)
     Description      : widget for defining mathematical expressions
-	modified version of http://qt-project.org/doc/qt-4.8/tools-customcompleter.html
+	modified version of https://doc.qt.io/qt-5/qtwidgets-tools-customcompleter-example.html
  ***************************************************************************/
 
 /***************************************************************************
@@ -97,7 +97,7 @@ private slots:
 
 private:
 	EquationHighlighter* m_highlighter;
-	XYEquationCurve::EquationType m_expressionType{XYEquationCurve::Neutral};
+	XYEquationCurve::EquationType m_expressionType{XYEquationCurve::EquationType::Neutral};
 	QStringList m_variables;
 	QCompleter* m_completer;
 	bool m_isValid{false};
