@@ -33,6 +33,8 @@
 #include <QGroupBox>
 #include <QVBoxLayout>
 
+#include <KLocalizedString>
+
 /*!
     \class ThemesComboBox
     \brief Preview of all themes in a QComboBox.
@@ -78,12 +80,16 @@ bool ThemesComboBox::eventFilter(QObject* object, QEvent* event) {
 		this->setFocus();
 		return true;
 	}
-	return false;
+
+	return QComboBox::eventFilter(object, event);
 }
 
 void ThemesComboBox::handleThemeChanged(const QString& theme) {
 	if (theme != currentText()) {
-		setItemText(0, theme);
+		if (theme.isEmpty())
+			setItemText(0, i18n("Default")); //default theme
+		else
+			setItemText(0, theme);
 		emit currentThemeChanged(theme);
 	}
 
