@@ -55,7 +55,7 @@ SlidingPanel::SlidingPanel(QWidget *parent, const QString &worksheetName) : QFra
 	setLayout(hlayout);
 
 	QPalette pal(palette());
-	pal.setColor(QPalette::Background, Qt::gray);
+	pal.setColor(QPalette::Window, Qt::gray);
 	setAutoFillBackground(true);
 	setPalette(pal);
 
@@ -82,12 +82,8 @@ QSize SlidingPanel::sizeHint() const {
 	QSize sh;
 	const QRect& screenSize = QGuiApplication::primaryScreen()->availableGeometry();
 	sh.setWidth(screenSize.width());
-
-	//for the height use 1.5 times the height of the font used in the label (20 points) in pixels
-	QFont font;
-	font.setPointSize(20);
-	const QFontMetrics fm(font);
-	sh.setHeight(1.5*fm.ascent());
+	sh.setHeight(m_worksheetName->sizeHint().height()
+				 + layout()->contentsMargins().top() + layout()->contentsMargins().bottom());
 
 	return sh;
 }
