@@ -37,9 +37,6 @@
 #include "backend/spreadsheet/Spreadsheet.h"
 
 void ProjectImportTest::initTestCase() {
-	const QString currentDir = __FILE__;
-	m_dataDir = currentDir.left(currentDir.lastIndexOf(QDir::separator())) + QDir::separator() + QLatin1String("data") + QDir::separator();
-
 	// needed in order to have the signals triggered by SignallingUndoCommand, see LabPlot.cpp
 	//TODO: redesign/remove this
 	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
@@ -81,7 +78,7 @@ void ProjectImportTest::testOrigin01() {
 
 	//import the opj file into LabPlot's project object
 	OriginProjectParser parser;
-	parser.setProjectFileName(m_dataDir + QLatin1String("origin8_test_tree_import.opj"));
+	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 	parser.importTo(&project, QStringList());
 
@@ -190,7 +187,7 @@ void ProjectImportTest::testOrigin01() {
 void ProjectImportTest::testOrigin02() {
 	//import one single object
 	OriginProjectParser parser;
-	parser.setProjectFileName(m_dataDir + QLatin1String("origin8_test_tree_import.opj"));
+	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"), QLatin1String("test_tree_import/Folder1"), QLatin1String("test_tree_import")};
 	parser.importTo(&project, selectedPathes);
@@ -222,7 +219,7 @@ void ProjectImportTest::testOrigin02() {
 void ProjectImportTest::testOrigin03() {
 	//import one single object
 	OriginProjectParser parser;
-	parser.setProjectFileName(m_dataDir + QLatin1String("origin8_test_tree_import.opj"));
+	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 
 	//import one single child in "Folder1"
@@ -283,7 +280,7 @@ void ProjectImportTest::testOrigin03() {
  */
 void ProjectImportTest::testOrigin04() {
 	OriginProjectParser parser;
-	parser.setProjectFileName(m_dataDir + QLatin1String("origin8_test_tree_import.opj"));
+	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 
 	//import "Book1"
@@ -303,12 +300,13 @@ void ProjectImportTest::testOrigin04() {
 	QCOMPARE(spreadsheet != nullptr, true);
 
 	//the (0,0)-cell has the value 1.0
-	if (spreadsheet != nullptr)
+	if (spreadsheet != nullptr) {
 		QCOMPARE(spreadsheet->column(0)->valueAt(0), 1.0);
 
-	//set the value to 5.0
-	spreadsheet->column(0)->setValueAt(0, 5.0);
-	QCOMPARE(spreadsheet->column(0)->valueAt(0), 5.0);
+		//set the value to 5.0
+		spreadsheet->column(0)->setValueAt(0, 5.0);
+		QCOMPARE(spreadsheet->column(0)->valueAt(0), 5.0);
+	}
 
 	//re-import
 	parser.importTo(&project, selectedPathes);
@@ -326,7 +324,7 @@ void ProjectImportTest::testOrigin04() {
 
 void ProjectImportTest::testOriginTextNumericColumns() {
 	OriginProjectParser parser;
-	parser.setProjectFileName(m_dataDir + QLatin1String("origin8_test_workbook.opj"));
+	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_workbook.opj")));
 	Project project;
 
 	//import "Book1"
@@ -345,14 +343,17 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	auto* spreadsheet = dynamic_cast<Spreadsheet*>(aspect);
 	QCOMPARE(spreadsheet != nullptr, true);
 
+	//additional pointer check for static code analysis tools like Coverity that are not aware of QCOMPARE above
+	if (!spreadsheet)
+		return;
+
 	//check the values in the imported columns
-	if (spreadsheet != nullptr)
-		QCOMPARE(spreadsheet->columnCount(), 6);
+	QCOMPARE(spreadsheet->columnCount(), 6);
 
 	//1st column, Origin::TextNumeric:
 	//first non-empty value is numerical, column is set to Numeric, empty or text values in the column a set to NAN
 	Column* column = spreadsheet->column(0);
-	QCOMPARE(column->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Numeric);
 	QCOMPARE(!std::isnan(column->valueAt(0)), false);
 	QCOMPARE(column->valueAt(1), 1.1);
 	QCOMPARE(column->valueAt(2), 2.2);
@@ -362,7 +363,7 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	//2nd column, Origin::TextNumeric:
 	//first non-empty value is string, the column is set to Text, numerical values are converted to strings
 	column = spreadsheet->column(1);
-	QCOMPARE(column->columnMode(), AbstractColumn::Text);
+	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(column->textAt(0).isEmpty(), true);
 	QCOMPARE(column->textAt(1), QLatin1String("a"));
 	QCOMPARE(column->textAt(2), QLatin1String("b"));
@@ -372,7 +373,7 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	//3rd column, Origin::TextNumeric:
 	//first is numerical, column is set to Numeric, empty or text values in the column a set to NAN
 	column = spreadsheet->column(2);
-	QCOMPARE(column->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Numeric);
 	QCOMPARE(column->valueAt(0), 1.1);
 	QCOMPARE(column->valueAt(1), 2.2);
 	QCOMPARE(!std::isnan(column->valueAt(2)), false);
@@ -382,7 +383,7 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	//4th column, Origin::TextNumeric:
 	//first value is string, the column is set to Text, numerical values are converted to strings
 	column = spreadsheet->column(3);
-	QCOMPARE(column->columnMode(), AbstractColumn::Text);
+	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(column->textAt(0), QLatin1String("a"));
 	QCOMPARE(column->textAt(1), QLatin1String("b"));
 	QCOMPARE(column->textAt(2), QLatin1String("1.1"));
@@ -392,7 +393,7 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	//5th column, Origin::Numeric
 	//column is set to Numeric, empty values in the column a set to NAN
 	column = spreadsheet->column(4);
-	QCOMPARE(column->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Numeric);
 	QCOMPARE(!std::isnan(column->valueAt(0)), false);
 	QCOMPARE(column->valueAt(1), 1.1);
 	QCOMPARE(column->valueAt(2), 2.2);
@@ -402,13 +403,67 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	//6th column, Origin::Numeric
 	//column is set to Numeric, empty values in the column a set to NAN
 	column = spreadsheet->column(5);
-	QCOMPARE(column->columnMode(), AbstractColumn::Numeric);
+	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Numeric);
 	QCOMPARE(column->valueAt(0), 1.1);
 	QCOMPARE(column->valueAt(1), 2.2);
 	QCOMPARE(column->valueAt(2), 3.3);
 	QCOMPARE(!std::isnan(column->valueAt(3)), false);
 	QCOMPARE(!std::isnan(column->valueAt(4)), false);
 }
+
+void ProjectImportTest::testParseOriginTags_data() {
+	QTest::addColumn<QString>("originTag");
+	QTest::addColumn<QString>("labPlotHTML");
+
+	QTest::newRow("bold") << "\\b(bold)" << "<b>bold</b>";
+
+	QTest::newRow("italic") << "\\i(italic)" << "<i>italic</i>";
+
+	QTest::newRow("strike through") << "\\s(strike through)" << "<s>strike through</s>";
+
+	QTest::newRow("underlined") << "\\u(underlined)" << "<u>underlined</u>";
+
+	QTest::newRow("greek char") << "\\g(a)" << "<font face=Symbol>a</font>";
+
+	QTest::newRow("sub-script") << "a\\-(b)" << "a<sub>b</sub>";
+
+	QTest::newRow("super-script") << "a\\+(b)" << "a<sup>b</sup>";
+
+	QTest::newRow("set-font") << "\\f:dejavu sans(text)" << "<font face=\"dejavu sans\">text</font>";
+
+	QTest::newRow("font-size")	<< "some \\p200(big) text"
+								<< "some <span style=\"font-size: 200%\">big</span> text";
+
+	QTest::newRow("color")	<< "some \\c15(colored) text"
+							<< "some <span style=\"color: #8000ff\">colored</span> text";
+
+	QTest::newRow("nested-non-tag-parenthesis")
+			<< "\\b(text (c) and (fh) and a(t) and empty ())"
+			<< "<b>text (c) and (fh) and a(t) and empty ()</b>";
+
+	QTest::newRow("nested-tags")
+			<< "\\b(bold text with some \\i(italic) bits and some \\c15(color)) "
+			   "then a change of \\f:dejavu sans(font)"
+			<< "<b>bold text with some <i>italic</i> bits and some "
+			   "<span style=\"color: #8000ff\">color</span></b> "
+			   "then a change of <font face=\"dejavu sans\">font</font>";
+
+	QTest::newRow("nested-tags-with-extra-spaces")
+			<< "\\ b (bold text with some \\ i(italic) bits and some \\c 15 (color)) "
+			   "then a change of \\ f:dejavu sans( font)"
+			<< "<b>bold text with some <i>italic</i> bits and some "
+			   "<span style=\"color: #8000ff\">color</span></b> "
+			   "then a change of <font face=\"dejavu sans\"> font</font>";
+}
+
+void ProjectImportTest::testParseOriginTags() {
+	QFETCH(QString, originTag);
+	QFETCH(QString, labPlotHTML);
+
+	OriginProjectParser parser;
+	QCOMPARE(parser.parseOriginTags(originTag), labPlotHTML);
+}
+
 #endif
 
 QTEST_MAIN(ProjectImportTest)
